diff -pruN 6.02-1/CHANGES 6.03-1/CHANGES
--- 6.02-1/CHANGES	2019-09-22 12:18:40.000000000 +0000
+++ 6.03-1/CHANGES	2020-04-23 13:51:45.000000000 +0000
@@ -1,5 +1,16 @@
 CHANGELOG for ClamTk:
 
+6.03 - 20200423
+---------------
+    * Bug fix affecting manual updates
+    * Update year (2019 -> 2020)
+    * Clean up man page.
+    * Heuristic scanning made an option rather than a default
+    * Fix icon mismatch in the Scheduler
+    * Fix icon glitch in Update
+    * Updated language files: English (en_UK), Indonesian (id),
+      Swedish (sv) (Launchpad #1688469)
+
 6.02 - 20190919
 ---------------
     * Updated language files: Turkish (tr), Kazakh (kk), Swedish (sv),
diff -pruN 6.02-1/clamtk 6.03-1/clamtk
--- 6.02-1/clamtk	2019-09-28 11:13:50.000000000 +0000
+++ 6.03-1/clamtk	2020-04-23 13:50:43.000000000 +0000
@@ -1,6 +1,6 @@
 #!/usr/bin/env perl
 #
-# ClamTk, copyright (C) 2004-2019 Dave M
+# ClamTk, copyright (C) 2004-2020 Dave M
 #
 # This file is part of ClamTk
 # (https://gitlab.com/dave_m/clamtk-gtk3/).
Binary files 6.02-1/clamtk.1.gz and 6.03-1/clamtk.1.gz differ
diff -pruN 6.02-1/clamtk-gnome/CHANGES 6.03-1/clamtk-gnome/CHANGES
--- 6.02-1/clamtk-gnome/CHANGES	1970-01-01 00:00:00.000000000 +0000
+++ 6.03-1/clamtk-gnome/CHANGES	2020-02-22 12:05:26.000000000 +0000
@@ -0,0 +1,28 @@
+CHANGELOG for clamtk-gnome:
+
+0.05 - 20200222
+---------------
+    * Fix for Github #15 ("Problem with filenames with spaces in nautilus"). Thanks, j-licht!
+
+0.04 - 20200209
+---------------
+    * Improvements to python3 code.
+    * Backwards compatibility with python2 removed.
+
+0.03 - 20190412
+---------------
+    * Allow for python3.
+
+0.02 - 20170907
+---------------
+    * Fix README file, which has incorrect instructions for
+      manually installing it.
+    * Make build for CentOS 7, now possible with the
+      nautilus-python rpm in EPEL.
+    * Python file has been renamed to clamtk-gnome.py.
+    * Use xz compression.
+    * Change Python interpreter from /usr/bin/env.
+
+0.01 - 20150906
+---------------
+    * Initial release.
Binary files 6.02-1/clamtk-gnome/clamtk-gnome.1.gz and 6.03-1/clamtk-gnome/clamtk-gnome.1.gz differ
diff -pruN 6.02-1/clamtk-gnome/clamtk-gnome.py 6.03-1/clamtk-gnome/clamtk-gnome.py
--- 6.02-1/clamtk-gnome/clamtk-gnome.py	1970-01-01 00:00:00.000000000 +0000
+++ 6.03-1/clamtk-gnome/clamtk-gnome.py	2020-02-22 12:15:19.000000000 +0000
@@ -0,0 +1,86 @@
+#!/usr/bin/env python3
+# -*- coding: utf-8 -*-
+# ClamTk, copyright (C) 2004-2020 Dave M, Tord Dellsén
+#
+# This file is part of ClamTk
+# (https://gitlab.com/dave_m/clamtk/wikis/Home)
+#
+# ClamTk is free software; you can redistribute it and/or modify it
+# under the terms of either:
+#
+# a) the GNU General Public License as published by the Free Software
+# Foundation; either version 1, or (at your option) any later version, or
+#
+# b) the "Artistic License".
+
+import locale
+import subprocess
+
+locale.setlocale(locale.LC_ALL, "")
+
+import gettext
+
+gettext.bindtextdomain("clamtk", "/usr/share/locale")
+gettext.textdomain("clamtk")
+_ = gettext.gettext
+
+import gi
+
+gi.require_version("Nautilus", "3.0")
+
+from gi.repository import Nautilus
+from gi.repository import GObject
+
+
+class OpenTerminalExtension(GObject.GObject, Nautilus.MenuProvider):
+    def __init__(self):
+        print("Initializing clamtk-gnome")
+
+    def _open_scanner(self, file):
+        filename = file.get_location().get_path()
+        # - file is of type nautiuls-vsf-file
+        # https://github.com/GNOME/nautilus/blob/master/src/nautilus-file.h
+        # which inherits from nautilus-file
+        # https://github.com/GNOME/nautilus/blob/master/src/nautilus-vfs-file.h
+        # - get_location returns a GFile
+        # https://developer.gnome.org/gio/stable/GFile.html
+        # which has the get_path function which returns the absolute path as a string
+
+        cmd = ["clamtk", filename]
+        subprocess.Popen(cmd)
+
+    def menu_activate_cb(self, menu, file):
+        self._open_scanner(file)
+
+    def menu_background_activate_cb(self, menu, file):
+        self._open_scanner(file)
+
+    def get_file_items(self, window, files):
+        if len(files) != 1:
+            return
+        file = files[0]
+
+        item = Nautilus.MenuItem(
+            name="NautilusPython::openscanner",
+            label=_("Scan for threats..."),
+            tip=_("Scan for threats..."),
+            icon="clamtk",
+        )
+        # - the tooltips are not shown any longer in Nautilus
+        # (the code is kept here in case this changes again for Nautilus)
+        item.connect("activate", self.menu_activate_cb, file)
+
+        return [item]
+
+    def get_background_items(self, window, file):
+        item = Nautilus.MenuItem(
+            name="NautilusPython::openscanner_directory",
+            label=_("Scan directory for threats..."),
+            tip=_("Scan this directory for threats..."),
+            icon="clamtk",
+        )
+        # - the tooltips are not shown any longer in Nautilus
+        # (the code is kept here in case this changes again for Nautilus
+        item.connect("activate", self.menu_background_activate_cb, file)
+
+        return [item]
diff -pruN 6.02-1/clamtk-gnome/DISCLAIMER 6.03-1/clamtk-gnome/DISCLAIMER
--- 6.02-1/clamtk-gnome/DISCLAIMER	1970-01-01 00:00:00.000000000 +0000
+++ 6.03-1/clamtk-gnome/DISCLAIMER	2016-08-06 09:15:13.000000000 +0000
@@ -0,0 +1,14 @@
+This software (ClamTk and clamtk-gnome) is provided 'as is' without
+warranty of any kind, either expressed or implied, including,
+but not limited to, the implied warranties of fitness for a
+purpose, or the warranty of non-infringement.
+
+Without limiting the foregoing, there is no warranty that:
+
+   1. the software will meet your requirements
+   2. the software will be uninterrupted, timely, secure or error-free
+   3. the results that may be obtained from the use of the software will
+      be effective, accurate or reliable
+   4. the quality of the software will meet your expectations
+
+Having said that, I do my best to make it as good as I can. Really.
Binary files 6.02-1/clamtk-gnome/images/clamtk-gnome.png and 6.03-1/clamtk-gnome/images/clamtk-gnome.png differ
diff -pruN 6.02-1/clamtk-gnome/LICENSE 6.03-1/clamtk-gnome/LICENSE
--- 6.02-1/clamtk-gnome/LICENSE	1970-01-01 00:00:00.000000000 +0000
+++ 6.03-1/clamtk-gnome/LICENSE	2020-02-09 15:04:59.000000000 +0000
@@ -0,0 +1,25 @@
+COPYRIGHT AND LICENCE
+
+ClamTk, copyright (C) 2004-2020 Dave M, Tord Dellsén
+https://gitlab.com/dave_m/clamtk-gnome
+https://bitbucket.org/davem_/clamtk-gnome/
+
+No longer used:
+http://code.google.com/p/clamtk/
+http://freshmeat.net/projects/clamtk
+http://clamtk.sourceforge.net
+
+Deprecated:
+https://github.com/dave-theunsub/clamtk
+
+Dave M <dave.nerd at gmail>
+0x6ADA59DE
+
+All rights reserved.  This program is free software; you can
+redistribute it and/or modify it under the terms of either:
+
+a) the GNU General Public License as published by the Free
+Software Foundation; either version 1, or (at your option)
+any later version, or
+
+b) the "Artistic License".
diff -pruN 6.02-1/clamtk-gnome/README.md 6.03-1/clamtk-gnome/README.md
--- 6.02-1/clamtk-gnome/README.md	1970-01-01 00:00:00.000000000 +0000
+++ 6.03-1/clamtk-gnome/README.md	2020-02-22 12:07:58.000000000 +0000
@@ -0,0 +1,83 @@
+This readme file was last updated 20200222
+
+# README for clamtk-gnome
+
+clamtk-gnome is a simple plugin for
+[ClamTk](https://github.com/dave-theunsub/clamtk) to allow a right-click, context menu scan of files or folders in the Nautilus file manager.
+
+
+## Installation
+
+This section gives different options for installing ClamTk Gnome
+
+Please note that you may need to add `sudo` before the installation commands for Ubuntu and Debian-based systems
+
+### Option A (for Ubuntu and Debian-based systems): Installation from official repo
+
+`apt-get install clamtk-gnome`
+
+### Option B: Installation from downloaded package
+
+There are deb and rpm packages to install this plugin:
+
+#### On Debian based systems (Ubuntu etc)
+
+`dpkg -i clamtk-gnome_0.03-1_all.deb`
+
+`apt-get install -f`
+
+#### On CentOS systems
+
+`yum install clamtk-gnome-0.03-1.fc.noarch.rpm`
+
+#### On Fedora systems
+
+`dnf install clamtk-gnome-0.03-1.fc.noarch.rpm`
+
+### Option C: Manual installation
+
+1. Install [ClamTk](https://gitlab.com/dave_m/clamtk/wikis/Downloads). You'll need version 5.00 or newer.
+2. Additionally, you need to install these packages:
+  * For Debian based systems: `python-nautilus`
+  * For Red Hat based systems: `nautilus-python`
+3. Download the project files
+4. As root: `cp clamtk-gnome.py /usr/share/nautilus-python/extensions/`
+5. Restart Nautilus
+
+
+## Usage and screenshots
+
+1. Bring up the context menu either by
+   1. right clicking on a directory:
+   
+   ![starting scan alt 1](_img/starting_scan_alt1.png)
+   
+   2. Or by clicking here:
+   
+   ![starting scan alt 2](_img/starting_scan_alt2.png)
+
+2. Click on the scan button
+
+3. Wait for the scan to complete (pleate note that it may take a couple of seconds for the scan to start and also for the "No threats found" message to be shown at the end - even after the message "Scanning completed" has been shown)
+![scan result](_img/scan_result.png)
+
+
+## Dependencies
+
+* `clamtk` >= 5.00
+* On Debian based systems: `python-nautilus`
+* On Red Hat based systems: `nautilus-python`
+
+## Links
+
+* https://gitlab.com/dave_m/clamtk-gnome
+* https://bitbucket.org/davem_/clamtk-gnome
+* http://standards.freedesktop.org/desktop-entry-spec/latest/
+* http://code.google.com/p/clamtk/ (no longer used)
+* http://dave-theunsub.github.io/clamtk/ (deprecated)
+* https://github.com/dave-theunsub/clamtk-gnome (deprecated)
+
+## Contact
+
+* Dave M, dave.nerd at gmail
+* Tord D, tord.dellsen at gmail
diff -pruN 6.02-1/clamtk-gnome-0-03/CHANGES 6.03-1/clamtk-gnome-0-03/CHANGES
--- 6.02-1/clamtk-gnome-0-03/CHANGES	2019-04-12 13:59:15.000000000 +0000
+++ 6.03-1/clamtk-gnome-0-03/CHANGES	1970-01-01 00:00:00.000000000 +0000
@@ -1,19 +0,0 @@
-CHANGELOG for clamtk-gnome:
-
-0.03 - 20190412
----------------
-    * Allow for python3.
-
-0.02 - 20170907
----------------
-    * Fix README file, which has incorrect instructions for
-      manually installing it.
-    * Make build for CentOS 7, now possible with the
-      nautilus-python rpm in EPEL.
-    * Python file has been renamed to clamtk-gnome.py.
-    * Use xz compression.
-    * Change Python interpreter from /usr/bin/env.
-
-0.01 - 20150906
----------------
-    * Initial release.
Binary files 6.02-1/clamtk-gnome-0-03/clamtk-gnome.1.gz and 6.03-1/clamtk-gnome-0-03/clamtk-gnome.1.gz differ
diff -pruN 6.02-1/clamtk-gnome-0-03/clamtk-gnome.py 6.03-1/clamtk-gnome-0-03/clamtk-gnome.py
--- 6.02-1/clamtk-gnome-0-03/clamtk-gnome.py	2019-04-13 19:39:36.000000000 +0000
+++ 6.03-1/clamtk-gnome-0-03/clamtk-gnome.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,82 +0,0 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
-# ClamTk, copyright (C) 2004-2019 Dave M, Tord Dellsén
-#
-# This file is part of ClamTk
-# (https://gitlab.com/dave_m/clamtk/wikis/Home)
-#
-# ClamTk is free software; you can redistribute it and/or modify it
-# under the terms of either:
-#
-# a) the GNU General Public License as published by the Free Software
-# Foundation; either version 1, or (at your option) any later version, or
-#
-# b) the "Artistic License".
-
-import os
-try:
-    # Python 3
-    from shlex import quote
-except ImportError:
-    # Python 2
-    from pipes import quote
-import locale
-locale.setlocale(locale.LC_ALL, '')
-
-import gettext
-_ = lambda x: gettext.ldgettext("clamtk-gnome", x)
-
-from gi.repository import Nautilus, GObject
-
-
-class OpenTerminalExtension(GObject.GObject, Nautilus.MenuProvider):
-    def __init__(self):
-        print("Initializing clamtk-gnome")
-
-    def _open_scanner(self, file):
-        filename = file.get_location().get_path()
-        # - file is of type nautiuls-vsf-file
-        # https://github.com/GNOME/nautilus/blob/master/src/nautilus-file.h
-        # which inherits from nautilus-file
-        # https://github.com/GNOME/nautilus/blob/master/src/nautilus-vfs-file.h
-        # - get_location returns a GFile
-        # https://developer.gnome.org/gio/stable/GFile.html
-        # which has the get_path function which returns the absolute path as a string
-
-        filename = quote(filename)
-
-        os.system('clamtk %s &' % filename)
-
-    def menu_activate_cb(self, menu, file):
-        self._open_scanner(file)
-
-    def menu_background_activate_cb(self, menu, file):
-        self._open_scanner(file)
-
-    def get_file_items(self, window, files):
-        if len(files) != 1:
-            return
-        file = files[0]
-
-        item = Nautilus.MenuItem(
-            name='NautilusPython::openscanner',
-            label=_('Scan for threats...') ,
-            tip=_('Scan %s for threats...') % file.get_name(),
-            icon='clamtk')
-        # - the tooltips are not shown any longer in Nautilus
-        # (the code is kept here in case this changes again for Nautilus
-        item.connect('activate', self.menu_activate_cb, file)
-
-        return [item]
-
-    def get_background_items(self, window, file):
-        item = Nautilus.MenuItem(
-            name='NautilusPython::openscanner_directory',
-            label=_('Scan directory for threats...'),
-            tip=_('Scan this directory for threats...'),
-            icon='clamtk')
-        # - the tooltips are not shown any longer in Nautilus
-        # (the code is kept here in case this changes again for Nautilus
-        item.connect('activate', self.menu_background_activate_cb, file)
-
-        return [item]
diff -pruN 6.02-1/clamtk-gnome-0-03/DISCLAIMER 6.03-1/clamtk-gnome-0-03/DISCLAIMER
--- 6.02-1/clamtk-gnome-0-03/DISCLAIMER	2016-08-06 09:15:13.000000000 +0000
+++ 6.03-1/clamtk-gnome-0-03/DISCLAIMER	1970-01-01 00:00:00.000000000 +0000
@@ -1,14 +0,0 @@
-This software (ClamTk and clamtk-gnome) is provided 'as is' without
-warranty of any kind, either expressed or implied, including,
-but not limited to, the implied warranties of fitness for a
-purpose, or the warranty of non-infringement.
-
-Without limiting the foregoing, there is no warranty that:
-
-   1. the software will meet your requirements
-   2. the software will be uninterrupted, timely, secure or error-free
-   3. the results that may be obtained from the use of the software will
-      be effective, accurate or reliable
-   4. the quality of the software will meet your expectations
-
-Having said that, I do my best to make it as good as I can. Really.
Binary files 6.02-1/clamtk-gnome-0-03/images/clamtk-gnome.png and 6.03-1/clamtk-gnome-0-03/images/clamtk-gnome.png differ
diff -pruN 6.02-1/clamtk-gnome-0-03/LICENSE 6.03-1/clamtk-gnome-0-03/LICENSE
--- 6.02-1/clamtk-gnome-0-03/LICENSE	2019-04-12 13:46:14.000000000 +0000
+++ 6.03-1/clamtk-gnome-0-03/LICENSE	1970-01-01 00:00:00.000000000 +0000
@@ -1,25 +0,0 @@
-COPYRIGHT AND LICENCE
-
-ClamTk, copyright (C) 2004-2019 Dave M, Tord Dellsén
-https://gitlab.com/dave_m/clamtk-gnome
-https://bitbucket.org/davem_/clamtk-gnome/
-
-No longer used:
-http://code.google.com/p/clamtk/
-http://freshmeat.net/projects/clamtk
-http://clamtk.sourceforge.net
-
-Deprecated:
-https://github.com/dave-theunsub/clamtk
-
-Dave M <dave.nerd at gmail>
-0x6ADA59DE
-
-All rights reserved.  This program is free software; you can
-redistribute it and/or modify it under the terms of either:
-
-a) the GNU General Public License as published by the Free
-Software Foundation; either version 1, or (at your option)
-any later version, or
-
-b) the "Artistic License".
diff -pruN 6.02-1/clamtk-gnome-0-03/README.md 6.03-1/clamtk-gnome-0-03/README.md
--- 6.02-1/clamtk-gnome-0-03/README.md	2019-04-07 13:44:43.000000000 +0000
+++ 6.03-1/clamtk-gnome-0-03/README.md	1970-01-01 00:00:00.000000000 +0000
@@ -1,83 +0,0 @@
-This readme file was last updated 2019 04 07
-
-# README for clamtk-gnome
-
-clamtk-gnome is a simple plugin for
-[ClamTk](https://github.com/dave-theunsub/clamtk) to allow a right-click, context menu scan of files or folders in the Nautilus file manager.
-
-
-## Installation
-
-This section gives different options for installing ClamTk Gnome
-
-Please note that you may need to add `sudo` before the installation commands for Ubuntu and Debian-based systems
-
-### Option A (for Ubuntu and Debian-based systems): Installation from official repo
-
-`apt-get install clamtk-gnome`
-
-### Option B: Installation from downloaded package
-
-There are deb and rpm packages to install this plugin:
-
-#### On Debian based systems (Ubuntu etc)
-
-`dpkg -i clamtk-gnome_0.03-1_all.deb`
-
-`apt-get install -f`
-
-#### On CentOS systems
-
-`yum install clamtk-gnome-0.03-1.fc.noarch.rpm`
-
-#### On Fedora systems
-
-`dnf install clamtk-gnome-0.03-1.fc.noarch.rpm`
-
-### Option C: Manual installation
-
-1. Install [ClamTk](https://gitlab.com/dave_m/clamtk/wikis/Downloads). You'll need version 5.00 or newer.
-2. Additionally, you need to install these packages:
-  * For Debian based systems: `python-nautilus`
-  * For Red Hat based systems: `nautilus-python`
-3. Download the project files
-4. As root run `cp clamtk-gnome.py /usr/share/nautilus-python/extensions/`
-5. Restart Nautilus
-
-
-## Usage and screenshots
-
-1. Bring up the context menu either by
-   1. right clicking on a directory:
-   
-   ![starting scan alt 1](_img/starting_scan_alt1.png)
-   
-   2. Or by clicking here:
-   
-   ![starting scan alt 2](_img/starting_scan_alt2.png)
-
-2. Click on the scan button
-
-3. Wait for the scan to complete (pleate note that it may take a couple of seconds for the scan to start and also for the "No threats found" message to be shown at the end - even after the message "Scanning completed" has been shown)
-![scan result](_img/scan_result.png)
-
-
-## Dependencies
-
-* `clamtk` >= 5.00
-* On Debian based systems: `python-nautilus`
-* On Red Hat based systems: `nautilus-python`
-
-## Links
-
-* https://gitlab.com/dave_m/clamtk-gnome
-* https://bitbucket.org/davem_/clamtk-gnome
-* http://standards.freedesktop.org/desktop-entry-spec/latest/
-* http://code.google.com/p/clamtk/ (no longer used)
-* http://dave-theunsub.github.io/clamtk/ (deprecated)
-* https://github.com/dave-theunsub/clamtk-gnome (deprecated)
-
-## Contact
-
-* Dave M, dave.nerd at gmail
-* Tord D, tord.dellsen at gmail
diff -pruN 6.02-1/clamtk-kde/CHANGES 6.03-1/clamtk-kde/CHANGES
--- 6.02-1/clamtk-kde/CHANGES	1970-01-01 00:00:00.000000000 +0000
+++ 6.03-1/clamtk-kde/CHANGES	2017-09-24 08:26:57.000000000 +0000
@@ -0,0 +1,97 @@
+Changelog for clamtk-kde
+------------------------
+
+0.18:   29 Sep 2017
+-------------------
+        * Updated links, README.md
+        * Updated strings: Afrikaans (af), Catalan (ca), Basque (eu),
+            Khmer (km), Lithuanian (lt), Punjabi (pa)
+        * Updated man pages (links, etc)
+        * Change compression to xz
+
+0.17:   27 Aug 2016
+-------------------
+        * Update to KDE 5 (Github #62)
+        * Update man pages with correct bug-reporting URL
+        * Updated strings: Romanian (ro), English (en_AU),
+          Italian (it), Korean (ko_KR)
+
+0.16:   15 Mar 2014
+-------------------
+        * Cleaned up desktop file - things like removing
+          deprecated Encoding line from desktop file.
+        * Updated strings: Dutch (nl), Czech (cs), Punjabi (pa),
+          Serbian Latin (sr@latin), Marathi (mr), Brazilian
+          Portuguese (pt_BR), Portuguese (pt), French (fr),
+          Malay (ms), probably others
+        * Update years -> 2014.
+
+0.15:   10 Nov 2013
+-------------------
+        * All files updated, including Requires to kde-filesystem.
+
+0.14:
+-------------------
+    * Added Dutch (nl_BE) and Greek (el_GR) language support.
+    * Updated .desktop file.
+    * Updated rpm file.
+
+0.13:
+-------------------
+    * Added Turkish (tr_TR) language file.
+
+0.12:
+-------------------
+    * Added Slovak (sk_SK) language file.
+
+0.11:
+-------------------
+    * Added Japanese (ja_JP) language file.
+
+0.10:
+-------------------
+    * Added Dutch (nl_NL) language file.
+
+0.09:
+-------------------
+    * Added Romanian (ro_RO) to the .desktop file.
+
+0.08:
+-------------------
+    * Added Slovene (sl_SI) to the .desktop file.
+
+0.07:
+-------------------
+    * Added Galician (gl_ES) to the .desktop file.
+
+0.06:
+-------------------
+    * Added Swedish to the .desktop file.
+
+0.05:
+-------------------
+    * Added Czech to the .desktop file and fixed formatting.
+    * Added new ClamTk logo image.
+
+0.04:
+-------------------
+    * Added several translations to the .desktop file.
+
+0.03:
+-------------------
+    * Added Danish and Italian to the .desktop file.
+    * The .deb was returned to "all", as opposed to i386.
+    * Minor fix in the .spec file.
+
+0.02:
+-------------------
+    * Language support was added.
+    * The .desktop entry file was improved.
+    * The rpm .spec file was cleaned up. The rpm should work for
+        FC3, FC4, and FC5.
+    * The rpm is now noarch.
+    * Added a manpage.
+
+0.01:
+-------------------
+    * Initial release.
Binary files 6.02-1/clamtk-kde/clamtk-kde.1.gz and 6.03-1/clamtk-kde/clamtk-kde.1.gz differ
diff -pruN 6.02-1/clamtk-kde/clamtk-kde.desktop 6.03-1/clamtk-kde/clamtk-kde.desktop
--- 6.02-1/clamtk-kde/clamtk-kde.desktop	1970-01-01 00:00:00.000000000 +0000
+++ 6.03-1/clamtk-kde/clamtk-kde.desktop	2017-09-24 06:30:54.000000000 +0000
@@ -0,0 +1,65 @@
+[Desktop Entry]
+Name=clamtk
+Exec=clamtk %F
+Type=Service
+ServiceTypes=KonqPopupMenu/Plugin
+MimeType=inode/directory;application/octet-stream;
+X-KDE-StartupNotify=true;
+Actions=openScanner;
+
+[Desktop Action openScanner]
+Icon=clamtk
+Exec=clamtk %F
+Name=Scan for threats...
+Name[af]=Skandeer vir virusse...
+Name[ar]=إمسح للكشف عن الفيروسات
+Name[ast]=Buscar amenaces...
+Name[az]=Təhlükə mövcudluğuna yoxla...
+Name[bg]=Проверка за наличие на заплахи ...
+Name[bs]=Pretraga za virusima...
+Name[ca]=Escaneja
+Name[cs]=Skenování hrozeb...
+Name[da]=Skan for virus...
+Name[de]=Auf Bedrohungen untersuchen…
+Name[el]=Έλεγχος για ιούς...
+Name[en]=Scan for threats...
+Name[en_AU]=Scan for threats...
+Name[en_CA]=Scan for threats...
+Name[en_GB]=Scan for threats...
+Name[es]=Analizar en busca de amenazas…
+Name[eu]=Eskaneatu birusen bila...
+Name[fi]=Tarkista uhkien varalta...
+Name[fo]=Skanna eftir virus...
+Name[fr]=Rechercher des menaces...
+Name[gl]=Buscar ameazas...
+Name[he]=סריקה לאיתור איומים…
+Name[hr]=Pretraživanje virusa...
+Name[hu]=Vírusok keresése...
+Name[id]=Pindai untuk ancaman...
+Name[it]=Analizza per la ricerca di minacce...
+Name[ja]=ウィルスをスキャンします...
+Name[km]=វិភាគរកការគំរាមកំហៃង...
+Name[ko]=위험 요소를 검사합니다...
+Name[lt]=Ieškoti virusų...
+Name[ms]=Imbas jika ada ancaman...
+Name[nl]=Scannen op virussen…
+Name[nb]=Skann etter virus...
+Name[nl_BE]=Scannen...
+Name[nn]=Skann...
+Name[pa]=ਧਮਕਿਯਾੰ ਲਈ ਖੋਜ ਕਰੋ
+Name[pl]=Przeskanuj pliki w poszukiwaniu wirusów...
+Name[pt]=A analizar ameaças...
+Name[pt_BR]=Verificar se há vírus...
+Name[ro]=Scanare pentru amenințări...
+Name[ru]=Проверка на наличие угроз...
+Name[sk]=Skenovanie hrozieb...
+Name[sl]=Preglej za virusi...
+Name[sr@latin]=Skeniranje pretnji...
+Name[sv]=Skanna efter virus...
+Name[te]=వైరస్సుల కోసం సంశోధిస్తున్నది...
+Name[tr]=Virüs taraması yap...
+Name[ug]=ۋىرۇس تەكشۈر…
+Name[uk]=Шукати загрози…
+Name[uz]=Хавф учун текшириш...
+Name[zh_CN]=扫描威胁...
+Name[zh_TW]=掃描威脅...
Binary files 6.02-1/clamtk-kde/clamtk-kde.png and 6.03-1/clamtk-kde/clamtk-kde.png differ
diff -pruN 6.02-1/clamtk-kde/clamtk-kde.xpm 6.03-1/clamtk-kde/clamtk-kde.xpm
--- 6.02-1/clamtk-kde/clamtk-kde.xpm	1970-01-01 00:00:00.000000000 +0000
+++ 6.03-1/clamtk-kde/clamtk-kde.xpm	2014-03-15 15:10:10.000000000 +0000
@@ -0,0 +1,290 @@
+/* XPM */
+static char * clamtk_xpm[] = {
+"32 32 255 2",
+"  	c None",
+". 	c #FF0000",
+"+ 	c #676966",
+"@ 	c #676965",
+"# 	c #B63331",
+"$ 	c #FE0101",
+"% 	c #E70E0D",
+"& 	c #646662",
+"* 	c #787A76",
+"= 	c #A3A59E",
+"- 	c #B9BDB6",
+"; 	c #D68C87",
+"> 	c #FF0201",
+", 	c #D8615D",
+"' 	c #A1A59F",
+") 	c #777975",
+"! 	c #686A64",
+"~ 	c #F00908",
+"{ 	c #6E706D",
+"] 	c #BCBFB7",
+"^ 	c #CBCFC7",
+"/ 	c #C7CAC4",
+"( 	c #CCC9C2",
+"_ 	c #F91A19",
+": 	c #ED4D4A",
+"< 	c #CFD3CB",
+"[ 	c #D0D3CC",
+"} 	c #D0D4CC",
+"| 	c #CED2CA",
+"1 	c #E72423",
+"2 	c #C22A29",
+"3 	c #787A74",
+"4 	c #C7CAC3",
+"5 	c #C9CDC5",
+"6 	c #C3C6BF",
+"7 	c #C2C5BE",
+"8 	c #DE8883",
+"9 	c #FE0404",
+"0 	c #D2BDB5",
+"a 	c #D9AEA7",
+"b 	c #CFB5AF",
+"c 	c #727471",
+"d 	c #686A66",
+"e 	c #C4C8C0",
+"f 	c #C8CCC4",
+"g 	c #C3C5BE",
+"h 	c #CACEC6",
+"i 	c #EC4B48",
+"j 	c #F23634",
+"k 	c #CDD0C9",
+"l 	c #CDD1C9",
+"m 	c #D1D5CD",
+"n 	c #7D817B",
+"o 	c #656863",
+"p 	c #A9ABA5",
+"q 	c #C6CAC2",
+"r 	c #D29A94",
+"s 	c #E25B58",
+"t 	c #E65F5C",
+"u 	c #E6605C",
+"v 	c #F91515",
+"w 	c #F22826",
+"x 	c #E55E5B",
+"y 	c #E8615E",
+"z 	c #E56C68",
+"A 	c #D0C7C0",
+"B 	c #D4C3BC",
+"C 	c #BC3634",
+"D 	c #ED0A08",
+"E 	c #6D706B",
+"F 	c #C5C8C1",
+"G 	c #C5C8C2",
+"H 	c #DB6B67",
+"I 	c #F42827",
+"J 	c #F42927",
+"K 	c #FC0808",
+"L 	c #FA1212",
+"M 	c #F52928",
+"N 	c #F52A28",
+"O 	c #F42F2E",
+"P 	c #D2B6AF",
+"Q 	c #F32B29",
+"R 	c #E61111",
+"S 	c #9C9E98",
+"T 	c #BFC3BB",
+"U 	c #C2C6BF",
+"V 	c #C7CBC3",
+"W 	c #C0C4BC",
+"X 	c #EC3E3C",
+"Y 	c #EE4240",
+"Z 	c #C4C8C1",
+"` 	c #90938D",
+" .	c #656964",
+"..	c #C0C3BC",
+"+.	c #C3C7BF",
+"@.	c #BDC1B9",
+"#.	c #C6C9C2",
+"$.	c #C1C5BD",
+"%.	c #C1C5BC",
+"&.	c #E0746F",
+"*.	c #FC0B0B",
+"=.	c #CCC4BD",
+"-.	c #CCD0C8",
+";.	c #D2BDB6",
+">.	c #D1C6BF",
+",.	c #C8CBC4",
+"'.	c #7B5C58",
+").	c #6C6F69",
+"!.	c #BFC3BC",
+"~.	c #C3C7C0",
+"{.	c #BDC0BA",
+"].	c #CBBBB4",
+"^.	c #E36360",
+"/.	c #BFC2BB",
+"(.	c #F13B39",
+"_.	c #E56460",
+":.	c #CC2827",
+"<.	c #81847E",
+"[.	c #BCBFB8",
+"}.	c #C2C5BF",
+"|.	c #C4C7C0",
+"1.	c #BDC0B8",
+"2.	c #DF6E6A",
+"3.	c #FE0202",
+"4.	c #D8918A",
+"5.	c #CACDC6",
+"6.	c #F22F2D",
+"7.	c #E65754",
+"8.	c #E2827D",
+"9.	c #949792",
+"0.	c #C0C2BC",
+"a.	c #C0C3BD",
+"b.	c #C5C9C1",
+"c.	c #BDBFB8",
+"d.	c #E84F4C",
+"e.	c #E26D69",
+"f.	c #CBC7C1",
+"g.	c #C7CBC4",
+"h.	c #F02D2B",
+"i.	c #E95B57",
+"j.	c #E8615D",
+"k.	c #FF0101",
+"l.	c #D35350",
+"m.	c #A3A59F",
+"n.	c #BDC0B9",
+"o.	c #C0C5BC",
+"p.	c #E0726D",
+"q.	c #FC0A0A",
+"r.	c #FB100F",
+"s.	c #E84744",
+"t.	c #F91817",
+"u.	c #F42E2C",
+"v.	c #EE4643",
+"w.	c #FC0C0C",
+"x.	c #FB1010",
+"y.	c #E08681",
+"z.	c #A9ADA6",
+"A.	c #656661",
+"B.	c #ABAEA8",
+"C.	c #C0C4BB",
+"D.	c #BEC1BA",
+"E.	c #C2C6BE",
+"F.	c #CAB7B0",
+"G.	c #DB6965",
+"H.	c #F13532",
+"I.	c #FD0707",
+"J.	c #FC0E0D",
+"K.	c #F13A37",
+"L.	c #E27873",
+"M.	c #CABFB8",
+"N.	c #C6C9C3",
+"O.	c #636762",
+"P.	c #B0B3AC",
+"Q.	c #BBBEB7",
+"R.	c #BEC1BB",
+"S.	c #C1C4BD",
+"T.	c #C3C6C0",
+"U.	c #F32F2E",
+"V.	c #E85956",
+"W.	c #8C8E89",
+"X.	c #656764",
+"Y.	c #B4B5AF",
+"Z.	c #BBBFB8",
+"`.	c #C0C3BB",
+" +	c #BEC2BA",
+".+	c #E75956",
+"++	c #C6C8C1",
+"@+	c #6E706B",
+"#+	c #646560",
+"$+	c #B3B6AF",
+"%+	c #BBBEB8",
+"&+	c #BDC1BA",
+"*+	c #BFC2BC",
+"=+	c #E45552",
+"-+	c #C0C4BD",
+";+	c #CBCEC7",
+">+	c #ABAFA8",
+",+	c #626360",
+"'+	c #676864",
+")+	c #848681",
+"!+	c #767773",
+"~+	c #B0B4AD",
+"{+	c #BBBFB7",
+"]+	c #DA6F6B",
+"^+	c #D58F8A",
+"/+	c #5F635E",
+"(+	c #8F938C",
+"_+	c #787B76",
+":+	c #B0B2AC",
+"<+	c #BBBDB6",
+"[+	c #BDBFB9",
+"}+	c #BABEB6",
+"|+	c #6B6D69",
+"1+	c #5F625D",
+"2+	c #727570",
+"3+	c #ACAFA8",
+"4+	c #BABDB7",
+"5+	c #BCBEB7",
+"6+	c #C0C2BB",
+"7+	c #BCBFB9",
+"8+	c #969993",
+"9+	c #646762",
+"0+	c #5B5E58",
+"a+	c #7E827B",
+"b+	c #BABDB6",
+"c+	c #BBBEB6",
+"d+	c #C1C3BD",
+"e+	c #ACAFA9",
+"f+	c #888B85",
+"g+	c #7F817C",
+"h+	c #ADAFA9",
+"i+	c #B6B8B1",
+"j+	c #B7BAB3",
+"k+	c #B6B9B2",
+"l+	c #B5B7B1",
+"m+	c #A8ABA5",
+"n+	c #9FA19C",
+"o+	c #959892",
+"p+	c #858781",
+"q+	c #70726C",
+"r+	c #666865",
+"s+	c #5A5A57",
+"t+	c #6D6F6B",
+"u+	c #6E706C",
+"v+	c #6A6C68",
+"w+	c #626561",
+"x+	c #646661",
+"y+	c #62645E",
+"z+	c #5D5F5B",
+"A+	c #8C908A",
+"B+	c #6D6F69",
+"C+	c #616360",
+"D+	c #636561",
+"E+	c #6E6E6A",
+"F+	c #808080",
+"                                                                ",
+"                                      . .                       ",
+"                                      . .                       ",
+"                                      . .                       ",
+"                                    . . .                       ",
+"                                . . . . . . . .                 ",
+"                        + @ # $ %     . .     . .               ",
+"                  & * = - ; > , ' ) ! ~ .       . .             ",
+"                { ] ^ / ( _ : < [ } | 1 2         . .           ",
+"              3 4 5 6 7 8 9 0 | < [ } a b c         .           ",
+"            d e f g g h i j k l | < [ } m } n       . .         ",
+"          o p q r s t u v w x y z A < [ } m B C D . . . . . .   ",
+"          E F G H I J J K L M N O P | < } } a Q R . . . . . .   ",
+"          S e T U q V W X Y h ^ F Z l | < } } m `   . .         ",
+"         ...+.@.F #.$.%.&.*.=.F $.-.k ;.>.< } } ,.'..           ",
+"        ).7 !.W e ~.{.#.].*.^./.h ^ -.(._.| < } } :..           ",
+"        <.$.[.}.|.1.|.#.4 2.3.4.5.h ^ 6.7.l | < 8..             ",
+"        9.0.@.7 !.a.e b.b.c.d.9 e.f.g.h.i.l A j.k.l.            ",
+"        m.n.0.o.n.6 |.e {.|.4 p.q.r.s.t.u.v.w.x.y.z.            ",
+"      A.B.[...n.C.7 6 D.E.b.#.4 F.G.H.I.J.K.L.M.N.z.            ",
+"      O.P.Q.R.[.S.$.D...|.e b.T.D.q f U.V.h f ..l W.            ",
+"      X.Y.Z.] R...D.@.E.6 |.`. +b.4 V 6..+++`.h -.@+            ",
+"      #+$+Z.%+ +D.c.S.$.E.&+*+e b.q 4 6.=+-+5.;+>+,+            ",
+"  '+)+!+~+Q.[.{.{+/...`.[.W 6 |.F b.E.]+^+f 5 ..@               ",
+"  /+(+_+:+<+Q.<+&+ +[+c.a.7 E.E...n.S.b.4 ,.}+|+                ",
+"    1+2+3+<+4+] 5+Q.@./.6+R.7+n...6 F b.+.8+9+                  ",
+"      0+a+b+}+c+Q.[.5+] [.D.d+7 E.}.e+f++                       ",
+"        1+g+h+i+j+k+l+P.m+n+o+p+q+r+O.                          ",
+"          s+t+u+v+w+9+x+y+                                      ",
+"            z+A+B+                                              ",
+"              C+D+                                              ",
+"                E+      F+F+F+F+F+F+F+                          "};
diff -pruN 6.02-1/clamtk-kde/LICENSE 6.03-1/clamtk-kde/LICENSE
--- 6.02-1/clamtk-kde/LICENSE	1970-01-01 00:00:00.000000000 +0000
+++ 6.03-1/clamtk-kde/LICENSE	2017-09-23 06:20:29.000000000 +0000
@@ -0,0 +1,37 @@
+COPYRIGHT AND LICENCE
+
+ClamTk and ClamTk-KDE, copyright (C) 2004-2017 Dave M
+
+### Links
+
+https://github.com/dave-theunsub/clamtk-kde
+https://github.com/dave-theunsub/clamtk/
+https://bitbucket.org/davem_/clamtk/
+https://github.com/dave-theunsub/clamtk
+https://bitbucket.org/davem_/clamtk-gnome/
+
+### Older links
+
+http://freshmeat.net/projects/clamtk
+http://clamtk.sourceforge.net
+http://code.google.com/p/clamtk/
+<dave.nerd AT gmail.com>
+
+### License
+
+All rights reserved.  This program is free software; you can
+redistribute it and/or modify it under the same terms as Perl itself.
+
+This software (ClamTk and ClamTk-KDE) is provided 'as is' without warranty
+of any kind, either express or implied, including, but not limited to, the
+implied warranties of fitness for a purpose, or the warranty of
+non-infringement.  Without limiting the foregoing, there is no warranty that:
+
+   1. the software will meet your requirements
+   2. the software will be uninterrupted, timely, secure or error-free
+   3. the results that may be obtained from the use of the software will be
+effective, accurate or reliable
+   4. the quality of the software will meet your expectations
+
+Having said that, I do my best to make it as good as I can. Really.
+Dave M <dave.nerd @ gmail>
diff -pruN 6.02-1/clamtk-kde/README.md 6.03-1/clamtk-kde/README.md
--- 6.02-1/clamtk-kde/README.md	1970-01-01 00:00:00.000000000 +0000
+++ 6.03-1/clamtk-kde/README.md	2017-09-23 07:40:08.000000000 +0000
@@ -0,0 +1,68 @@
+This readme file was last updated 23 Sept 2017
+
+# README for clamtk-kde
+
+clamtk-kde is a simple plugin to allow a right-click,
+context menu scan of files or folders in Dolphin,
+a file manager in KDE.
+
+All this plugin does is copy a desktop file to a
+directory.  If this seems redundant, that's because it is:
+this plugin depends on clamtk, which already has this directory
+file. So, it stands to reason we should be able to just find that
+file and copy it, rather than having our own copy.
+
+## Installation
+
+### Automatic installation
+
+There are deb and rpm packages to install this plugin:
+
+#### On Debian based systems (Ubuntu etc)
+
+`sudo apt-get install clamtk-kde`
+
+or, if you've already downloaded it:
+
+`sudo dpkg -i clamtk-kde`
+
+#### On CentOS systems
+
+`yum install clamtk-kde-0.18-1.fc.noarch.rpm`
+
+#### On Fedora systems
+
+`dnf install clamtk-kde-0.18-1.fc.noarch.rpm`
+
+### Manual installation
+
+To manually install it:
+Ensure ClamTk is installed. You'll need version 4.00 or newer,
+but you should run at least the 5.xx series by now.
+
+Copy the clamtk-kde.desktop file to the services folder. For example:  
+For KDE 4:  
+`cp clamtk-kde.desktop /usr/share/kde4/services/`  
+For KDE 5:  
+`cp clamtk-kde.desktop /usr/share/kservices5/ServiceMenus/`  
+You will need to have root privileges for that step.  
+
+DEPENDENCIES
+------------
+
+clamtk >= 5.00
+(KDE4) kde-filesystem or (KDE5) kf5-filesystem
+
+LINKS
+-----
+
+https://github.com/dave-theunsub/clamtk/  
+https://bitbucket.org/davem_/clamtk-kde/  
+http://dolphin.kde.org  
+http://standards.freedesktop.org/desktop-entry-spec/latest/  
+
+CONTACT
+-------
+
+email : Dave M, dave.nerd @ gmail.com  
+0x6ADA59DE
diff -pruN 6.02-1/clamtk-kde-0-18/CHANGES 6.03-1/clamtk-kde-0-18/CHANGES
--- 6.02-1/clamtk-kde-0-18/CHANGES	2017-09-24 08:26:57.000000000 +0000
+++ 6.03-1/clamtk-kde-0-18/CHANGES	1970-01-01 00:00:00.000000000 +0000
@@ -1,97 +0,0 @@
-Changelog for clamtk-kde
-------------------------
-
-0.18:   29 Sep 2017
--------------------
-        * Updated links, README.md
-        * Updated strings: Afrikaans (af), Catalan (ca), Basque (eu),
-            Khmer (km), Lithuanian (lt), Punjabi (pa)
-        * Updated man pages (links, etc)
-        * Change compression to xz
-
-0.17:   27 Aug 2016
--------------------
-        * Update to KDE 5 (Github #62)
-        * Update man pages with correct bug-reporting URL
-        * Updated strings: Romanian (ro), English (en_AU),
-          Italian (it), Korean (ko_KR)
-
-0.16:   15 Mar 2014
--------------------
-        * Cleaned up desktop file - things like removing
-          deprecated Encoding line from desktop file.
-        * Updated strings: Dutch (nl), Czech (cs), Punjabi (pa),
-          Serbian Latin (sr@latin), Marathi (mr), Brazilian
-          Portuguese (pt_BR), Portuguese (pt), French (fr),
-          Malay (ms), probably others
-        * Update years -> 2014.
-
-0.15:   10 Nov 2013
--------------------
-        * All files updated, including Requires to kde-filesystem.
-
-0.14:
--------------------
-    * Added Dutch (nl_BE) and Greek (el_GR) language support.
-    * Updated .desktop file.
-    * Updated rpm file.
-
-0.13:
--------------------
-    * Added Turkish (tr_TR) language file.
-
-0.12:
--------------------
-    * Added Slovak (sk_SK) language file.
-
-0.11:
--------------------
-    * Added Japanese (ja_JP) language file.
-
-0.10:
--------------------
-    * Added Dutch (nl_NL) language file.
-
-0.09:
--------------------
-    * Added Romanian (ro_RO) to the .desktop file.
-
-0.08:
--------------------
-    * Added Slovene (sl_SI) to the .desktop file.
-
-0.07:
--------------------
-    * Added Galician (gl_ES) to the .desktop file.
-
-0.06:
--------------------
-    * Added Swedish to the .desktop file.
-
-0.05:
--------------------
-    * Added Czech to the .desktop file and fixed formatting.
-    * Added new ClamTk logo image.
-
-0.04:
--------------------
-    * Added several translations to the .desktop file.
-
-0.03:
--------------------
-    * Added Danish and Italian to the .desktop file.
-    * The .deb was returned to "all", as opposed to i386.
-    * Minor fix in the .spec file.
-
-0.02:
--------------------
-    * Language support was added.
-    * The .desktop entry file was improved.
-    * The rpm .spec file was cleaned up. The rpm should work for
-        FC3, FC4, and FC5.
-    * The rpm is now noarch.
-    * Added a manpage.
-
-0.01:
--------------------
-    * Initial release.
Binary files 6.02-1/clamtk-kde-0-18/clamtk-kde.1.gz and 6.03-1/clamtk-kde-0-18/clamtk-kde.1.gz differ
diff -pruN 6.02-1/clamtk-kde-0-18/clamtk-kde.desktop 6.03-1/clamtk-kde-0-18/clamtk-kde.desktop
--- 6.02-1/clamtk-kde-0-18/clamtk-kde.desktop	2017-09-24 06:30:54.000000000 +0000
+++ 6.03-1/clamtk-kde-0-18/clamtk-kde.desktop	1970-01-01 00:00:00.000000000 +0000
@@ -1,65 +0,0 @@
-[Desktop Entry]
-Name=clamtk
-Exec=clamtk %F
-Type=Service
-ServiceTypes=KonqPopupMenu/Plugin
-MimeType=inode/directory;application/octet-stream;
-X-KDE-StartupNotify=true;
-Actions=openScanner;
-
-[Desktop Action openScanner]
-Icon=clamtk
-Exec=clamtk %F
-Name=Scan for threats...
-Name[af]=Skandeer vir virusse...
-Name[ar]=إمسح للكشف عن الفيروسات
-Name[ast]=Buscar amenaces...
-Name[az]=Təhlükə mövcudluğuna yoxla...
-Name[bg]=Проверка за наличие на заплахи ...
-Name[bs]=Pretraga za virusima...
-Name[ca]=Escaneja
-Name[cs]=Skenování hrozeb...
-Name[da]=Skan for virus...
-Name[de]=Auf Bedrohungen untersuchen…
-Name[el]=Έλεγχος για ιούς...
-Name[en]=Scan for threats...
-Name[en_AU]=Scan for threats...
-Name[en_CA]=Scan for threats...
-Name[en_GB]=Scan for threats...
-Name[es]=Analizar en busca de amenazas…
-Name[eu]=Eskaneatu birusen bila...
-Name[fi]=Tarkista uhkien varalta...
-Name[fo]=Skanna eftir virus...
-Name[fr]=Rechercher des menaces...
-Name[gl]=Buscar ameazas...
-Name[he]=סריקה לאיתור איומים…
-Name[hr]=Pretraživanje virusa...
-Name[hu]=Vírusok keresése...
-Name[id]=Pindai untuk ancaman...
-Name[it]=Analizza per la ricerca di minacce...
-Name[ja]=ウィルスをスキャンします...
-Name[km]=វិភាគរកការគំរាមកំហៃង...
-Name[ko]=위험 요소를 검사합니다...
-Name[lt]=Ieškoti virusų...
-Name[ms]=Imbas jika ada ancaman...
-Name[nl]=Scannen op virussen…
-Name[nb]=Skann etter virus...
-Name[nl_BE]=Scannen...
-Name[nn]=Skann...
-Name[pa]=ਧਮਕਿਯਾੰ ਲਈ ਖੋਜ ਕਰੋ
-Name[pl]=Przeskanuj pliki w poszukiwaniu wirusów...
-Name[pt]=A analizar ameaças...
-Name[pt_BR]=Verificar se há vírus...
-Name[ro]=Scanare pentru amenințări...
-Name[ru]=Проверка на наличие угроз...
-Name[sk]=Skenovanie hrozieb...
-Name[sl]=Preglej za virusi...
-Name[sr@latin]=Skeniranje pretnji...
-Name[sv]=Skanna efter virus...
-Name[te]=వైరస్సుల కోసం సంశోధిస్తున్నది...
-Name[tr]=Virüs taraması yap...
-Name[ug]=ۋىرۇس تەكشۈر…
-Name[uk]=Шукати загрози…
-Name[uz]=Хавф учун текшириш...
-Name[zh_CN]=扫描威胁...
-Name[zh_TW]=掃描威脅...
Binary files 6.02-1/clamtk-kde-0-18/clamtk-kde.png and 6.03-1/clamtk-kde-0-18/clamtk-kde.png differ
diff -pruN 6.02-1/clamtk-kde-0-18/clamtk-kde.xpm 6.03-1/clamtk-kde-0-18/clamtk-kde.xpm
--- 6.02-1/clamtk-kde-0-18/clamtk-kde.xpm	2014-03-15 15:10:10.000000000 +0000
+++ 6.03-1/clamtk-kde-0-18/clamtk-kde.xpm	1970-01-01 00:00:00.000000000 +0000
@@ -1,290 +0,0 @@
-/* XPM */
-static char * clamtk_xpm[] = {
-"32 32 255 2",
-"  	c None",
-". 	c #FF0000",
-"+ 	c #676966",
-"@ 	c #676965",
-"# 	c #B63331",
-"$ 	c #FE0101",
-"% 	c #E70E0D",
-"& 	c #646662",
-"* 	c #787A76",
-"= 	c #A3A59E",
-"- 	c #B9BDB6",
-"; 	c #D68C87",
-"> 	c #FF0201",
-", 	c #D8615D",
-"' 	c #A1A59F",
-") 	c #777975",
-"! 	c #686A64",
-"~ 	c #F00908",
-"{ 	c #6E706D",
-"] 	c #BCBFB7",
-"^ 	c #CBCFC7",
-"/ 	c #C7CAC4",
-"( 	c #CCC9C2",
-"_ 	c #F91A19",
-": 	c #ED4D4A",
-"< 	c #CFD3CB",
-"[ 	c #D0D3CC",
-"} 	c #D0D4CC",
-"| 	c #CED2CA",
-"1 	c #E72423",
-"2 	c #C22A29",
-"3 	c #787A74",
-"4 	c #C7CAC3",
-"5 	c #C9CDC5",
-"6 	c #C3C6BF",
-"7 	c #C2C5BE",
-"8 	c #DE8883",
-"9 	c #FE0404",
-"0 	c #D2BDB5",
-"a 	c #D9AEA7",
-"b 	c #CFB5AF",
-"c 	c #727471",
-"d 	c #686A66",
-"e 	c #C4C8C0",
-"f 	c #C8CCC4",
-"g 	c #C3C5BE",
-"h 	c #CACEC6",
-"i 	c #EC4B48",
-"j 	c #F23634",
-"k 	c #CDD0C9",
-"l 	c #CDD1C9",
-"m 	c #D1D5CD",
-"n 	c #7D817B",
-"o 	c #656863",
-"p 	c #A9ABA5",
-"q 	c #C6CAC2",
-"r 	c #D29A94",
-"s 	c #E25B58",
-"t 	c #E65F5C",
-"u 	c #E6605C",
-"v 	c #F91515",
-"w 	c #F22826",
-"x 	c #E55E5B",
-"y 	c #E8615E",
-"z 	c #E56C68",
-"A 	c #D0C7C0",
-"B 	c #D4C3BC",
-"C 	c #BC3634",
-"D 	c #ED0A08",
-"E 	c #6D706B",
-"F 	c #C5C8C1",
-"G 	c #C5C8C2",
-"H 	c #DB6B67",
-"I 	c #F42827",
-"J 	c #F42927",
-"K 	c #FC0808",
-"L 	c #FA1212",
-"M 	c #F52928",
-"N 	c #F52A28",
-"O 	c #F42F2E",
-"P 	c #D2B6AF",
-"Q 	c #F32B29",
-"R 	c #E61111",
-"S 	c #9C9E98",
-"T 	c #BFC3BB",
-"U 	c #C2C6BF",
-"V 	c #C7CBC3",
-"W 	c #C0C4BC",
-"X 	c #EC3E3C",
-"Y 	c #EE4240",
-"Z 	c #C4C8C1",
-"` 	c #90938D",
-" .	c #656964",
-"..	c #C0C3BC",
-"+.	c #C3C7BF",
-"@.	c #BDC1B9",
-"#.	c #C6C9C2",
-"$.	c #C1C5BD",
-"%.	c #C1C5BC",
-"&.	c #E0746F",
-"*.	c #FC0B0B",
-"=.	c #CCC4BD",
-"-.	c #CCD0C8",
-";.	c #D2BDB6",
-">.	c #D1C6BF",
-",.	c #C8CBC4",
-"'.	c #7B5C58",
-").	c #6C6F69",
-"!.	c #BFC3BC",
-"~.	c #C3C7C0",
-"{.	c #BDC0BA",
-"].	c #CBBBB4",
-"^.	c #E36360",
-"/.	c #BFC2BB",
-"(.	c #F13B39",
-"_.	c #E56460",
-":.	c #CC2827",
-"<.	c #81847E",
-"[.	c #BCBFB8",
-"}.	c #C2C5BF",
-"|.	c #C4C7C0",
-"1.	c #BDC0B8",
-"2.	c #DF6E6A",
-"3.	c #FE0202",
-"4.	c #D8918A",
-"5.	c #CACDC6",
-"6.	c #F22F2D",
-"7.	c #E65754",
-"8.	c #E2827D",
-"9.	c #949792",
-"0.	c #C0C2BC",
-"a.	c #C0C3BD",
-"b.	c #C5C9C1",
-"c.	c #BDBFB8",
-"d.	c #E84F4C",
-"e.	c #E26D69",
-"f.	c #CBC7C1",
-"g.	c #C7CBC4",
-"h.	c #F02D2B",
-"i.	c #E95B57",
-"j.	c #E8615D",
-"k.	c #FF0101",
-"l.	c #D35350",
-"m.	c #A3A59F",
-"n.	c #BDC0B9",
-"o.	c #C0C5BC",
-"p.	c #E0726D",
-"q.	c #FC0A0A",
-"r.	c #FB100F",
-"s.	c #E84744",
-"t.	c #F91817",
-"u.	c #F42E2C",
-"v.	c #EE4643",
-"w.	c #FC0C0C",
-"x.	c #FB1010",
-"y.	c #E08681",
-"z.	c #A9ADA6",
-"A.	c #656661",
-"B.	c #ABAEA8",
-"C.	c #C0C4BB",
-"D.	c #BEC1BA",
-"E.	c #C2C6BE",
-"F.	c #CAB7B0",
-"G.	c #DB6965",
-"H.	c #F13532",
-"I.	c #FD0707",
-"J.	c #FC0E0D",
-"K.	c #F13A37",
-"L.	c #E27873",
-"M.	c #CABFB8",
-"N.	c #C6C9C3",
-"O.	c #636762",
-"P.	c #B0B3AC",
-"Q.	c #BBBEB7",
-"R.	c #BEC1BB",
-"S.	c #C1C4BD",
-"T.	c #C3C6C0",
-"U.	c #F32F2E",
-"V.	c #E85956",
-"W.	c #8C8E89",
-"X.	c #656764",
-"Y.	c #B4B5AF",
-"Z.	c #BBBFB8",
-"`.	c #C0C3BB",
-" +	c #BEC2BA",
-".+	c #E75956",
-"++	c #C6C8C1",
-"@+	c #6E706B",
-"#+	c #646560",
-"$+	c #B3B6AF",
-"%+	c #BBBEB8",
-"&+	c #BDC1BA",
-"*+	c #BFC2BC",
-"=+	c #E45552",
-"-+	c #C0C4BD",
-";+	c #CBCEC7",
-">+	c #ABAFA8",
-",+	c #626360",
-"'+	c #676864",
-")+	c #848681",
-"!+	c #767773",
-"~+	c #B0B4AD",
-"{+	c #BBBFB7",
-"]+	c #DA6F6B",
-"^+	c #D58F8A",
-"/+	c #5F635E",
-"(+	c #8F938C",
-"_+	c #787B76",
-":+	c #B0B2AC",
-"<+	c #BBBDB6",
-"[+	c #BDBFB9",
-"}+	c #BABEB6",
-"|+	c #6B6D69",
-"1+	c #5F625D",
-"2+	c #727570",
-"3+	c #ACAFA8",
-"4+	c #BABDB7",
-"5+	c #BCBEB7",
-"6+	c #C0C2BB",
-"7+	c #BCBFB9",
-"8+	c #969993",
-"9+	c #646762",
-"0+	c #5B5E58",
-"a+	c #7E827B",
-"b+	c #BABDB6",
-"c+	c #BBBEB6",
-"d+	c #C1C3BD",
-"e+	c #ACAFA9",
-"f+	c #888B85",
-"g+	c #7F817C",
-"h+	c #ADAFA9",
-"i+	c #B6B8B1",
-"j+	c #B7BAB3",
-"k+	c #B6B9B2",
-"l+	c #B5B7B1",
-"m+	c #A8ABA5",
-"n+	c #9FA19C",
-"o+	c #959892",
-"p+	c #858781",
-"q+	c #70726C",
-"r+	c #666865",
-"s+	c #5A5A57",
-"t+	c #6D6F6B",
-"u+	c #6E706C",
-"v+	c #6A6C68",
-"w+	c #626561",
-"x+	c #646661",
-"y+	c #62645E",
-"z+	c #5D5F5B",
-"A+	c #8C908A",
-"B+	c #6D6F69",
-"C+	c #616360",
-"D+	c #636561",
-"E+	c #6E6E6A",
-"F+	c #808080",
-"                                                                ",
-"                                      . .                       ",
-"                                      . .                       ",
-"                                      . .                       ",
-"                                    . . .                       ",
-"                                . . . . . . . .                 ",
-"                        + @ # $ %     . .     . .               ",
-"                  & * = - ; > , ' ) ! ~ .       . .             ",
-"                { ] ^ / ( _ : < [ } | 1 2         . .           ",
-"              3 4 5 6 7 8 9 0 | < [ } a b c         .           ",
-"            d e f g g h i j k l | < [ } m } n       . .         ",
-"          o p q r s t u v w x y z A < [ } m B C D . . . . . .   ",
-"          E F G H I J J K L M N O P | < } } a Q R . . . . . .   ",
-"          S e T U q V W X Y h ^ F Z l | < } } m `   . .         ",
-"         ...+.@.F #.$.%.&.*.=.F $.-.k ;.>.< } } ,.'..           ",
-"        ).7 !.W e ~.{.#.].*.^./.h ^ -.(._.| < } } :..           ",
-"        <.$.[.}.|.1.|.#.4 2.3.4.5.h ^ 6.7.l | < 8..             ",
-"        9.0.@.7 !.a.e b.b.c.d.9 e.f.g.h.i.l A j.k.l.            ",
-"        m.n.0.o.n.6 |.e {.|.4 p.q.r.s.t.u.v.w.x.y.z.            ",
-"      A.B.[...n.C.7 6 D.E.b.#.4 F.G.H.I.J.K.L.M.N.z.            ",
-"      O.P.Q.R.[.S.$.D...|.e b.T.D.q f U.V.h f ..l W.            ",
-"      X.Y.Z.] R...D.@.E.6 |.`. +b.4 V 6..+++`.h -.@+            ",
-"      #+$+Z.%+ +D.c.S.$.E.&+*+e b.q 4 6.=+-+5.;+>+,+            ",
-"  '+)+!+~+Q.[.{.{+/...`.[.W 6 |.F b.E.]+^+f 5 ..@               ",
-"  /+(+_+:+<+Q.<+&+ +[+c.a.7 E.E...n.S.b.4 ,.}+|+                ",
-"    1+2+3+<+4+] 5+Q.@./.6+R.7+n...6 F b.+.8+9+                  ",
-"      0+a+b+}+c+Q.[.5+] [.D.d+7 E.}.e+f++                       ",
-"        1+g+h+i+j+k+l+P.m+n+o+p+q+r+O.                          ",
-"          s+t+u+v+w+9+x+y+                                      ",
-"            z+A+B+                                              ",
-"              C+D+                                              ",
-"                E+      F+F+F+F+F+F+F+                          "};
diff -pruN 6.02-1/clamtk-kde-0-18/LICENSE 6.03-1/clamtk-kde-0-18/LICENSE
--- 6.02-1/clamtk-kde-0-18/LICENSE	2017-09-23 06:20:29.000000000 +0000
+++ 6.03-1/clamtk-kde-0-18/LICENSE	1970-01-01 00:00:00.000000000 +0000
@@ -1,37 +0,0 @@
-COPYRIGHT AND LICENCE
-
-ClamTk and ClamTk-KDE, copyright (C) 2004-2017 Dave M
-
-### Links
-
-https://github.com/dave-theunsub/clamtk-kde
-https://github.com/dave-theunsub/clamtk/
-https://bitbucket.org/davem_/clamtk/
-https://github.com/dave-theunsub/clamtk
-https://bitbucket.org/davem_/clamtk-gnome/
-
-### Older links
-
-http://freshmeat.net/projects/clamtk
-http://clamtk.sourceforge.net
-http://code.google.com/p/clamtk/
-<dave.nerd AT gmail.com>
-
-### License
-
-All rights reserved.  This program is free software; you can
-redistribute it and/or modify it under the same terms as Perl itself.
-
-This software (ClamTk and ClamTk-KDE) is provided 'as is' without warranty
-of any kind, either express or implied, including, but not limited to, the
-implied warranties of fitness for a purpose, or the warranty of
-non-infringement.  Without limiting the foregoing, there is no warranty that:
-
-   1. the software will meet your requirements
-   2. the software will be uninterrupted, timely, secure or error-free
-   3. the results that may be obtained from the use of the software will be
-effective, accurate or reliable
-   4. the quality of the software will meet your expectations
-
-Having said that, I do my best to make it as good as I can. Really.
-Dave M <dave.nerd @ gmail>
diff -pruN 6.02-1/clamtk-kde-0-18/README.md 6.03-1/clamtk-kde-0-18/README.md
--- 6.02-1/clamtk-kde-0-18/README.md	2017-09-23 07:40:08.000000000 +0000
+++ 6.03-1/clamtk-kde-0-18/README.md	1970-01-01 00:00:00.000000000 +0000
@@ -1,68 +0,0 @@
-This readme file was last updated 23 Sept 2017
-
-# README for clamtk-kde
-
-clamtk-kde is a simple plugin to allow a right-click,
-context menu scan of files or folders in Dolphin,
-a file manager in KDE.
-
-All this plugin does is copy a desktop file to a
-directory.  If this seems redundant, that's because it is:
-this plugin depends on clamtk, which already has this directory
-file. So, it stands to reason we should be able to just find that
-file and copy it, rather than having our own copy.
-
-## Installation
-
-### Automatic installation
-
-There are deb and rpm packages to install this plugin:
-
-#### On Debian based systems (Ubuntu etc)
-
-`sudo apt-get install clamtk-kde`
-
-or, if you've already downloaded it:
-
-`sudo dpkg -i clamtk-kde`
-
-#### On CentOS systems
-
-`yum install clamtk-kde-0.18-1.fc.noarch.rpm`
-
-#### On Fedora systems
-
-`dnf install clamtk-kde-0.18-1.fc.noarch.rpm`
-
-### Manual installation
-
-To manually install it:
-Ensure ClamTk is installed. You'll need version 4.00 or newer,
-but you should run at least the 5.xx series by now.
-
-Copy the clamtk-kde.desktop file to the services folder. For example:  
-For KDE 4:  
-`cp clamtk-kde.desktop /usr/share/kde4/services/`  
-For KDE 5:  
-`cp clamtk-kde.desktop /usr/share/kservices5/ServiceMenus/`  
-You will need to have root privileges for that step.  
-
-DEPENDENCIES
-------------
-
-clamtk >= 5.00
-(KDE4) kde-filesystem or (KDE5) kf5-filesystem
-
-LINKS
------
-
-https://github.com/dave-theunsub/clamtk/  
-https://bitbucket.org/davem_/clamtk-kde/  
-http://dolphin.kde.org  
-http://standards.freedesktop.org/desktop-entry-spec/latest/  
-
-CONTACT
--------
-
-email : Dave M, dave.nerd @ gmail.com  
-0x6ADA59DE
diff -pruN 6.02-1/debian/changelog 6.03-1/debian/changelog
--- 6.02-1/debian/changelog	2020-01-06 20:39:51.000000000 +0000
+++ 6.03-1/debian/changelog	2020-04-29 05:22:23.000000000 +0000
@@ -1,3 +1,16 @@
+clamtk (6.03-1) unstable; urgency=medium
+
+  * New upstream release
+    - Also update clamtk-gnome to version 0.05
+  * Update debian/patches/py3-clamtk-gnome.patch for new release
+  * Bump standards-version to 4.5.0 without further change
+  * Add missing install rule for thunar-sendto-clamtk
+  * Update debian/copyright
+  * Delete obsolete clamtk-gnome Breaks/Replaces on clamtk-nautilus
+  * Switch to debhelper-compat and update to compat 12
+
+ -- Scott Kitterman <scott@kitterman.com>  Wed, 29 Apr 2020 01:22:23 -0400
+
 clamtk (6.02-1) unstable; urgency=medium
 
   * Update debian/watch to version 4
diff -pruN 6.02-1/debian/clamtk-gnome.install 6.03-1/debian/clamtk-gnome.install
--- 6.02-1/debian/clamtk-gnome.install	2020-01-06 20:03:00.000000000 +0000
+++ 6.03-1/debian/clamtk-gnome.install	2020-04-29 05:22:23.000000000 +0000
@@ -1 +1 @@
-clamtk-gnome-0-03/clamtk-gnome.py /usr/share/nautilus-python/extensions
+clamtk-gnome/clamtk-gnome.py /usr/share/nautilus-python/extensions
diff -pruN 6.02-1/debian/clamtk.install 6.03-1/debian/clamtk.install
--- 6.02-1/debian/clamtk.install	2020-01-06 20:03:00.000000000 +0000
+++ 6.03-1/debian/clamtk.install	2020-04-29 05:22:23.000000000 +0000
@@ -3,5 +3,6 @@ clamtk.desktop				usr/share/applications
 images/*				usr/share/pixmaps/
 lib/*					usr/share/perl5/ClamTk/
 #help/*					usr/share/help
-clamtk-kde-0-18/clamtk-kde.desktop	usr/share/applications/
-nemo-sendto-clamtk-0-04/nemo-sendto-clamtk.nemo_action	usr/share/nemo/actions
+clamtk-kde/clamtk-kde.desktop	usr/share/applications/
+nemo-sendto-clamtk/nemo-sendto-clamtk.nemo_action	usr/share/nemo/actions
+thunar-sendto-clamtk/thunar-sendto-clamtk.desktop	usr/share/Thunar/sendto
diff -pruN 6.02-1/debian/compat 6.03-1/debian/compat
--- 6.02-1/debian/compat	2020-01-06 20:03:00.000000000 +0000
+++ 6.03-1/debian/compat	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-9
diff -pruN 6.02-1/debian/control 6.03-1/debian/control
--- 6.02-1/debian/control	2020-01-06 20:24:16.000000000 +0000
+++ 6.03-1/debian/control	2020-04-29 05:22:23.000000000 +0000
@@ -7,11 +7,11 @@ Uploaders: Scott Kitterman <scott@kitter
            Andreas Cadhalpun <Andreas.Cadhalpun@googlemail.com>,
            David Paleino <dapal@debian.org>
 Build-Depends:
- debhelper (>= 9~)
+ debhelper-compat (= 12)
 Build-Depends-Indep:
  liblocale-gettext-perl
  , gettext
-Standards-Version: 4.4.1
+Standards-Version: 4.5.0
 Homepage: https://gitlab.com/dave_m/clamtk
 Vcs-Git: https://salsa.debian.org/clamav-team/clamtk.git
 Vcs-Browser: https://salsa.debian.org/clamav-team/clamtk
@@ -61,8 +61,6 @@ Description: graphical front-end for Cla
 Package: clamtk-gnome
 Architecture: all
 Depends: clamtk, python3-nautilus, python3-gi, python3, ${misc:Depends}
-Breaks: clamtk-nautilus (<< 5.20)
-Replaces: clamtk-nautilus (<< 5.20)
 Enhances: nautilus
 Description: GNOME (Nautilus) MenuProvider extension for ClamTk
  ClamTk is a graphical front-end for Clam Antivirus.
diff -pruN 6.02-1/debian/copyright 6.03-1/debian/copyright
--- 6.02-1/debian/copyright	2020-01-06 20:03:00.000000000 +0000
+++ 6.03-1/debian/copyright	2020-04-29 05:22:23.000000000 +0000
@@ -1,7 +1,11 @@
 Format: https://www.debian.org/doc/packaging-manuals/copyright-format/1.0
 
 Files: *
-Copyright: © 2004-2019, Dave Mauroni <dave.nerd@gmail.com>
+Copyright: (C) 2004-2020 Dave M
+License: GPL-1+ or Artistic
+
+Files: clamtk-gnome/clamtk-gnome.py
+Copyright: 2004-2020 Dave M, Tord Dellsén
 License: GPL-1+ or Artistic
 
 Files: debian/*
diff -pruN 6.02-1/debian/patches/py3-clamtk-gnome.patch 6.03-1/debian/patches/py3-clamtk-gnome.patch
--- 6.02-1/debian/patches/py3-clamtk-gnome.patch	2020-01-06 20:25:41.000000000 +0000
+++ 6.03-1/debian/patches/py3-clamtk-gnome.patch	2020-04-29 05:22:23.000000000 +0000
@@ -1,10 +1,10 @@
 Index: clamtk/clamtk-gnome-0-03/clamtk-gnome.py
 ===================================================================
 --- clamtk.orig/clamtk-gnome-0-03/clamtk-gnome.py
-+++ clamtk/clamtk-gnome-0-03/clamtk-gnome.py
++++ clamtk/clamtk-gnome/clamtk-gnome.py
 @@ -1,4 +1,4 @@
--#!/usr/bin/env python
+-#!/usr/bin/env python3
 +#!/usr/bin/python3
  # -*- coding: utf-8 -*-
- # ClamTk, copyright (C) 2004-2019 Dave M, Tord Dellsén
+ # ClamTk, copyright (C) 2004-2020 Dave M, Tord Dellsén
  #
diff -pruN 6.02-1/debian/rules 6.03-1/debian/rules
--- 6.02-1/debian/rules	2020-01-06 20:03:00.000000000 +0000
+++ 6.03-1/debian/rules	2020-04-29 05:22:23.000000000 +0000
@@ -16,10 +16,10 @@ override_dh_auto_install:
 	dh_auto_install
 
 override_dh_installdocs:
-	cp nemo-sendto-clamtk-0-04/README.md README.nemo-sendto-clamtk
-	cp clamtk-kde-0-18/README.md README.clamtk-kde
-	cp thunar-sendto-clamtk-0-06/README README.Thunar-sendto-clamtk
-	cp clamtk-gnome-0-03/README.md README_clamtk-gnome
+	cp nemo-sendto-clamtk/README.md README.nemo-sendto-clamtk
+	cp clamtk-kde/README.md README.clamtk-kde
+	cp thunar-sendto-clamtk/README README.Thunar-sendto-clamtk
+	cp clamtk-gnome/README.md README_clamtk-gnome
 	dh_installdocs
 	rm README.nemo-sendto-clamtk
 	rm README.clamtk-kde
diff -pruN 6.02-1/debian/watch 6.03-1/debian/watch
--- 6.02-1/debian/watch	2020-01-06 20:03:00.000000000 +0000
+++ 6.03-1/debian/watch	2020-04-29 05:22:23.000000000 +0000
@@ -4,7 +4,7 @@ https://bitbucket.org/davem_/clamtk-gtk3
 
 
 opts=pgpsigurlmangle=s/$/.asc/,component=clamtk-gnome, \
-https://bitbucket.org/davem_/clamtk-gnome/downloads/clamtk-gnome@ANY_VERSION@@ARCHIVE_EXT@ 0.03
+https://bitbucket.org/davem_/clamtk-gnome/downloads/clamtk-gnome@ANY_VERSION@@ARCHIVE_EXT@ 0.05
 
 opts=pgpsigurlmangle=s/$/.asc/,component=clamtk-kde, \
 https://bitbucket.org/davem_/clamtk-kde/downloads/clamtk-kde@ANY_VERSION@@ARCHIVE_EXT@ 0.18
diff -pruN 6.02-1/lib/Analysis.pm 6.03-1/lib/Analysis.pm
--- 6.02-1/lib/Analysis.pm	2019-09-27 11:35:05.000000000 +0000
+++ 6.03-1/lib/Analysis.pm	2020-04-23 13:47:21.000000000 +0000
@@ -1,4 +1,4 @@
-# ClamTk, copyright (C) 2004-2019 Dave M
+# ClamTk, copyright (C) 2004-2020 Dave M
 #
 # This file is part of ClamTk
 # (https://gitlab.com/dave_m/clamtk-gtk3/).
diff -pruN 6.02-1/lib/App.pm 6.03-1/lib/App.pm
--- 6.02-1/lib/App.pm	2019-09-22 10:21:58.000000000 +0000
+++ 6.03-1/lib/App.pm	2020-04-23 13:47:15.000000000 +0000
@@ -1,4 +1,4 @@
-# ClamTk, copyright (C) 2004-2019 Dave M
+# ClamTk, copyright (C) 2004-2020 Dave M
 #
 # This file is part of ClamTk
 # (https://gitlab.com/dave_m/clamtk-gtk3/).
@@ -25,7 +25,7 @@ use Encode 'decode';
 
 sub get_TK_version {
     # Stick with %.2f format - 4.50 vice 4.5
-    return '6.02';
+    return '6.03';
 }
 
 sub get_path {
@@ -87,14 +87,14 @@ sub get_path {
 
     # Most times freshclam is under /usr/bin
     $path->{ freshclam }
-        = ( -e '/usr/bin/freshclam' ) ? '/usr/bin/freshclam'
+        = ( -e '/usr/bin/freshclam' )       ? '/usr/bin/freshclam'
         : ( -e '/usr/local/bin/freshclam' ) ? '/usr/local/bin/freshclam'
         : ( -e '/opt/local/bin/freshclam' ) ? '/opt/local/bin/freshclam'
         :                                     '';
 
     # Use sigtool for db info
     $path->{ sigtool }
-        = ( -e '/usr/bin/sigtool' ) ? '/usr/bin/sigtool'
+        = ( -e '/usr/bin/sigtool' )       ? '/usr/bin/sigtool'
         : ( -e '/usr/local/bin/sigtool' ) ? '/usr/local/bin/sigtool'
         : ( -e '/opt/local/bin/sigtool' ) ? '/opt/local/bin/sigtool'
         :                                   '';
@@ -103,7 +103,7 @@ sub get_path {
     # We'll use clampath as the actual path
     # and clamscan as clampath + scan options
     $path->{ clampath }
-        = ( -e '/usr/bin/clamscan' ) ? '/usr/bin/clamscan'
+        = ( -e '/usr/bin/clamscan' )       ? '/usr/bin/clamscan'
         : ( -e '/usr/local/bin/clamscan' ) ? '/usr/local/bin/clamscan'
         : ( -e '/opt/local/bin/clamscan' ) ? '/opt/local/bin/clamscan'
         :                                    '';
diff -pruN 6.02-1/lib/Assistant.pm 6.03-1/lib/Assistant.pm
--- 6.02-1/lib/Assistant.pm	2019-09-22 10:22:49.000000000 +0000
+++ 6.03-1/lib/Assistant.pm	2020-04-23 13:47:09.000000000 +0000
@@ -1,4 +1,4 @@
-# ClamTk, copyright (C) 2004-2019 Dave M
+# ClamTk, copyright (C) 2004-2020 Dave M
 #
 # This file is part of ClamTk (https://gitlab.com/dave_m/clamtk/).
 #
diff -pruN 6.02-1/lib/GUI.pm 6.03-1/lib/GUI.pm
--- 6.02-1/lib/GUI.pm	2019-09-27 11:10:24.000000000 +0000
+++ 6.03-1/lib/GUI.pm	2020-04-23 13:45:33.000000000 +0000
@@ -1,4 +1,4 @@
-# ClamTk, copyright (C) 2004-2019 Dave M
+# ClamTk, copyright (C) 2004-2020 Dave M
 #
 # This file is part of ClamTk
 # (https://gitlab.com/dave_m/clamtk-gtk3/).
@@ -28,17 +28,17 @@ my $infobar;
 my $top_box;
 my $box;
 
-sub start_gui {
-    # Some themes don't have all the "standard" gnome icons, so
-    # clamtk will crash if they're not there.  This is a patch from
-    # Arch Linux, which may solve the issue - or at least stop dying
-    # because it's missing an icon :|
-    # https://aur.archlinux.org/packages/clamtk/
-    my $theme = Gtk3::IconTheme::get_default;
-    $theme->append_search_path( '/usr/share/icons/gnome/24x24/actions' );
-    $theme->append_search_path( '/usr/share/icons/gnome/24x24/places' );
-    $theme->append_search_path( '/usr/share/icons/gnome/24x24/mimetypes' );
+# Some themes don't have all the "standard" gnome icons, so
+# clamtk will crash if they're not there.  This is a patch from
+# Arch Linux, which may solve the issue - or at least stop dying
+# because it's missing an icon :|
+# https://aur.archlinux.org/packages/clamtk/
+my $theme = Gtk3::IconTheme::get_default;
+$theme->append_search_path( '/usr/share/icons/gnome/24x24/actions' );
+$theme->append_search_path( '/usr/share/icons/gnome/24x24/places' );
+$theme->append_search_path( '/usr/share/icons/gnome/24x24/mimetypes' );
 
+sub start_gui {
     $window = Gtk3::Window->new( 'toplevel' );
     $window->signal_connect(
         destroy => sub {
@@ -76,7 +76,7 @@ sub start_gui {
     $hb->pack_end( $separator );
 
     my $button = Gtk3::Button->new_from_icon_name( 'help-about', 2 );
-    $button->set_can_focus(FALSE);
+    $button->set_can_focus( FALSE );
     $hb->pack_end( $button );
     $button->set_tooltip_text( _( 'About' ) );
     $button->signal_connect( 'clicked', sub { about() } );
@@ -237,11 +237,11 @@ sub add_config_panels {
     );
 
     #<<<
-    my $theme = Gtk3::IconTheme->new;
+    # my $theme = Gtk3::IconTheme->new;
     for my $item ( @data ) {
         my $use_image = ClamTk::Icons->get_image($item->{image});
         my $iter = $liststore->append;
-        my $pix = Gtk3::IconTheme::get_default->load_icon(
+        my $pix = $theme->load_icon(
             $use_image, 24, 'use-builtin'
         );
         $liststore->set( $iter,
@@ -305,11 +305,11 @@ sub add_update_panels {
     );
 
     #<<<
-    my $theme = Gtk3::IconTheme->new;
+    # my $theme = Gtk3::IconTheme->new;
     for my $item ( @data ) {
         my $use_image = ClamTk::Icons->get_image($item->{image});
         my $iter = $liststore->append;
-        my $pix = Gtk3::IconTheme::get_default->load_icon(
+        my $pix = $theme->load_icon(
             $use_image, 24, 'use-builtin'
         );
         $liststore->set( $iter,
@@ -509,7 +509,7 @@ sub press {
     my ( $path, $store ) = @_;
     return unless ( $path );
 
-    my $iter = $store->get_iter( $path );
+    my $iter  = $store->get_iter( $path );
     my $value = $store->get_value( $iter, 1 );
 
     iconview_react( $value );
@@ -519,7 +519,7 @@ sub click {
     my ( $view, $path, $model ) = @_;
     $view->unselect_all;
 
-    my $iter = $model->get_iter( $path );
+    my $iter  = $model->get_iter( $path );
     my $value = $model->get_value( $iter, 1 );
 
     iconview_react( $value );
@@ -711,7 +711,7 @@ sub about {
     $dialog->set_logo( $pixbuf );
     $dialog->set_translator_credits(
         'Please see the credits.md for full listing' );
-    $dialog->set_copyright( "\x{a9} Dave M 2004 - 2019" );
+    $dialog->set_copyright( "\x{a9} Dave M 2004 - 2020" );
     $dialog->set_program_name( 'ClamTk' );
     $dialog->set_authors( [ 'Dave M', 'dave.nerd@gmail.com' ] );
     $dialog->set_comments(
diff -pruN 6.02-1/lib/History.pm 6.03-1/lib/History.pm
--- 6.02-1/lib/History.pm	2019-09-27 11:42:46.000000000 +0000
+++ 6.03-1/lib/History.pm	2020-04-23 13:46:16.000000000 +0000
@@ -1,4 +1,4 @@
-# ClamTk, copyright (C) 2004-2019 Dave M
+# ClamTk, copyright (C) 2004-2020 Dave M
 #
 # This file is part of ClamTk
 # (https://gitlab.com/dave_m/clamtk-gtk3/).
@@ -74,20 +74,33 @@ sub show_window {
     $viewbar->set_style( 'both-horiz' );
 
     my $button = Gtk3::ToolButton->new();
-    my $use_image = ClamTk::Icons->get_image('text-x-preview');
+    # my $use_image = ClamTk::Icons->get_image('text-x-preview');
+    my $use_image = ClamTk::Icons->get_image( 'document-new' );
     $button->set_icon_name( $use_image );
     $button->set_label( _( 'View' ) );
     $viewbar->insert( $button, -1 );
     $button->set_is_important( TRUE );
     $button->signal_connect( clicked => \&view_history, $view );
 
+    $button    = Gtk3::ToolButton->new();
+    $use_image = ClamTk::Icons->get_image( 'document-print' );
+    $button->set_icon_name( $use_image );
+    $button->set_label( _( 'Print' ) );
+    $viewbar->insert( $button, -1 );
+    $button->set_is_important( TRUE );
+    $button->signal_connect(
+        clicked => sub {
+            my $p = Gtk3::PrintOperation->new();
+        }
+    );
+
     my $v_sep = Gtk3::SeparatorToolItem->new;
     $v_sep->set_draw( FALSE );
     $v_sep->set_expand( TRUE );
     $viewbar->insert( $v_sep, -1 );
 
-    $button = Gtk3::ToolButton->new();
-    $use_image = ClamTk::Icons->get_image('edit-delete');
+    $button    = Gtk3::ToolButton->new();
+    $use_image = ClamTk::Icons->get_image( 'edit-delete' );
     $button->set_icon_name( $use_image );
     $button->set_label( _( 'Delete' ) );
     $viewbar->insert( $button, -1 );
@@ -191,7 +204,7 @@ sub view_history {
     $viewbar->insert( $v_sep, -1 );
 
     my $close_btn = Gtk3::ToolButton->new();
-    my $use_image = ClamTk::Icons->get_image('window-close');
+    my $use_image = ClamTk::Icons->get_image( 'window-close' );
     $close_btn->set_icon_name( $use_image );
     $close_btn->set_label( _( 'Close' ) );
     $close_btn->set_is_important( TRUE );
diff -pruN 6.02-1/lib/Icons.pm 6.03-1/lib/Icons.pm
--- 6.02-1/lib/Icons.pm	2019-09-28 08:33:41.000000000 +0000
+++ 6.03-1/lib/Icons.pm	2020-04-23 13:45:53.000000000 +0000
@@ -1,4 +1,4 @@
-# ClamTk, copyright (C) 2004-2019 Dave M
+# ClamTk, copyright (C) 2004-2020 Dave M
 #
 # This file is part of ClamTk
 # (https://gitlab.com/dave_m/clamtk-gtk3/).
@@ -18,15 +18,18 @@ package ClamTk::Icons;
 
 sub get_image() {
     my ( $self, $wanted ) = @_;
-    # warn "wanted: >$wanted<\n";
 
     my $use_image = '';
 
     my %table;
 
     # These need to be scrubbed again
+    # The gtk-apply in the left column is because it works and
+    # the newer names (e.g., emblem-ok) don't.
+    $table{ 'system-run' }                 = 'gtk-apply';
     $table{ 'alarm' }                      = 'gtk-properties';
     $table{ 'document-new' }               = 'gtk-file';
+    $table{ 'document-print' }             = 'gtk-print';
     $table{ 'document-save' }              = 'gtk-apply';
     $table{ 'document-save-as' }           = 'gtk-save-as';
     $table{ 'document-send' }              = 'gtk-index';
@@ -35,13 +38,13 @@ sub get_image() {
     $table{ 'edit-select' }                = 'gtk-find';
     $table{ 'edit-undo' }                  = 'gtk-undelete';
     $table{ 'emblem-important' }           = 'gtk-no';
-    $table{ 'emblem-ok' }                  = 'gtk-yes';
     $table{ 'folder-documents' }           = 'gtk-directory';
     $table{ 'go-previous' }                = 'gtk-go-back';
     $table{ 'help-about' }                 = 'gtk-about';
     $table{ 'image-missing' }              = 'gtk-missing-image';
     $table{ 'list-add' }                   = 'gtk-add';
     $table{ 'list-remove' }                = 'gtk-remove';
+    $table{ 'media-playback-start' }       = 'gtk-yes';
     $table{ 'preferences-system' }         = 'gtk-preferences';
     $table{ 'preferences-system-network' } = 'gtk-network';
     $table{ 'process-stop' }               = 'gtk-cancel';
diff -pruN 6.02-1/lib/Network.pm 6.03-1/lib/Network.pm
--- 6.02-1/lib/Network.pm	2019-09-27 11:45:48.000000000 +0000
+++ 6.03-1/lib/Network.pm	2020-04-23 13:47:03.000000000 +0000
@@ -1,4 +1,4 @@
-# ClamTk, copyright (C) 2004-2019 Dave M
+# ClamTk, copyright (C) 2004-2020 Dave M
 #
 # This file is part of ClamTk
 # (https://gitlab.com/dave_m/clamtk-gtk3/).
@@ -106,12 +106,12 @@ sub show_window {
         }
     );
 
-    my $use_image = ClamTk::Icons->get_image('document-save');
+    my $use_image    = ClamTk::Icons->get_image( 'document-save' );
     my $apply_button = Gtk3::Button->new_from_icon_name( $use_image, 0 );
     $apply_button->set_tooltip_text( _( 'Press Apply to save changes' ) );
     $grid->attach( $apply_button, 0, 6, 1, 1 );
 
-    $use_image = ClamTk::Icons->get_image('list-add');
+    $use_image          = ClamTk::Icons->get_image( 'list-add' );
     $proxy_status_image = Gtk3::Button->new_from_icon_name( $use_image, 0 );
     $grid->attach( $proxy_status_image, 1, 6, 1, 1 );
 
@@ -257,15 +257,15 @@ sub proxy_non_block_status {
     my $status  = shift;
     my $message = '';
     if ( $status eq 'yes' ) {
-        my $use_image = ClamTk::Icons->get_image('emblem-ok');
-        my $btn = Gtk3::Button->new_from_icon_name( $use_image, 0 );
+        my $use_image = ClamTk::Icons->get_image( 'emblem-ok' );
+        my $btn       = Gtk3::Button->new_from_icon_name( $use_image, 0 );
         $btn->set_relief( 'none' );
         $proxy_status_image->set_image( $btn );
         $message = _( 'Settings saved' );
         $infobar->set_message_type( 'other' );
     } else {
-        my $use_image = ClamTk::Icons->get_image('emblem-important');
-        my $btn = Gtk3::Button->new_from_icon_name( $use_image, 0 );
+        my $use_image = ClamTk::Icons->get_image( 'emblem-important' );
+        my $btn       = Gtk3::Button->new_from_icon_name( $use_image, 0 );
         $btn->set_relief( 'none' );
         $proxy_status_image->set_image( $btn );
         $message = _( 'Error' );
diff -pruN 6.02-1/lib/Prefs.pm 6.03-1/lib/Prefs.pm
--- 6.02-1/lib/Prefs.pm	2019-09-22 10:24:54.000000000 +0000
+++ 6.03-1/lib/Prefs.pm	2020-04-23 13:45:25.000000000 +0000
@@ -1,4 +1,4 @@
-# ClamTk, copyright (C) 2004-2019 Dave M
+# ClamTk, copyright (C) 2004-2020 Dave M
 #
 # This file is part of ClamTk
 # (https://gitlab.com/dave_m/clamtk-gtk3/).
@@ -126,6 +126,9 @@ sub structure {
         close( $F );
     }
 
+    # Automatically set local freshclam.conf for individual updates
+    set_local_config();
+
     return 1;
 }
 
@@ -179,7 +182,7 @@ sub custom_prefs {
     # Recursive: Scan all files/directories within a directory
     # Mounted: Scan gvfs and related directories
     for my $o (
-        qw{ScanHidden SizeLimit
+        qw{ScanHidden SizeLimit Heuristic
         Thorough Recursive Mounted}
         )
     {
@@ -226,7 +229,7 @@ sub get_all_prefs {
 sub legit_key {
     # Sanity check the prefs file's keys.
     my @keys = qw(
-        SizeLimit HTTPProxy
+        SizeLimit HTTPProxy Heuristic
         LastInfection GUICheck DupeDB
         TruncateLog SaveToLog
         Whitelist Update ScanHidden
@@ -318,8 +321,7 @@ sub set_proxy {
     my $path = ClamTk::App->get_path( 'db' );
 
     # This gets clobbered every time.
-    # Doesn't need to be utf-8 friendly. I think.
-    open( my $FH, '>', "$path/local.conf" )
+    open( my $FH, '>:encoding(UTF-8)', "$path/local.conf" )
         or return -1;
     print $FH <<"EOF";
 HTTPProxyServer $ip
@@ -332,4 +334,27 @@ EOF
     return 1;
 }
 
+sub set_local_config {
+    my $path = ClamTk::App->get_path( 'db' );
+    if ( -e "$path/freshclam.conf" ) {
+        return;
+    }
+
+    # This gets clobbered every time.
+    open( my $FH, '>:encoding(UTF-8)', "$path/freshclam.conf" )
+        or return -1;
+    print $FH <<"EOF";
+# Local config
+DatabaseMirror database.clamav.net
+LogSyslog no
+EOF
+    close( $FH )
+        or warn "Couldn't close $path/freshclam.conf: $!\n";
+    if ( !-e "$path/freshclam.conf" ) {
+        warn "Couldn't create local freshclam.conf!\n"
+            . "You will be unable to do manual updates.\n";
+    }
+    return 1;
+}
+
 1;
diff -pruN 6.02-1/lib/Quarantine.pm 6.03-1/lib/Quarantine.pm
--- 6.02-1/lib/Quarantine.pm	2019-09-27 11:51:04.000000000 +0000
+++ 6.03-1/lib/Quarantine.pm	2020-04-23 13:46:58.000000000 +0000
@@ -1,4 +1,4 @@
-# ClamTk, copyright (C) 2004-2019 Dave M
+# ClamTk, copyright (C) 2004-2020 Dave M
 #
 # This file is part of ClamTk
 # (https://gitlab.com/dave_m/clamtk-gtk3/).
diff -pruN 6.02-1/lib/Results.pm 6.03-1/lib/Results.pm
--- 6.02-1/lib/Results.pm	2019-09-27 11:51:48.000000000 +0000
+++ 6.03-1/lib/Results.pm	2020-04-23 13:46:51.000000000 +0000
@@ -1,4 +1,4 @@
-# ClamTk, copyright (C) 2004-2019 Dave M
+# ClamTk, copyright (C) 2004-2020 Dave M
 #
 # This file is part of ClamTk
 # (https://gitlab.com/dave_m/clamtk-gtk3/).
diff -pruN 6.02-1/lib/Scan.pm 6.03-1/lib/Scan.pm
--- 6.02-1/lib/Scan.pm	2019-09-28 11:10:44.000000000 +0000
+++ 6.03-1/lib/Scan.pm	2020-04-23 13:45:18.000000000 +0000
@@ -1,4 +1,4 @@
-# ClamTk, copyright (C) 2004-2019 Dave M
+# ClamTk, copyright (C) 2004-2020 Dave M
 #
 # This file is part of ClamTk
 # (https://gitlab.com/dave_m/clamtk-gtk3/).
@@ -292,7 +292,7 @@ sub filter {
             $directive
                 .= ' --detect-pua --alert-broken'
                 . ' --alert-macros --alert-encrypted-archive'
-                . ' --alert-encrypted-doc --heuristic-alerts';
+                . ' --alert-encrypted-doc';
         } else {
             $directive .= ' --detect-pua --algorithmic-detection';
         }
@@ -301,12 +301,19 @@ sub filter {
             || ( $version cmp '101' ) == 1 )
         {
             $directive
-                =~ s/\s--detect-pua --alert-broken --alert-macros --alert-encrypted-archive --alert-encrypted-doc --heuristic-alerts'//;
+                =~ s/\s--detect-pua --alert-broken --alert-macros --alert-encrypted-archive --alert-encrypted-doc'//;
         } else {
             $directive =~ s/\s--detect-pua --algorithmic-detection//;
         }
     }
-    # print "directive = >", $directive, "<\n";
+
+    # remove the hidden files if chosen:
+    if ( $prefs{ Heuristic } ) {
+        # By default, if included, == yes
+        $directive .= ' --heuristic-alerts=yes';
+    } else {
+        $directive .= ' --heuristic-alerts=no';
+    }
 
     # only a single file
 
diff -pruN 6.02-1/lib/Schedule.pm 6.03-1/lib/Schedule.pm
--- 6.02-1/lib/Schedule.pm	2019-09-27 11:56:57.000000000 +0000
+++ 6.03-1/lib/Schedule.pm	2020-04-23 13:46:23.000000000 +0000
@@ -1,4 +1,4 @@
-# ClamTk, copyright (C) 2004-2019 Dave M
+# ClamTk, copyright (C) 2004-2020 Dave M
 #
 # This file is part of ClamTk
 # (https://gitlab.com/dave_m/clamtk-gtk3/).
@@ -28,7 +28,7 @@ use open ':encoding(utf8)';
 
 # This should be under /usr/bin, but we'll check anyway.
 my $cmd
-    = ( -e '/usr/bin/crontab' ) ? '/usr/bin/crontab'
+    = ( -e '/usr/bin/crontab' )       ? '/usr/bin/crontab'
     : ( -e '/usr/local/bin/crontab' ) ? '/usr/local/bin/crontab'
     : ( -e '/bin/crontab' )           ? '/bin/crontab'
     :                                   '';
@@ -189,7 +189,7 @@ sub show_window {
         : TRUE;
 
     $defs_apply_btn = Gtk3::ToolButton->new();
-    $defs_apply_btn->set_icon_name( 'emblem-new' );
+    $defs_apply_btn->set_icon_name( 'list-add' );
     $defs_apply_btn->set_label( _( 'Close' ) );
     if ( $can_update ) {
         $defs_bar->insert( $defs_apply_btn, -1 );
diff -pruN 6.02-1/lib/Settings.pm 6.03-1/lib/Settings.pm
--- 6.02-1/lib/Settings.pm	2019-09-27 12:05:17.000000000 +0000
+++ 6.03-1/lib/Settings.pm	2020-04-23 13:46:09.000000000 +0000
@@ -1,4 +1,4 @@
-# ClamTk, copyright (C) 2004-2019 Dave M
+# ClamTk, copyright (C) 2004-2020 Dave M
 #
 # This file is part of ClamTk
 # (https://gitlab.com/dave_m/clamtk-gtk3/).
@@ -53,11 +53,26 @@ sub show_window {
         }
     );
 
+    $option
+        = Gtk3::CheckButton->new_with_label( _( 'Use heuristic scanning' ) );
+    # $option->set_tooltip_text(
+    #     _( 'tooltip here' ) );
+    $option->set_active( TRUE ) if ( $prefs{ Heuristic } );
+    $grid->attach( $option, 0, 1, 1, 1 );
+    $option->signal_connect(
+        toggled => sub {
+            my $btn = shift;
+            ClamTk::Prefs->set_preference( 'Heuristic', $btn->get_active
+                ? 1
+                : 0 );
+        }
+    );
+
     $option = Gtk3::CheckButton->new_with_label(
         _( 'Scan files beginning with a dot (.*)' ) );
     $option->set_tooltip_text( _( 'Scan files typically hidden from view' ) );
     $option->set_active( TRUE ) if ( $prefs{ ScanHidden } );
-    $grid->attach( $option, 0, 1, 1, 1 );
+    $grid->attach( $option, 0, 2, 1, 1 );
     $option->signal_connect(
         toggled => sub {
             my $btn = shift;
@@ -72,7 +87,7 @@ sub show_window {
     $option->set_tooltip_text(
         _( 'Scan large files which are typically not examined' ) );
     $option->set_active( TRUE ) if ( $prefs{ SizeLimit } );
-    $grid->attach( $option, 0, 2, 1, 1 );
+    $grid->attach( $option, 0, 3, 1, 1 );
     $option->signal_connect(
         toggled => sub {
             my $btn = shift;
@@ -87,7 +102,7 @@ sub show_window {
     $option->set_tooltip_text(
         _( 'Scan all files and directories within a directory' ) );
     $option->set_active( TRUE ) if ( $prefs{ Recursive } );
-    $grid->attach( $option, 0, 3, 1, 1 );
+    $grid->attach( $option, 0, 4, 1, 1 );
     $option->signal_connect(
         toggled => sub {
             my $btn = shift;
@@ -102,7 +117,7 @@ sub show_window {
     $option->set_tooltip_text(
         _( 'Check online for application and signature updates' ) );
     $option->set_active( TRUE ) if ( $prefs{ GUICheck } );
-    $grid->attach( $option, 0, 4, 1, 1 );
+    $grid->attach( $option, 0, 5, 1, 1 );
     $option->signal_connect(
         toggled => sub {
             my $btn = shift;
diff -pruN 6.02-1/lib/Shortcuts.pm 6.03-1/lib/Shortcuts.pm
--- 6.02-1/lib/Shortcuts.pm	2019-09-27 11:59:25.000000000 +0000
+++ 6.03-1/lib/Shortcuts.pm	2020-04-23 13:46:43.000000000 +0000
@@ -1,4 +1,4 @@
-# ClamTk, copyright (C) 2004-2019 Dave M
+# ClamTk, copyright (C) 2004-2020 Dave M
 #
 # This file is part of ClamTk
 # (https://gitlab.com/dave_m/clamtk-gtk3/).
diff -pruN 6.02-1/lib/Startup.pm 6.03-1/lib/Startup.pm
--- 6.02-1/lib/Startup.pm	2019-09-27 11:59:44.000000000 +0000
+++ 6.03-1/lib/Startup.pm	2020-04-23 13:46:38.000000000 +0000
@@ -1,4 +1,4 @@
-# ClamTk, copyright (C) 2004-2019 Dave M
+# ClamTk, copyright (C) 2004-2020 Dave M
 #
 # This file is part of ClamTk
 # (https://gitlab.com/dave_m/clamtk-gtk3/).
@@ -65,7 +65,7 @@ sub check_gui {
     my $remote_tk_version = ClamTk::Update->get_remote_TK_version();
 
     my ( $local_chopped, $remote_chopped );
-    ( $local_chopped  = $local_tk_version ) =~ s/[^0-9]//;
+    ( $local_chopped  = $local_tk_version )  =~ s/[^0-9]//;
     ( $remote_chopped = $remote_tk_version ) =~ s/[^0-9]//;
 
     # Sanity check to ensure we received an answer
diff -pruN 6.02-1/lib/Update.pm 6.03-1/lib/Update.pm
--- 6.02-1/lib/Update.pm	2019-09-27 12:02:17.000000000 +0000
+++ 6.03-1/lib/Update.pm	2020-04-23 13:45:04.000000000 +0000
@@ -1,4 +1,4 @@
-# ClamTk, copyright (C) 2004-2019 Dave M
+# ClamTk, copyright (C) 2004-2020 Dave M
 #
 # This file is part of ClamTk
 # (https://gitlab.com/dave_m/clamtk-gtk3/).
@@ -100,23 +100,22 @@ sub show_window {
 
     my $text = '';
     if ( ClamTk::Prefs->get_preference( 'Update' ) eq 'shared' ) {
-        $text = _( 'You are configured to automatically receive updates' );
+        my $label = Gtk3::Label->new;
+        $label->set_text(
+            _( 'You are configured to automatically receive updates' ) );
+        $infobar->get_content_area()->add( $label );
     } else {
         $text = _( 'Check for updates' );
-        my $use_image = ClamTk::Icons->get_image( 'emblem-ok' );
-        $infobar->add_button( $use_image, -5 );
-    }
+        $infobar->add_button( $text, -5 );
 
-    my $label = Gtk3::Label->new;
-    $label->set_text( $text );
-    $infobar->get_content_area()->add( $label );
-    #<<<
-    $infobar->signal_connect(
-        response => sub {
-                update_signatures();
-        }
-    );
-    #>>>
+        #<<<
+        $infobar->signal_connect(
+            response => sub {
+                    update_signatures();
+            }
+        );
+        #>>>
+    }
 
     $box->pack_start( Gtk3::VBox->new, TRUE, TRUE, 5 );
 
@@ -155,6 +154,12 @@ sub update_signatures {
     $pb->set_text( _( 'Please wait...' ) );
 
     my $freshclam = get_freshclam_path();
+    if ( ClamTk::Prefs->get_preference( 'Update' ) eq 'single' ) {
+        my $dbpath = ClamTk::App->get_path( 'db' ) . '/' . 'freshclam.conf';
+        if ( -e $dbpath ) {
+            $freshclam .= " --config-file=$dbpath";
+        }
+    }
 
     # The mirrors can be slow sometimes and may return/die
     # 'failed' despite that the update is still in progress.
@@ -169,6 +174,7 @@ sub update_signatures {
             = sub { die "failed updating signatures (timeout)\n" };
         alarm 100;
 
+        warn "about to run\n";
         $update_sig_pid = open( $update, '-|', "$freshclam --stdout" );
         defined( $update_sig_pid ) or do {
             set_infobar_text( 'error',
@@ -176,6 +182,7 @@ sub update_signatures {
             return 0;
         };
         alarm 0;
+        warn "after alarm and launch\n";
     };
     if ( $@ && $@ eq "failed\n" ) {
         set_infobar_text( 'error', _( 'Error updating: try again later' ) );
@@ -189,6 +196,7 @@ sub update_signatures {
     # speaking users. So, we'll grab the first couple words
     # and try to sum it up.
 
+    warn "running parser\n";
     while ( defined( my $line = <$update> ) ) {
         Gtk3::main_iteration while Gtk3::events_pending;
         $pb->set_text( _( 'Downloading...' ) );
diff -pruN 6.02-1/lib/Whitelist.pm 6.03-1/lib/Whitelist.pm
--- 6.02-1/lib/Whitelist.pm	2019-09-27 12:03:50.000000000 +0000
+++ 6.03-1/lib/Whitelist.pm	2020-04-23 13:46:31.000000000 +0000
@@ -1,4 +1,4 @@
-# ClamTk, copyright (C) 2004-2019 Dave M
+# ClamTk, copyright (C) 2004-2020 Dave M
 #
 # This file is part of ClamTk
 # (https://gitlab.com/dave_m/clamtk-gtk3/).
@@ -64,8 +64,8 @@ sub show_window {
     $bbox->set_style( 'both-horiz' );
     $bbox->set_show_arrow( FALSE );
 
-    my $button = Gtk3::ToolButton->new();
-    my $use_image = ClamTk::Icons->get_image('list-add');
+    my $button    = Gtk3::ToolButton->new();
+    my $use_image = ClamTk::Icons->get_image( 'list-add' );
     $button->set_icon_name( $use_image );
     $button->set_label( _( 'Add a directory' ) );
     $bbox->insert( $button, -1 );
@@ -77,8 +77,8 @@ sub show_window {
     $sep->set_expand( TRUE );
     $bbox->insert( $sep, -1 );
 
-    $button = Gtk3::ToolButton->new();
-    $use_image = ClamTk::Icons->get_image('list-remove');
+    $button    = Gtk3::ToolButton->new();
+    $use_image = ClamTk::Icons->get_image( 'list-remove' );
     $button->set_icon_name( $use_image );
     $button->set_label( _( 'Remove a directory' ) );
     $bbox->insert( $button, -1 );
diff -pruN 6.02-1/LICENSE 6.03-1/LICENSE
--- 6.02-1/LICENSE	2019-03-23 09:58:00.000000000 +0000
+++ 6.03-1/LICENSE	2020-03-22 10:11:26.000000000 +0000
@@ -1,6 +1,6 @@
 COPYRIGHT AND LICENSE
 
-ClamTk, copyright (C) 2004-2019 Dave M
+ClamTk, copyright (C) 2004-2020 Dave M
 https://gitlab.com/dave_m/clamtk
 https://gitlab.com/dave_m/clamtk/wikis/Home
 https://bitbucket.org/davem_/clamtk/
@@ -28,7 +28,7 @@ https://help.launchpad.net/Legal/BSDLice
 
 [Source: http://www.opensource.org/licenses/bsd-license.php]
 
-Copyright (c) 2004-2019, Dave M. All rights reserved.
+Copyright (c) 2004-2020, Dave M. All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions are met:
diff -pruN 6.02-1/nemo-sendto-clamtk/CHANGES 6.03-1/nemo-sendto-clamtk/CHANGES
--- 6.02-1/nemo-sendto-clamtk/CHANGES	1970-01-01 00:00:00.000000000 +0000
+++ 6.03-1/nemo-sendto-clamtk/CHANGES	2017-10-01 19:43:58.000000000 +0000
@@ -0,0 +1,28 @@
+CHANGES for nemo-sendto-clamtk:
+
+0.04 - 1 Oct 2017
+-----------------
+    * Updated language strings: Afrikaans (af), Basque (eu),
+        Punjabi (pa), Esperanto (eo)
+    * Updated documentation and links
+    * Changed README to use markdown (.md)
+    * Changed compression gz -> xz
+    * Fix permissions
+
+0.03 - 5 Sep 2016
+------------------
+    * Updated strings: Romanian (ro), English (en_AU),
+        Italian (it), Korean (ko_KR)
+    * Updated documentation and links
+
+0.02 - 15 Mar 2014
+------------------
+    * Updated strings: Dutch (nl), Czech (cs),
+        Serbian Latin (sr@latin), Marathi (mr),
+        Brazilian Portuguese (pt_BR), Portuguese (pt),
+        probably others
+    * Update years -> 2014
+
+0.01 - 16 Nov 2013
+------------------
+    * Initial release
diff -pruN 6.02-1/nemo-sendto-clamtk/DISCLAIMER 6.03-1/nemo-sendto-clamtk/DISCLAIMER
--- 6.02-1/nemo-sendto-clamtk/DISCLAIMER	1970-01-01 00:00:00.000000000 +0000
+++ 6.03-1/nemo-sendto-clamtk/DISCLAIMER	2013-11-16 20:26:30.000000000 +0000
@@ -0,0 +1,14 @@
+This software (nemo-sendto-clamtk) is provided 'as is' without
+warranty of any kind, either expressed or implied, including, but
+not limited to, the implied warranties of fitness for a purpose,
+or the warranty of non-infringement.
+
+Without limiting the foregoing, there is no warranty that:
+
+   1. the software will meet your requirements
+   2. the software will be uninterrupted, timely, secure or error-free
+   3. the results that may be obtained from the use of the software will
+      be effective, accurate or reliable
+   4. the quality of the software will meet your expectations
+
+Having said that, I do my best to make it as good as I can. Really.
diff -pruN 6.02-1/nemo-sendto-clamtk/LICENSE 6.03-1/nemo-sendto-clamtk/LICENSE
--- 6.02-1/nemo-sendto-clamtk/LICENSE	1970-01-01 00:00:00.000000000 +0000
+++ 6.03-1/nemo-sendto-clamtk/LICENSE	2017-10-01 06:49:02.000000000 +0000
@@ -0,0 +1,13 @@
+COPYRIGHT AND LICENSE
+
+nemo-sendto-clamtk, copyright (C) 2010 - 2017 Dave M
+
+<dave.nerd @ gmail.com>
+
+All rights reserved.  This program is free software; you can
+redistribute it and/or modify it under the terms of either:
+
+a) the GNU General Public License as published by the Free Software Foundation;
+either version 1, or (at your option) any later version, or
+
+b) the "Artistic License".
Binary files 6.02-1/nemo-sendto-clamtk/nemo-sendto-clamtk.1.gz and 6.03-1/nemo-sendto-clamtk/nemo-sendto-clamtk.1.gz differ
diff -pruN 6.02-1/nemo-sendto-clamtk/nemo-sendto-clamtk.nemo_action 6.03-1/nemo-sendto-clamtk/nemo-sendto-clamtk.nemo_action
--- 6.02-1/nemo-sendto-clamtk/nemo-sendto-clamtk.nemo_action	1970-01-01 00:00:00.000000000 +0000
+++ 6.03-1/nemo-sendto-clamtk/nemo-sendto-clamtk.nemo_action	2017-10-01 15:31:02.000000000 +0000
@@ -0,0 +1,129 @@
+# ClamTk, copyright (C) 2004-2017 Dave M
+#
+# This file is part of ClamTk.
+# https://dave-theunsub.github.io/clamtk/
+#
+# ClamTk is free software; you can redistribute it and/or modify it
+# under the terms of either:
+#
+# a) the GNU General Public License as published by the Free Software
+# Foundation; either version 1, or (at your option) any later version, or
+#
+# b) the "Artistic License".
+# nemo-sendto-clamtk.nemo_action 0.04
+[Nemo Action]
+
+Name=Scan for threats...
+
+Exec=clamtk %F
+
+Icon-Name=clamtk
+
+Selection=Any
+
+Label=''
+
+Extensions=any;
+
+Name=Scan for threats...
+Name[af]=Skandeer vir virusse...
+Name[ar]=إمسح للكشف عن الفيروسات
+Name[ast]=Buscar amenaces...
+Name[az]=Təhlükə mövcudluğuna yoxla...
+Name[bg]=Проверка за наличие на заплахи ...
+Name[bs]=Pretraga za virusima...
+Name[cs]=Skenování hrozeb...
+Name[da]=Skan for virus...
+Name[de]=Auf Bedrohungen untersuchen…
+Name[el]=Έλεγχος για ιούς...
+Name[en]=Scan for threats...
+Name[en_AU]=Scan for threats...
+Name[en_CA]=Scan for threats...
+Name[en_GB]=Scan for threats...
+Name[es]=Analizar en busca de amenazas…
+Name[eu]=Eskaneatu birusen bila...
+Name[fi]=Tarkista uhkien varalta...
+Name[fo]=Skanna eftir virus...
+Name[fr]=Rechercher des menaces...
+Name[gl]=Buscar ameazas...
+Name[he]=סריקה לאיתור איומים…
+Name[hr]=Pretraživanje virusa...
+Name[hu]=Vírusok keresése...
+Name[id]=Pindai untuk ancaman...
+Name[it]=Analizza per la ricerca di minacce...
+Name[ja]=ウィルスをスキャンします...
+Name[ko]=위험 요소를 검사합니다...
+Name[ms]=Imbas jika ada ancaman...
+Name[nl]=Scannen op virussen…
+Name[nb]=Skann etter virus...
+Name[nn]=Skann...
+Name[pa]=ਧਮਕਿਯਾੰ ਲਈ ਖੋਜ ਕਰੋ
+Name[pl]=Przeskanuj pliki w poszukiwaniu wirusów...
+Name[pt]=A analizar ameaças...
+Name[pt_BR]=Verificar se há vírus...
+Name[ro]=Scanare pentru amenințări...
+Name[ru]=Проверка на наличие угроз...
+Name[sk]=Skenovanie hrozieb...
+Name[sl]=Preglej za virusi...
+Name[sr@latin]=Skeniranje pretnji...
+Name[sv]=Skanna efter virus...
+Name[te]=వైరస్సుల కోసం సంశోధిస్తున్నది...
+Name[tr]=Virüs taraması yap...
+Name[ug]=ۋىرۇس تەكشۈر…
+Name[uk]=Шукати загрози…
+Name[uz]=Хавф учун текшириш...
+Name[zh_CN]=扫描威胁...
+Name[zh_TW]=掃描威脅...
+GenericName=Virus Scanner
+GenericName[af]=Virus Skandeerder
+GenericName[ar]=ماسح الفيروسات
+GenericName[ast]=Antivirus
+GenericName[az]=Virus axtarışı
+GenericName[bg]=Скенер за вируси
+GenericName[bs]=Virus Skener
+GenericName[ca]=Comprovador de virus
+GenericName[cs]=Antivirový program
+GenericName[da]=Virusscanneren
+GenericName[de]=Virensuche
+GenericName[el]=Ανιχνευτής ιών
+GenericName[en_AU]=Virus Scanner
+GenericName[en_CA]=Virus Scanner
+GenericName[en_GB]=Virus Scanner
+GenericName[eo]=Viruskontrolilo
+GenericName[es]=Analizador de Virus
+GenericName[eu]=Birus eskanerra
+GenericName[fi]=Virustorjuntasovellus
+GenericName[fo]=Virus skannari
+GenericName[fr]=Module de recherche et analyse de virus
+GenericName[gl]=Analizador de virus
+GenericName[he]=סורק וירוסים
+GenericName[hr]=Skener virusa
+GenericName[hu]=Víruskereső
+GenericName[id]=Pemindai Virus
+GenericName[it]=Analizzatore virus
+GenericName[ja]=ウイルススキャナ
+GenericName[ko]=바이러스 검사기
+GenericName[lt]=Virusų suradimo programa
+GenericName[mr]=धमक्या साठी स्कॅन
+GenericName[ms]=Pengimbas Virus
+GenericName[nb]=Virusskanner
+GenericName[nl]=Virusscanner
+GenericName[nl_BE]=Virusscanner
+GenericName[nn]=Virusskannar
+GenericName[pl]=Skaner wirusów
+GenericName[pt]=Verificador de vírus
+GenericName[pt_BR]=Antivírus Escaner
+GenericName[ro]=Scaner pentru viruși
+GenericName[ru]=Проверка на вирусы
+GenericName[sk]=Antivírus
+GenericName[sl]=Virusni pregledovalec
+GenericName[sr@latin]=Virus Skener
+GenericName[sv]=Virusskanner
+GenericName[te]=వైరస్ స్కానర్
+GenericName[th]=โปรแกรมตรวจจับไวรัส
+GenericName[tr]=Virüs Tarayıcı
+GenericName[ug]=ۋﻯﺭۇﺱ ﺕەﻚﺷۈﺭگۈچ
+GenericName[uk]=Антивірусний сканер
+GenericName[uz]=Вирусларни текшириш
+GenericName[zh_CN]=病毒扫描工具
+GenericName[zh_TW]=病毒掃描程式
diff -pruN 6.02-1/nemo-sendto-clamtk/README.md 6.03-1/nemo-sendto-clamtk/README.md
--- 6.02-1/nemo-sendto-clamtk/README.md	1970-01-01 00:00:00.000000000 +0000
+++ 6.03-1/nemo-sendto-clamtk/README.md	2017-10-01 19:39:12.000000000 +0000
@@ -0,0 +1,38 @@
+README
+------
+(Last updated 1 October 2017)
+
+## About
+
+nemo-sendto-clamtk is a simple plugin to allow a right-click,
+context menu scan of files or folders in nemo, the
+file manager for Cinnamon.
+
+All this plugin does is copy a desktop style file to the
+directory where nemo reads such things.  If this seems redundant,
+that's because it is: this plugin depends on clamtk,
+which already has this directory file. So, it stands to
+reason we should be able to just find that file and
+copy it, rather than having our own copy.
+
+nemo-sendto-clamtk is available for Fedora, CentOS, and
+Debian|Ubuntu - or probably any system that can run Cinnamon.
+
+Link to screenshot:
+* http://imgur.com/YgzL7xH
+
+## Dependencies
+
+clamtk >= 5.00
+nemo
+
+## Important Links
+
+For feature requests or bugs, it's best to use one of the following:
+
+* https://github.com/dave-theunsub/nemo-sendto-clamtk
+* https://bitbucket.org/davem_/nemo-sendto-clamtk/
+
+## Contact
+
+* Dave M, dave.nerd @gmail.com (0x6ADA59DE)
diff -pruN 6.02-1/nemo-sendto-clamtk-0-04/CHANGES 6.03-1/nemo-sendto-clamtk-0-04/CHANGES
--- 6.02-1/nemo-sendto-clamtk-0-04/CHANGES	2017-10-01 19:43:58.000000000 +0000
+++ 6.03-1/nemo-sendto-clamtk-0-04/CHANGES	1970-01-01 00:00:00.000000000 +0000
@@ -1,28 +0,0 @@
-CHANGES for nemo-sendto-clamtk:
-
-0.04 - 1 Oct 2017
------------------
-    * Updated language strings: Afrikaans (af), Basque (eu),
-        Punjabi (pa), Esperanto (eo)
-    * Updated documentation and links
-    * Changed README to use markdown (.md)
-    * Changed compression gz -> xz
-    * Fix permissions
-
-0.03 - 5 Sep 2016
-------------------
-    * Updated strings: Romanian (ro), English (en_AU),
-        Italian (it), Korean (ko_KR)
-    * Updated documentation and links
-
-0.02 - 15 Mar 2014
-------------------
-    * Updated strings: Dutch (nl), Czech (cs),
-        Serbian Latin (sr@latin), Marathi (mr),
-        Brazilian Portuguese (pt_BR), Portuguese (pt),
-        probably others
-    * Update years -> 2014
-
-0.01 - 16 Nov 2013
-------------------
-    * Initial release
diff -pruN 6.02-1/nemo-sendto-clamtk-0-04/DISCLAIMER 6.03-1/nemo-sendto-clamtk-0-04/DISCLAIMER
--- 6.02-1/nemo-sendto-clamtk-0-04/DISCLAIMER	2013-11-16 20:26:30.000000000 +0000
+++ 6.03-1/nemo-sendto-clamtk-0-04/DISCLAIMER	1970-01-01 00:00:00.000000000 +0000
@@ -1,14 +0,0 @@
-This software (nemo-sendto-clamtk) is provided 'as is' without
-warranty of any kind, either expressed or implied, including, but
-not limited to, the implied warranties of fitness for a purpose,
-or the warranty of non-infringement.
-
-Without limiting the foregoing, there is no warranty that:
-
-   1. the software will meet your requirements
-   2. the software will be uninterrupted, timely, secure or error-free
-   3. the results that may be obtained from the use of the software will
-      be effective, accurate or reliable
-   4. the quality of the software will meet your expectations
-
-Having said that, I do my best to make it as good as I can. Really.
diff -pruN 6.02-1/nemo-sendto-clamtk-0-04/LICENSE 6.03-1/nemo-sendto-clamtk-0-04/LICENSE
--- 6.02-1/nemo-sendto-clamtk-0-04/LICENSE	2017-10-01 06:49:02.000000000 +0000
+++ 6.03-1/nemo-sendto-clamtk-0-04/LICENSE	1970-01-01 00:00:00.000000000 +0000
@@ -1,13 +0,0 @@
-COPYRIGHT AND LICENSE
-
-nemo-sendto-clamtk, copyright (C) 2010 - 2017 Dave M
-
-<dave.nerd @ gmail.com>
-
-All rights reserved.  This program is free software; you can
-redistribute it and/or modify it under the terms of either:
-
-a) the GNU General Public License as published by the Free Software Foundation;
-either version 1, or (at your option) any later version, or
-
-b) the "Artistic License".
Binary files 6.02-1/nemo-sendto-clamtk-0-04/nemo-sendto-clamtk.1.gz and 6.03-1/nemo-sendto-clamtk-0-04/nemo-sendto-clamtk.1.gz differ
diff -pruN 6.02-1/nemo-sendto-clamtk-0-04/nemo-sendto-clamtk.nemo_action 6.03-1/nemo-sendto-clamtk-0-04/nemo-sendto-clamtk.nemo_action
--- 6.02-1/nemo-sendto-clamtk-0-04/nemo-sendto-clamtk.nemo_action	2017-10-01 15:31:02.000000000 +0000
+++ 6.03-1/nemo-sendto-clamtk-0-04/nemo-sendto-clamtk.nemo_action	1970-01-01 00:00:00.000000000 +0000
@@ -1,129 +0,0 @@
-# ClamTk, copyright (C) 2004-2017 Dave M
-#
-# This file is part of ClamTk.
-# https://dave-theunsub.github.io/clamtk/
-#
-# ClamTk is free software; you can redistribute it and/or modify it
-# under the terms of either:
-#
-# a) the GNU General Public License as published by the Free Software
-# Foundation; either version 1, or (at your option) any later version, or
-#
-# b) the "Artistic License".
-# nemo-sendto-clamtk.nemo_action 0.04
-[Nemo Action]
-
-Name=Scan for threats...
-
-Exec=clamtk %F
-
-Icon-Name=clamtk
-
-Selection=Any
-
-Label=''
-
-Extensions=any;
-
-Name=Scan for threats...
-Name[af]=Skandeer vir virusse...
-Name[ar]=إمسح للكشف عن الفيروسات
-Name[ast]=Buscar amenaces...
-Name[az]=Təhlükə mövcudluğuna yoxla...
-Name[bg]=Проверка за наличие на заплахи ...
-Name[bs]=Pretraga za virusima...
-Name[cs]=Skenování hrozeb...
-Name[da]=Skan for virus...
-Name[de]=Auf Bedrohungen untersuchen…
-Name[el]=Έλεγχος για ιούς...
-Name[en]=Scan for threats...
-Name[en_AU]=Scan for threats...
-Name[en_CA]=Scan for threats...
-Name[en_GB]=Scan for threats...
-Name[es]=Analizar en busca de amenazas…
-Name[eu]=Eskaneatu birusen bila...
-Name[fi]=Tarkista uhkien varalta...
-Name[fo]=Skanna eftir virus...
-Name[fr]=Rechercher des menaces...
-Name[gl]=Buscar ameazas...
-Name[he]=סריקה לאיתור איומים…
-Name[hr]=Pretraživanje virusa...
-Name[hu]=Vírusok keresése...
-Name[id]=Pindai untuk ancaman...
-Name[it]=Analizza per la ricerca di minacce...
-Name[ja]=ウィルスをスキャンします...
-Name[ko]=위험 요소를 검사합니다...
-Name[ms]=Imbas jika ada ancaman...
-Name[nl]=Scannen op virussen…
-Name[nb]=Skann etter virus...
-Name[nn]=Skann...
-Name[pa]=ਧਮਕਿਯਾੰ ਲਈ ਖੋਜ ਕਰੋ
-Name[pl]=Przeskanuj pliki w poszukiwaniu wirusów...
-Name[pt]=A analizar ameaças...
-Name[pt_BR]=Verificar se há vírus...
-Name[ro]=Scanare pentru amenințări...
-Name[ru]=Проверка на наличие угроз...
-Name[sk]=Skenovanie hrozieb...
-Name[sl]=Preglej za virusi...
-Name[sr@latin]=Skeniranje pretnji...
-Name[sv]=Skanna efter virus...
-Name[te]=వైరస్సుల కోసం సంశోధిస్తున్నది...
-Name[tr]=Virüs taraması yap...
-Name[ug]=ۋىرۇس تەكشۈر…
-Name[uk]=Шукати загрози…
-Name[uz]=Хавф учун текшириш...
-Name[zh_CN]=扫描威胁...
-Name[zh_TW]=掃描威脅...
-GenericName=Virus Scanner
-GenericName[af]=Virus Skandeerder
-GenericName[ar]=ماسح الفيروسات
-GenericName[ast]=Antivirus
-GenericName[az]=Virus axtarışı
-GenericName[bg]=Скенер за вируси
-GenericName[bs]=Virus Skener
-GenericName[ca]=Comprovador de virus
-GenericName[cs]=Antivirový program
-GenericName[da]=Virusscanneren
-GenericName[de]=Virensuche
-GenericName[el]=Ανιχνευτής ιών
-GenericName[en_AU]=Virus Scanner
-GenericName[en_CA]=Virus Scanner
-GenericName[en_GB]=Virus Scanner
-GenericName[eo]=Viruskontrolilo
-GenericName[es]=Analizador de Virus
-GenericName[eu]=Birus eskanerra
-GenericName[fi]=Virustorjuntasovellus
-GenericName[fo]=Virus skannari
-GenericName[fr]=Module de recherche et analyse de virus
-GenericName[gl]=Analizador de virus
-GenericName[he]=סורק וירוסים
-GenericName[hr]=Skener virusa
-GenericName[hu]=Víruskereső
-GenericName[id]=Pemindai Virus
-GenericName[it]=Analizzatore virus
-GenericName[ja]=ウイルススキャナ
-GenericName[ko]=바이러스 검사기
-GenericName[lt]=Virusų suradimo programa
-GenericName[mr]=धमक्या साठी स्कॅन
-GenericName[ms]=Pengimbas Virus
-GenericName[nb]=Virusskanner
-GenericName[nl]=Virusscanner
-GenericName[nl_BE]=Virusscanner
-GenericName[nn]=Virusskannar
-GenericName[pl]=Skaner wirusów
-GenericName[pt]=Verificador de vírus
-GenericName[pt_BR]=Antivírus Escaner
-GenericName[ro]=Scaner pentru viruși
-GenericName[ru]=Проверка на вирусы
-GenericName[sk]=Antivírus
-GenericName[sl]=Virusni pregledovalec
-GenericName[sr@latin]=Virus Skener
-GenericName[sv]=Virusskanner
-GenericName[te]=వైరస్ స్కానర్
-GenericName[th]=โปรแกรมตรวจจับไวรัส
-GenericName[tr]=Virüs Tarayıcı
-GenericName[ug]=ۋﻯﺭۇﺱ ﺕەﻚﺷۈﺭگۈچ
-GenericName[uk]=Антивірусний сканер
-GenericName[uz]=Вирусларни текшириш
-GenericName[zh_CN]=病毒扫描工具
-GenericName[zh_TW]=病毒掃描程式
diff -pruN 6.02-1/nemo-sendto-clamtk-0-04/README.md 6.03-1/nemo-sendto-clamtk-0-04/README.md
--- 6.02-1/nemo-sendto-clamtk-0-04/README.md	2017-10-01 19:39:12.000000000 +0000
+++ 6.03-1/nemo-sendto-clamtk-0-04/README.md	1970-01-01 00:00:00.000000000 +0000
@@ -1,38 +0,0 @@
-README
-------
-(Last updated 1 October 2017)
-
-## About
-
-nemo-sendto-clamtk is a simple plugin to allow a right-click,
-context menu scan of files or folders in nemo, the
-file manager for Cinnamon.
-
-All this plugin does is copy a desktop style file to the
-directory where nemo reads such things.  If this seems redundant,
-that's because it is: this plugin depends on clamtk,
-which already has this directory file. So, it stands to
-reason we should be able to just find that file and
-copy it, rather than having our own copy.
-
-nemo-sendto-clamtk is available for Fedora, CentOS, and
-Debian|Ubuntu - or probably any system that can run Cinnamon.
-
-Link to screenshot:
-* http://imgur.com/YgzL7xH
-
-## Dependencies
-
-clamtk >= 5.00
-nemo
-
-## Important Links
-
-For feature requests or bugs, it's best to use one of the following:
-
-* https://github.com/dave-theunsub/nemo-sendto-clamtk
-* https://bitbucket.org/davem_/nemo-sendto-clamtk/
-
-## Contact
-
-* Dave M, dave.nerd @gmail.com (0x6ADA59DE)
Binary files 6.02-1/po/en_GB.mo and 6.03-1/po/en_GB.mo differ
diff -pruN 6.02-1/po/en_GB.po 6.03-1/po/en_GB.po
--- 6.02-1/po/en_GB.po	2016-11-18 19:13:34.000000000 +0000
+++ 6.03-1/po/en_GB.po	2020-03-22 08:49:32.000000000 +0000
@@ -1,5 +1,5 @@
 # English (United Kingdom) translation for clamtk
-# Copyright (c) Dave M < dave . nerd @ gmail >, 2004-2016.
+# Copyright (c) Dave M < dave . nerd @ gmail >, 2004-2020.
 # This file is distributed under the same license as the clamtk package.
 # Jen Ockwell, Anthony Scarth, Ken Sharp, Will Bickerstaff, ezekiel000,
 # maty, Max Eaves, Vibhav Pant, Anthony Harrington, fossfreedom,
@@ -9,62 +9,66 @@ msgid ""
 msgstr ""
 "Project-Id-Version: clamtk\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2016-11-11 02:42-0600\n"
-"PO-Revision-Date: 2016-11-11 13:09+0000\n"
-"Last-Translator: Anthony Harrington 😁 <untaintableangel@ubuntu.com>\n"
+"POT-Creation-Date: 2019-04-16 02:50-0500\n"
+"PO-Revision-Date: 2020-02-02 20:12+0000\n"
+"Last-Translator: Stephan Woidowski <swoidowski@t-online.de>\n"
 "Language-Team: English (United Kingdom) <en_GB@li.org>\n"
+"Language: English (en_GB)\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2016-11-18 19:08+0000\n"
-"X-Generator: Launchpad (build 18269)\n"
+"X-Launchpad-Export-Date: 2020-03-21 14:52+0000\n"
+"X-Generator: Launchpad (build 3a6db24bbe7280ec09bae73384238390fcc98ad3)\n"
 
-#: lib/Analysis.pm:49 lib/GUI.pm:525 lib/GUI.pm:608 lib/GUI.pm:749
-#: lib/Results.pm:136 lib/Results.pm:209
-msgid "Analysis"
-msgstr "Analysis"
+#: lib/Analysis.pm:66
+msgid "Schedule"
+msgstr "Schedule"
+
+#: lib/Analysis.pm:78 lib/GUI.pm:79 lib/Schedule.pm:66
+msgid "ClamTk Virus Scanner"
+msgstr "ClamTk Virus Scanner"
 
-#: lib/Analysis.pm:72
+#: lib/Analysis.pm:93
 msgid "File Analysis"
 msgstr "File Analysis"
 
-#: lib/Analysis.pm:79 lib/Results.pm:35
+#: lib/Analysis.pm:100 lib/Results.pm:36 lib/Results.pm:41
 msgid "Results"
 msgstr "Results"
 
-#: lib/Analysis.pm:143
+#: lib/Analysis.pm:165
 msgid "Vendor"
 msgstr "Vendor"
 
-#: lib/Analysis.pm:152
+#: lib/Analysis.pm:174
 msgid "Date"
 msgstr "Date"
 
-#: lib/Analysis.pm:161
+#: lib/Analysis.pm:183
 msgid "Result"
 msgstr "Result"
 
-#: lib/Analysis.pm:180
+#: lib/Analysis.pm:202
 msgid "Save results"
 msgstr "Save results"
 
-#: lib/Analysis.pm:196
+#: lib/Analysis.pm:219
 msgid "Check or recheck a file's reputation"
 msgstr "Check or recheck a file's reputation"
 
-#: lib/Analysis.pm:213 lib/GUI.pm:648 lib/Shortcuts.pm:40
+#: lib/Analysis.pm:236 lib/GUI.pm:597 lib/Shortcuts.pm:41
 msgid "Select a file"
 msgstr "Select a file"
 
-#: lib/Analysis.pm:247
+#: lib/Analysis.pm:258
 msgid "Submit file for analysis"
 msgstr "Submit file for analysis"
 
-#: lib/Analysis.pm:268
+#: lib/Analysis.pm:273
 msgid "Uploaded files must be smaller than 32MB"
 msgstr "Uploaded files must be smaller than 32MB"
 
-#: lib/Analysis.pm:287
+#: lib/Analysis.pm:289
 msgid ""
 "No information exists for this file. Press OK to submit this file for "
 "analysis."
@@ -72,351 +76,348 @@ msgstr ""
 "No information exists for this file. Press OK to submit this file for "
 "analysis."
 
-#: lib/Analysis.pm:298 lib/Analysis.pm:618
+#: lib/Analysis.pm:300 lib/Analysis.pm:614
 msgid "Unable to submit file: try again later"
 msgstr "Unable to submit file: try again later"
 
-#: lib/Analysis.pm:310
+#: lib/Analysis.pm:313
 msgid "View or delete previous results"
 msgstr "View or delete previous results"
 
-#: lib/Analysis.pm:336
+#: lib/Analysis.pm:340
 msgid "View file results"
 msgstr "View file results"
 
-#: lib/Analysis.pm:398
+#: lib/Analysis.pm:404
 msgid "Delete file results"
 msgstr "Delete file results"
 
-#: lib/Analysis.pm:471 lib/Analysis.pm:572 lib/Assistant.pm:103
-#: lib/Update.pm:156
+#: lib/Analysis.pm:476 lib/Analysis.pm:570 lib/Assistant.pm:100 lib/Scan.pm:102
+#: lib/Update.pm:155
 msgid "Please wait..."
 msgstr "Please wait..."
 
-#: lib/Analysis.pm:616
+#: lib/Analysis.pm:612
 msgid "File successfully submitted for analysis."
 msgstr "File successfully submitted for analysis."
 
-#: lib/Analysis.pm:676 lib/Analysis.pm:681
+#: lib/Analysis.pm:672 lib/Analysis.pm:677
 msgid "Unable to save file"
 msgstr "Unable to save file"
 
-#: lib/Analysis.pm:690
+#: lib/Analysis.pm:686
 msgid "File has been saved"
 msgstr "File has been saved"
 
-#: lib/App.pm:245
+#: lib/App.pm:246
 msgid "Unknown"
 msgstr "Unknown"
 
-#: lib/App.pm:396 lib/Prefs.pm:172
+#: lib/App.pm:397 lib/Prefs.pm:173
 msgid "Never"
 msgstr "Never"
 
-#: lib/App.pm:454 clamtk-gnome.py:58
+#: lib/App.pm:455
 msgid "Scan for threats..."
 msgstr "Scan for threats..."
 
-#: lib/App.pm:455
+#: lib/App.pm:456
 msgid "Advanced"
 msgstr "Advanced"
 
-#: lib/App.pm:456 lib/GUI.pm:499 lib/GUI.pm:500 lib/GUI.pm:611
+#: lib/App.pm:457 lib/GUI.pm:452 lib/GUI.pm:453 lib/GUI.pm:560
 msgid "Scan a file"
 msgstr "Scan a file"
 
-#: lib/App.pm:457 lib/GUI.pm:504 lib/GUI.pm:505 lib/GUI.pm:614
+#: lib/App.pm:458 lib/GUI.pm:457 lib/GUI.pm:458 lib/GUI.pm:563
 msgid "Scan a directory"
 msgstr "Scan a directory"
 
-#: lib/App.pm:459
+#: lib/App.pm:460 lib/GUI.pm:741
 msgid "ClamTk is a graphical front-end for Clam Antivirus"
 msgstr "ClamTk is a graphical front-end for Clam Antivirus"
 
-#: lib/Assistant.pm:37
+#: lib/Assistant.pm:38
 msgid "Please choose how you will update your antivirus signatures"
 msgstr "Please choose how you will update your antivirus signatures"
 
-#: lib/Assistant.pm:55
+#: lib/Assistant.pm:54
 msgid "My computer automatically receives updates"
 msgstr "My computer automatically receives updates"
 
-#: lib/Assistant.pm:70
+#: lib/Assistant.pm:68
 msgid "I would like to update signatures myself"
 msgstr "I would like to update signatures myself"
 
-#: lib/Assistant.pm:96 lib/Assistant.pm:154
+#: lib/Assistant.pm:93 lib/Assistant.pm:150
 msgid "Press Apply to save changes"
 msgstr "Press Apply to save changes"
 
-#: lib/Assistant.pm:126
+#: lib/Assistant.pm:122
 msgid "Your changes were saved."
 msgstr "Your changes were saved."
 
-#: lib/Assistant.pm:129 lib/Update.pm:175 lib/Update.pm:181
+#: lib/Assistant.pm:125 lib/Update.pm:175 lib/Update.pm:181
 msgid "Error updating: try again later"
 msgstr "Error updating: try again later"
 
-#: lib/GUI.pm:54
+#: lib/GUI.pm:82
 msgid "Virus Scanner"
 msgstr "Virus Scanner"
 
-#: lib/GUI.pm:87
-msgid "ClamTk Virus Scanner"
-msgstr "ClamTk Virus Scanner"
-
-#: lib/GUI.pm:99 lib/GUI.pm:605
-msgid "Help"
-msgstr "Help"
+#: lib/GUI.pm:90
+msgid "Quit"
+msgstr "Quit"
 
-#: lib/GUI.pm:105 lib/GUI.pm:602 lib/Shortcuts.pm:28
+#: lib/GUI.pm:101 lib/GUI.pm:554 lib/Shortcuts.pm:29
 msgid "About"
 msgstr "About"
 
-#: lib/GUI.pm:113
-msgid "Quit"
-msgstr "Quit"
-
-#: lib/GUI.pm:160
+#: lib/GUI.pm:147
 msgid "Updates are available"
 msgstr "Updates are available"
 
-#: lib/GUI.pm:163
+#: lib/GUI.pm:150
 msgid "The antivirus signatures are outdated"
 msgstr "The antivirus signatures are outdated"
 
-#: lib/GUI.pm:166
+#: lib/GUI.pm:153
 msgid "An update is available"
 msgstr "An update is available"
 
-#: lib/GUI.pm:264 lib/GUI.pm:627
+#: lib/GUI.pm:243 lib/GUI.pm:576
 msgid "Settings"
 msgstr "Settings"
 
-#: lib/GUI.pm:265
+#: lib/GUI.pm:244
 msgid "View and set your preferences"
 msgstr "View and set your preferences"
 
-#: lib/GUI.pm:269 lib/GUI.pm:635
+#: lib/GUI.pm:248 lib/GUI.pm:584
 msgid "Whitelist"
 msgstr "Whitelist"
 
-#: lib/GUI.pm:270
+#: lib/GUI.pm:249
 msgid "View or update scanning whitelist"
 msgstr "View or update scanning whitelist"
 
-#: lib/GUI.pm:274 lib/GUI.pm:633
+#: lib/GUI.pm:253 lib/GUI.pm:582
 msgid "Network"
 msgstr "Network"
 
-#: lib/GUI.pm:275
+#: lib/GUI.pm:254
 msgid "Edit proxy settings"
 msgstr "Edit proxy settings"
 
-#: lib/GUI.pm:279 lib/GUI.pm:617
+#: lib/GUI.pm:258 lib/GUI.pm:566 lib/Schedule.pm:54
 msgid "Scheduler"
 msgstr "Scheduler"
 
-#: lib/GUI.pm:280
+#: lib/GUI.pm:259
 msgid "Schedule a scan or signature update"
 msgstr "Schedule a scan or signature update"
 
-#: lib/GUI.pm:349 lib/GUI.pm:629
+#: lib/GUI.pm:320 lib/GUI.pm:578
 msgid "Update"
 msgstr "Update"
 
-#: lib/GUI.pm:350
+#: lib/GUI.pm:321
 msgid "Update antivirus signatures"
 msgstr "Update antivirus signatures"
 
-#: lib/GUI.pm:354 lib/GUI.pm:637
+#: lib/GUI.pm:325 lib/GUI.pm:586
 msgid "Update Assistant"
 msgstr "Update Assistant"
 
-#: lib/GUI.pm:355
+#: lib/GUI.pm:326
 msgid "Signature update preferences"
 msgstr "Signature update preferences"
 
-#: lib/GUI.pm:423 lib/GUI.pm:625 lib/GUI.pm:737 lib/History.pm:38
+#: lib/GUI.pm:386 lib/GUI.pm:574 lib/GUI.pm:686 lib/History.pm:41
 msgid "History"
 msgstr "History"
 
-#: lib/GUI.pm:424
+#: lib/GUI.pm:387
 msgid "View previous scans"
 msgstr "View previous scans"
 
-#: lib/GUI.pm:428 lib/GUI.pm:631 lib/Results.pm:121 lib/Results.pm:194
+#: lib/GUI.pm:391 lib/GUI.pm:580 lib/Results.pm:137 lib/Results.pm:211
 msgid "Quarantine"
 msgstr "Quarantine"
 
-#: lib/GUI.pm:429
+#: lib/GUI.pm:392
 msgid "Manage quarantined files"
 msgstr "Manage quarantined files"
 
-#: lib/GUI.pm:526
+#: lib/GUI.pm:477 lib/GUI.pm:557 lib/GUI.pm:698 lib/Results.pm:152
+#: lib/Results.pm:226
+msgid "Analysis"
+msgstr "Analysis"
+
+#: lib/GUI.pm:478
 msgid "View a file's reputation"
 msgstr "View a file's reputation"
 
-#: lib/GUI.pm:671 lib/GUI.pm:709 lib/Scan.pm:740 lib/Scan.pm:751
+#: lib/GUI.pm:620 lib/GUI.pm:658 lib/Scan.pm:766 lib/Scan.pm:777
 msgid "You do not have permissions to scan that file or directory"
 msgstr "You do not have permissions to scan that file or directory"
 
-#: lib/GUI.pm:685 lib/Shortcuts.pm:46 lib/Whitelist.pm:96
+#: lib/GUI.pm:634 lib/Shortcuts.pm:47 lib/Whitelist.pm:96
 msgid "Select a directory"
 msgstr "Select a directory"
 
-#: lib/GUI.pm:730
+#: lib/GUI.pm:679
 msgid "Configuration"
 msgstr "Configuration"
 
-#: lib/GUI.pm:743
+#: lib/GUI.pm:692
 msgid "Updates"
 msgstr "Updates"
 
-#: lib/GUI.pm:811
-msgid "Please install yelp to view documentation"
-msgstr "Please install yelp to view documentation"
-
-#: lib/GUI.pm:837
+#: lib/GUI.pm:732
 msgid "Homepage"
 msgstr "Homepage"
 
-#: lib/History.pm:74
+#: lib/History.pm:77
 msgid "View"
 msgstr "View"
 
-#: lib/History.pm:144
+#: lib/History.pm:132
 #, perl-format
 msgid "Viewing %s"
 msgstr "Viewing %s"
 
-#: lib/History.pm:160
+#: lib/History.pm:148
 #, perl-format
 msgid "Problems opening %s..."
 msgstr "Problems opening %s..."
 
-#: lib/Network.pm:48
+#: lib/Network.pm:41
 msgid "No proxy"
 msgstr "No proxy"
 
-#: lib/Network.pm:54
+#: lib/Network.pm:46
 msgid "Environment settings"
 msgstr "Environment settings"
 
-#: lib/Network.pm:60
+#: lib/Network.pm:51
 msgid "Set manually"
 msgstr "Set manually"
 
-#: lib/Network.pm:65
+#: lib/Network.pm:55
 msgid "IP address or host"
 msgstr "IP address or host"
 
-#: lib/Network.pm:90
+#: lib/Network.pm:77
 msgid "Port"
 msgstr "Port"
 
-#: lib/Network.pm:271
+#: lib/Network.pm:258
 msgid "Settings saved"
 msgstr "Settings saved"
 
-#: lib/Network.pm:275
+#: lib/Network.pm:262
 msgid "Error"
 msgstr "Error"
 
-#: lib/Quarantine.pm:53
+#: lib/Quarantine.pm:56
 msgid "Number"
 msgstr "Number"
 
-#: lib/Quarantine.pm:61 lib/Results.pm:68
+#: lib/Quarantine.pm:67 lib/Results.pm:78
 msgid "File"
 msgstr "File"
 
-#: lib/Quarantine.pm:74
+#: lib/Quarantine.pm:83
 msgid "Restore"
 msgstr "Restore"
 
-#: lib/Quarantine.pm:110 lib/Results.pm:259
+#: lib/Quarantine.pm:119 lib/Results.pm:276
 #, perl-format
 msgid "Really delete this file (%s) ?"
 msgstr "Really delete this file (%s) ?"
 
-#: lib/Quarantine.pm:171
+#: lib/Quarantine.pm:180
 msgid "Save file as..."
 msgstr "Save file as..."
 
-#: lib/Results.pm:79 lib/Schedule.pm:187
+#: lib/Results.pm:89 lib/Schedule.pm:207
 msgid "Status"
 msgstr "Status"
 
-#: lib/Results.pm:90
+#: lib/Results.pm:100
 msgid "Action Taken"
 msgstr "Action Taken"
 
-#: lib/Results.pm:127 lib/Results.pm:202
+#: lib/Results.pm:143 lib/Results.pm:219
 msgid "Delete"
 msgstr "Delete"
 
-#: lib/Results.pm:148
+#: lib/Results.pm:164
 msgid "Close"
 msgstr "Close"
 
-#: lib/Results.pm:197
+#: lib/Results.pm:214
 msgid "Quarantined"
 msgstr "Quarantined"
 
-#: lib/Results.pm:205
+#: lib/Results.pm:222
 msgid "Deleted"
 msgstr "Deleted"
 
-#: lib/Scan.pm:134
+#: lib/Scan.pm:141
 msgid "Preparing..."
 msgstr "Preparing..."
 
-#: lib/Scan.pm:145 lib/Scan.pm:380
+#: lib/Scan.pm:152 lib/Scan.pm:405
 #, perl-format
 msgid "Files scanned: %d"
 msgstr "Files scanned: %d"
 
-#: lib/Scan.pm:149 lib/Scan.pm:450
+#: lib/Scan.pm:156 lib/Scan.pm:475
 #, perl-format
 msgid "Possible threats: %d"
 msgstr "Possible threats: %d"
 
-#: lib/Scan.pm:363
+#: lib/Scan.pm:388
 #, perl-format
 msgid "Scanning %s..."
 msgstr "Scanning %s..."
 
-#: lib/Scan.pm:448
+#: lib/Scan.pm:473
 msgid "None"
 msgstr "None"
 
-#: lib/Scan.pm:474
+#: lib/Scan.pm:499
 msgid "Cleaning up..."
 msgstr "Cleaning up..."
 
-#: lib/Scan.pm:483
+#: lib/Scan.pm:506 lib/Update.pm:219 lib/Update.pm:222
+msgid "Complete"
+msgstr "Complete"
+
+#: lib/Scan.pm:509
 msgid "Scanning complete"
 msgstr "Scanning complete"
 
-#: lib/Scan.pm:485
+#: lib/Scan.pm:511
 msgid "Possible threats found"
 msgstr "Possible threats found"
 
-#: lib/Scan.pm:527
+#: lib/Scan.pm:553
 msgid "No threats found"
 msgstr "No threats found"
 
-#: lib/Scan.pm:564
+#: lib/Scan.pm:590
 #, perl-format
 msgid "ClamAV Signatures: %d\n"
 msgstr "ClamAV Signatures: %d\n"
 
-#: lib/Scan.pm:566
+#: lib/Scan.pm:592
 msgid "Directories Scanned:\n"
 msgstr "Directories Scanned:\n"
 
-#: lib/Scan.pm:571
+#: lib/Scan.pm:597
 #, perl-format
 msgid ""
 "\n"
@@ -427,79 +428,75 @@ msgstr ""
 "Found %d possible %s (%d %s scanned).\n"
 "\n"
 
-#: lib/Scan.pm:573
+#: lib/Scan.pm:599
 msgid "threat"
 msgstr "threat"
 
-#: lib/Scan.pm:573
+#: lib/Scan.pm:599
 msgid "threats"
 msgstr "threats"
 
-#: lib/Scan.pm:575
+#: lib/Scan.pm:601
 msgid "file"
 msgstr "file"
 
-#: lib/Scan.pm:575
+#: lib/Scan.pm:601
 msgid "files"
 msgstr "files"
 
-#: lib/Scan.pm:587
+#: lib/Scan.pm:613
 msgid "No threats found.\n"
 msgstr "No threats found.\n"
 
-#: lib/Schedule.pm:46
-msgid "Schedule"
-msgstr "Schedule"
-
-#: lib/Schedule.pm:63
+#: lib/Schedule.pm:81
 msgid "Scan"
 msgstr "Scan"
 
-#: lib/Schedule.pm:69
+#: lib/Schedule.pm:88
 msgid "Select a time to scan your home directory"
 msgstr "Select a time to scan your home directory"
 
-#: lib/Schedule.pm:73
+#: lib/Schedule.pm:92
 msgid "Set the scan time using a 24 hour clock"
 msgstr "Set the scan time using a 24 hour clock"
 
-#: lib/Schedule.pm:83 lib/Schedule.pm:139
+#: lib/Schedule.pm:103 lib/Schedule.pm:159
 msgid "Set the hour using a 24 hour clock"
 msgstr "Set the hour using a 24 hour clock"
 
-#: lib/Schedule.pm:84 lib/Schedule.pm:140
+#: lib/Schedule.pm:104 lib/Schedule.pm:160
 msgid "Hour"
 msgstr "Hour"
 
-#: lib/Schedule.pm:91 lib/Schedule.pm:146
+#: lib/Schedule.pm:111 lib/Schedule.pm:166
 msgid "Minute"
 msgstr "Minute"
 
-#: lib/Schedule.pm:122 lib/Update.pm:77 lib/Update.pm:201 lib/Update.pm:219
+#: lib/Schedule.pm:142 lib/Update.pm:80 lib/Update.pm:200 lib/Update.pm:215
 msgid "Antivirus signatures"
 msgstr "Antivirus signatures"
 
-#: lib/Schedule.pm:129
+#: lib/Schedule.pm:149
 msgid "Select a time to update your signatures"
 msgstr "Select a time to update your signatures"
 
-#: lib/Schedule.pm:196 lib/Schedule.pm:258
+#: lib/Schedule.pm:216 lib/Schedule.pm:278
 msgid "A daily scan is scheduled"
 msgstr "A daily scan is scheduled"
 
-#: lib/Schedule.pm:201 lib/Schedule.pm:271
+#: lib/Schedule.pm:221 lib/Schedule.pm:291
 msgid "A daily definitions update is scheduled"
 msgstr "A daily definitions update is scheduled"
 
-#: lib/Schedule.pm:262
+#: lib/Schedule.pm:282
 msgid "A daily scan is not scheduled"
 msgstr "A daily scan is not scheduled"
 
-#: lib/Schedule.pm:276
+#: lib/Schedule.pm:296
 msgid "A daily definitions update is not scheduled"
 msgstr "A daily definitions update is not scheduled"
 
-#: lib/Schedule.pm:285
+#: lib/Schedule.pm:305
 msgid "You are set to automatically receive updates"
 msgstr "You are set to automatically receive updates"
 
@@ -507,78 +504,82 @@ msgstr "You are set to automatically rec
 msgid "Scan for PUAs"
 msgstr "Scan for PUAs"
 
-#: lib/Settings.pm:45
+#: lib/Settings.pm:44
 msgid "Detect packed binaries, password recovery tools, and more"
 msgstr "Detect packed binaries, password recovery tools, and more"
 
-#: lib/Settings.pm:58
+#: lib/Settings.pm:57
 msgid "Scan files beginning with a dot (.*)"
 msgstr "Scan files beginning with a dot (.*)"
 
-#: lib/Settings.pm:60
+#: lib/Settings.pm:58
 msgid "Scan files typically hidden from view"
 msgstr "Scan files typically hidden from view"
 
-#: lib/Settings.pm:73
+#: lib/Settings.pm:71
 msgid "Scan files larger than 20 MB"
 msgstr "Scan files larger than 20 MB"
 
-#: lib/Settings.pm:76
+#: lib/Settings.pm:73
 msgid "Scan large files which are typically not examined"
 msgstr "Scan large files which are typically not examined"
 
-#: lib/Settings.pm:89
+#: lib/Settings.pm:86
 msgid "Scan directories recursively"
 msgstr "Scan directories recursively"
 
-#: lib/Settings.pm:92
+#: lib/Settings.pm:88
 msgid "Scan all files and directories within a directory"
 msgstr "Scan all files and directories within a directory"
 
-#: lib/Settings.pm:105
+#: lib/Settings.pm:101
 msgid "Check for updates to this program"
 msgstr "Check for updates to this program"
 
-#: lib/Settings.pm:108
+#: lib/Settings.pm:103
 msgid "Check online for application and signature updates"
 msgstr "Check online for application and signature updates"
 
-#: lib/Settings.pm:121
-msgid "Double click icons to activate"
-msgstr "Double click icons to activate"
-
-#: lib/Settings.pm:124
-msgid "Uncheck this box to activate icons with single click"
-msgstr "Uncheck this box to activate icons with single click"
-
-#: lib/Shortcuts.pm:34
+#: lib/Shortcuts.pm:35
 msgid "Exit"
 msgstr "Exit"
 
-#: lib/Update.pm:57
+#: lib/Tips.pm:55
+msgid "Next"
+msgstr "Next"
+
+#: lib/Tips.pm:56
+msgid "Show me another tip"
+msgstr "Show me another tip"
+
+#: lib/Tips.pm:78
+msgid "No tips found."
+msgstr "No tips found."
+
+#: lib/Tips.pm:110
+msgid "Helpful information"
+msgstr "Helpful information"
+
+#: lib/Update.pm:60
 msgid "Product"
 msgstr "Product"
 
-#: lib/Update.pm:65
+#: lib/Update.pm:68
 msgid "Installed"
 msgstr "Installed"
 
-#: lib/Update.pm:100
+#: lib/Update.pm:103
 msgid "You are configured to automatically receive updates"
 msgstr "You are configured to automatically receive updates"
 
-#: lib/Update.pm:102
+#: lib/Update.pm:105
 msgid "Check for updates"
 msgstr "Check for updates"
 
-#: lib/Update.pm:193
+#: lib/Update.pm:194
 msgid "Downloading..."
 msgstr "Downloading..."
 
-#: lib/Update.pm:223
-msgid "Complete"
-msgstr "Complete"
-
 #: lib/Whitelist.pm:48
 msgid "Directory"
 msgstr "Directory"
@@ -590,16 +591,3 @@ msgstr "Add a directory"
 #: lib/Whitelist.pm:82
 msgid "Remove a directory"
 msgstr "Remove a directory"
-
-#: clamtk-gnome.py:59
-#, python-format
-msgid "Scan %s for threats..."
-msgstr "Scan %s for threats..."
-
-#: clamtk-gnome.py:70
-msgid "Scan directory for threats..."
-msgstr "Scan directory for threats..."
-
-#: clamtk-gnome.py:71
-msgid "Scan this directory for threats..."
-msgstr "Scan this directory for threats..."
Binary files 6.02-1/po/id.mo and 6.03-1/po/id.mo differ
diff -pruN 6.02-1/po/id.po 6.03-1/po/id.po
--- 6.02-1/po/id.po	2019-09-14 13:09:35.000000000 +0000
+++ 6.03-1/po/id.po	2020-03-22 08:47:05.000000000 +0000
@@ -1,5 +1,5 @@
 # Indonesian translation for clamtk
-# Copyright (c) Dave M < dave DOT nerd AT gmail >, 2004 - 2019
+# Copyright (c) Dave M < dave DOT nerd AT gmail >, 2004 - 2020
 # This file is distributed under the same license as the clamtk package.
 # Hertatijanto Hartono <dvertx@gmail.com>\n"
 # Arief Setiadi Wibowo <q_thrynx@yahoo.com>
@@ -7,18 +7,18 @@
 #
 msgid ""
 msgstr ""
-"Project-Id-Version: clamtk\n"
+"Project-Id-Version: clamtk 6.03\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
 "POT-Creation-Date: 2019-04-16 02:50-0500\n"
-"PO-Revision-Date: 2019-04-05 03:58+0000\n"
+"PO-Revision-Date: 2020-01-25 04:04+0000\n"
 "Last-Translator: Arief Setiadi Wibowo <q_thrynx@yahoo.com>\n"
 "Language-Team: Indonesian <id@li.org>\n"
-"Language: Indonesian\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2019-09-14 12:48+0000\n"
-"X-Generator: Launchpad (build 19048)\n"
+"X-Launchpad-Export-Date: 2020-03-21 14:52+0000\n"
+"X-Generator: Launchpad (build 3a6db24bbe7280ec09bae73384238390fcc98ad3)\n"
+"Language: Indonesian\n"
 
 #: lib/Analysis.pm:66
 msgid "Schedule"
@@ -546,19 +546,19 @@ msgstr "Keluar"
 
 #: lib/Tips.pm:55
 msgid "Next"
-msgstr ""
+msgstr "Selanjutnya"
 
 #: lib/Tips.pm:56
 msgid "Show me another tip"
-msgstr ""
+msgstr "Tunjukkan tips lainnya kepadaku"
 
 #: lib/Tips.pm:78
 msgid "No tips found."
-msgstr ""
+msgstr "Tidak ditemukan tips lainnya"
 
 #: lib/Tips.pm:110
 msgid "Helpful information"
-msgstr ""
+msgstr "informasi bermanfaat"
 
 #: lib/Update.pm:60
 msgid "Product"
Binary files 6.02-1/po/sv.mo and 6.03-1/po/sv.mo differ
diff -pruN 6.02-1/po/sv.po 6.03-1/po/sv.po
--- 6.02-1/po/sv.po	2019-09-14 12:00:52.000000000 +0000
+++ 6.03-1/po/sv.po	2020-03-22 08:45:04.000000000 +0000
@@ -1,5 +1,5 @@
 # ClamTk Swedish language file
-# Copyright (C) Dave M. < dave . nerd @ gmail >, 2004-2019.
+# Copyright (C) Dave M. < dave . nerd @ gmail >, 2004-2020.
 # This file is distributed under the same license as the ClamTk package.
 # First author: Petter Viklund <petter.viklund@gmail.com>, 2007-2010.
 # David Bengtsson
@@ -9,19 +9,19 @@
 #
 msgid ""
 msgstr ""
-"Project-Id-Version: clamtk 6.02\n"
+"Project-Id-Version: clamtk 6.03\n"
 "Report-Msgid-Bugs-To: \n"
 "POT-Creation-Date: 2019-04-16 02:50-0500\n"
-"PO-Revision-Date: 2019-06-26 16:51+0000\n"
-"Last-Translator: Jonatan Nyberg <Unknown>\n"
+"PO-Revision-Date: 2020-01-16 10:48+0000\n"
+"Last-Translator: Anders Jonsson <Unknown>\n"
 "Language-Team: Launchpad Swedish Translators <lp-l10n-"
 "sv@lists.launchpad.net>\n"
-"Language: Swedish\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2019-09-14 11:40+0000\n"
-"X-Generator: Launchpad (build 19048)\n"
+"X-Launchpad-Export-Date: 2020-03-21 14:52+0000\n"
+"X-Generator: Launchpad (build 3a6db24bbe7280ec09bae73384238390fcc98ad3)\n"
+"Language: Swedish\n"
 
 #: lib/Analysis.pm:66
 msgid "Schedule"
@@ -57,7 +57,7 @@ msgstr "Spara resultat"
 
 #: lib/Analysis.pm:219
 msgid "Check or recheck a file's reputation"
-msgstr "Kontrollera eller kontrollera igen en fil rykte"
+msgstr "Kontrollera eller kontrollera igen en fils rykte"
 
 #: lib/Analysis.pm:236 lib/GUI.pm:597 lib/Shortcuts.pm:41
 msgid "Select a file"
@@ -154,7 +154,7 @@ msgstr "Jag skulle vilja uppdatera signa
 
 #: lib/Assistant.pm:93 lib/Assistant.pm:150
 msgid "Press Apply to save changes"
-msgstr "Tryck på Tillämpa för att spara ändringar"
+msgstr "Tryck på Verkställ för att spara ändringar"
 
 #: lib/Assistant.pm:122
 msgid "Your changes were saved."
@@ -309,7 +309,7 @@ msgstr "Ange manuellt"
 
 #: lib/Network.pm:55
 msgid "IP address or host"
-msgstr "IP-address eller värd"
+msgstr "IP-adress eller värd"
 
 #: lib/Network.pm:77
 msgid "Port"
@@ -489,7 +489,7 @@ msgstr "En daglig skanning är schemalag
 
 #: lib/Schedule.pm:221 lib/Schedule.pm:291
 msgid "A daily definitions update is scheduled"
-msgstr "En daglig uppdatering av antivirussignaturer är schemalagd"
+msgstr "En daglig uppdatering av definitioner är schemalagd"
 
 #: lib/Schedule.pm:282
 msgid "A daily scan is not scheduled"
@@ -497,7 +497,7 @@ msgstr "En daglig skanning är inte sche
 
 #: lib/Schedule.pm:296
 msgid "A daily definitions update is not scheduled"
-msgstr "En uppdatering av dagliga definitioner är inte schemalagd"
+msgstr "En daglig uppdatering av definitioner är inte schemalagd"
 
 #: lib/Schedule.pm:305
 msgid "You are set to automatically receive updates"
diff -pruN 6.02-1/README.md 6.03-1/README.md
--- 6.02-1/README.md	2019-03-23 10:22:36.000000000 +0000
+++ 6.03-1/README.md	2020-03-26 13:38:08.000000000 +0000
@@ -1,6 +1,4 @@
-[![Gitter chat](https://badges.gitter.im/gitterHQ/gitter.png)](https://gitter.im/clamtk/Lobby)
-
-This readme file was last updated on 23 March 2019
+This readme file was last updated on 26 March 2020.
 
 # Readme for ClamTk
 
@@ -21,7 +19,14 @@ This readme file was last updated on 23
 
 ClamTk is a frontend for ClamAV (Clam Antivirus). It is intended to be an easy to use, light-weight, on-demand scanner for Linux systems. It has been ported to Fedora, Debian, RedHat, openSUSE, ALT Linux, Ubuntu, CentOS, Gentoo, Archlinux, Mandriva, PCLinuxOS, Frugalware, FreeBSD, and others.
 
-Although its earliest incarnations date to 2003, ClamTk was first uploaded for distribution in 2004 to a rootshell.be account and finally to Sourceforge.net in 2005. At the end of 2013, it was moved to a Google Code page (then to github), then gitlab and Bitbucket. It's now 2019 and for some reason, it's still going. In fact, February 2019 marks 15 years of activity (of being publically available, that is).
+Although its earliest incarnations date to 2003, ClamTk was first uploaded for distribution in 2004 to a rootshell.be account and finally to Sourceforge.net in 2005. At the end of 2013, it was moved to a Google Code page (then to github), then gitlab and Bitbucket. It's now 2020 and for some reason, it's still going. In fact, February 2020 marks 16 years of activity (of being publically available, that is).
+
+
+## Plans
+
+Version 7 will likely have a new design, and will almost certainly use a different language.  
+
+Also, clamtk-notify is in the works - a program that will watch a directory (or directories) for downloads and scan them automatically.  
 
 
 ### Important Links
@@ -30,43 +35,41 @@ ClamTk:
 https://gitlab.com/dave_m/clamtk-gtk3/  
 https://bitbucket.org/davem_/clamtk-gtk3/  
 https://gitlab.com/dave_m/clamtk/wikis/home  
+https://launchpad.net/clamtk  
 https://code.google.com/p/clamtk/ (not used anymore)  
 http://clamtk.sourceforge.net (not used anymore)  
 https://dave-theunsub.github.io/clamtk/ (deprecated)  
 https://github.com/dave-theunsub/clamtk/ (deprecated)  
 
-Launchpad ClamTk:  
-https://launchpad.net/clamtk
-
-ClamAV:  
-https://www.clamav.net
-
-Gtk2-Perl:  
-http://gtk2-perl.sourceforge.net
-
-Gtk3:  
-https://developer.gnome.org/gtk3/stable/index.html
-
-Virustotal:  
-https://virustotal.com
+[ClamAV](https://www.clamav.net)  
+[Gtk2-Perl](http://gtk2-perl.sourceforge.net)  
+[Gtk3](https://developer.gnome.org/gtk3/stable/index.html)  
+[Virustotal](https://virustotal.com)  
 
 
 ## Installation  
 
 ### RPMs  
-The easiest way to install ClamTk is to use the rpms. Note: The `dnf` (which is now used by Fedora) command instructions are the same as the `yum` instructions below (just switch out `yum` for `dnf` if that's what your system is using):  
+The easiest way to install ClamTk is to use the rpms. The commands `dnf` and `yum` will pull in any requirements.   
   
-First, try `yum install clamtk`. If this does not work,
-download it and try:  
+First, start with the official repositories.
 
-`# yum install clamtk*.rpm`
+`sudo yum install clamtk` or `sudo dnf install clamtk`.  
+
+If this does not work, download the file from [the official site](https://gitlab.com/dave_m/clamtk/-/wikis/Home). 
+
+From a terminal window:  
+
+`sudo yum install clamtk*.rpm` or `sudo dnf install clamtk*.rpm`
 
 To remove clamtk:  
   
-`# yum erase clamtk`
+`sudo yum erase clamtk` or `sudo dnf erase clamtk`.
 
-### Source
-Warning: Don't do this. It's much easier to just double-click a .deb or .rpm. Really, put down the source. The tarball contains all the sources. One way to do this on Fedora:  
+### Source  
+**Warning**: Don't do this. It's much easier to just double-click a .deb or .rpm. Really, put down the source. 
+
+The tarball contains all the sources. One way to do this, as tested on Fedora, is to run the following commands:  
 
 ```
 mkdir -p /usr/share/perl5/vendor_perl/ClamTk  
@@ -91,13 +94,13 @@ or
 
 You should be able to just double-click the .deb file to install it. This assumes you have permissions to install programs, of course. Your package manager should grab any necessary dependencies.
 
-By the commandline, you can do this:  
+From the commandline, you can do this:  
 
-    # apt install clamtk-*.deb
+    sudo apt install clamtk-*.deb
 
 To remove clamtk:  
 
-    # dpkg --purge clamtk
+    sudo dpkg --purge clamtk
 
 Note that the Debian/Ubuntu builds are and have always been gpg-signed.
 
@@ -107,31 +110,43 @@ It is recommended you install ClamTk fro
 
 While the Debian/Ubuntu .debs have always been digitally signed, the rpms have not. Beginning with 5.22, you can once again check the rpm's signature to verify its integrity. Here's one way:
 
-1. Get and import the key in one step: `rpm --import https://davem.fedorapeople.org/RPM-GPG-KEY-DaveM-21-June-2018`
-2. Verify the list of gpg keys installed in RPM DB: `rpm -q gpg-pubkey --qf '%{name}-%{version}-%{release} --> %{summary}\n'`
-3. Check the signature of the rpm. For this example, we'll use version 5.25: `rpm --checksig clamtk-5.25-1.fc.noarch.rpm`
-4. You should see something like this: `/home/you/clamtk-5.25-1.fc.noarch.rpm: rsa sha1 (md5) pgp md5 OK`
-
-You can also verify the tarball. Using 5.22 as the example version, ensure you have downloaded the tarball, its detached signature (.asc), and the key in step 1 above.
+1. Get and import the key in one step:  
+`rpm --import https://davem.fedorapeople.org/RPM-GPG-KEY-DaveM-21-June-2018`  
+2. Verify the list of gpg keys installed in RPM DB:  
+`rpm -q gpg-pubkey --qf '%{name}-%{version}-%{release} --> %{summary}\n'`  
+3. Check the signature of the rpm. For this example, we'll use version 6.03:  
+`rpm --checksig clamtk-6.03-1.fc.noarch.rpm`  
+4. You should see something like this:  
+`/home/you/clamtk-6.03-1.fc.noarch.rpm: rsa sha1 (md5) pgp md5 OK`
+
+You can also verify the tarball. Using 6.03 as the example version, ensure you have downloaded the tarball, its detached signature (.asc), and the key in step 1 above.
+
+1. Get the key (skip this step if you already have it):  
+`wget https://davem.fedorapeople.org/RPM-GPG-KEY-DaveM-21-June-2018`.
+2. Import it (skip this step if you have done it already):  
+`gpg --import RPM-GPG-KEY-DaveM-21-June-2018`.
+3. Verify like so:  
+`gpg2 --verify clamtk-6.03.tar.xz.asc clamtk-6.03.tar.gz` or  
+`gpg --verify clamtk-6.03.tar.xz.asc clamtk-6.03.tar.xz`.
+4. You should see something like this:  
+`gpg: Signature made Sun 11 Sep 2016 06:29:41 AM CDT using RSA key ID` (snipped for brevity).  
+
+You can now use minisign, too!  
+[Minisign](https://jedisct1.github.io/minisign/)  
+
+First, you will need my public minisign key:  
+[Public minisign key](https://davem.fedorapeople.org/davemminisign.pub)  
 
-1. Get the key (skip if you already have it): `wget https://davem.fedorapeople.org/RPM-GPG-KEY-DaveM-21-June-2018`
-2. Import it (skip if you have done it already): `gpg --import RPM-GPG-KEY-DaveM-21-June-2018`
-3. Verify `gpg2 --verify clamtk-5.27.tar.xz.asc clamtk-5.27.tar.gz` or `gpg --verify clamtk-5.27.tar.gz.asc clamtk-5.27.tar.gz`
-4. You should see something like this: `gpg: Signature made Sun 11 Sep 2016 06:29:41 AM CDT using RSA key ID` (snipped for brevity)  
+Then, you will need the minisig file for the program you are verifying.  
 
-Guess what? You can always use minisign, too!  
-https://jedisct1.github.io/minisign/
+A link to it will be with the rest of the downloads. 
 
-First, you'll need my public minisign key:  
-https://davem.fedorapeople.org/davemminisign.pub
+For this example:  
+https://bitbucket.org/davem_/clamtk-gtk3/downloads/clamtk-6.03.tar.xz.minisig
 
-Then, you'll need the minisig file for the program you're verifying.
-A link to it will be with the rest of the downloads. For this example:  
-https://bitbucket.org/davem_/clamtk-gtk3/downloads/clamtk-6.00.tar.xz.minisig
-
-Now, you can verify like so:  
+Now, you verify like so:  
 ```
-minisign -V -x clamtk-6.00.tar.xz.minisig -p davemminisign.pub -m clamtk-6.00.tar.xz
+minisign -V -x clamtk-6.03.tar.xz.minisig -p davemminisign.pub -m clamtk-6.03.tar.xz
 ```
 
 
@@ -139,21 +154,21 @@ minisign -V -x clamtk-6.00.tar.xz.minisi
 
 ### Running ClamTk
 
-* Beginning with version 4.23, ClamTk will automatically search for signatures if you do not have them set already. This way ClamTk should work right out of the box, with no prompting.
+* Beginning with version 4.23, ClamTk will automatically search for signatures if you do not have them set already. This way ClamTk should work right out of the box, with no prompting.  
 * Consider the extra scanning options in Settings.
-  * Select "Scan files beginning with a dot (.*)" to scan those files beginning with a ".".  These are sometimes referred to as "hidden" files.
-  * Select "Scan directories recursively" to scan all files and directories within a directory.
-  * The "Scan for PUAs" option enables the ability to scan for Potentially Unwanted Applications as well as broken executables.  Note that this can result in what may be false positives.
-  * By default, ClamTk will avoid scanning files larger than 20MB. To force scanning of these files, check the "Scan files larger than 20 MB" box.
-  * You can also check for updates upon startup.  This requires an active Internet connection.
-* Information on items quarantined is available under the "Quarantine" option.  If you believe there is a false positive contained, you can easily move it back to your home directory. You may also delete this file(s). Note that there is no recycle bin - once deleted, they are gone forever.
+  * Select "Scan files beginning with a dot (.*)" to scan those files beginning with a ".".  These are sometimes referred to as "hidden" files.  
+  * Select "Scan directories recursively" to scan all files and directories within a directory.  
+  * The "Scan for PUAs" option enables the ability to scan for Potentially Unwanted Applications as well as broken executables.  Note that this can result in what may be false positives.  
+  * By default, ClamTk will avoid scanning files larger than 20MB. To force scanning of these files, check the "Scan files larger than 20 MB" box.  
+  * You can also check for updates upon startup.  This requires an active Internet connection.  
+* Information on items quarantined is available under the "Quarantine" option.  If you believe there is a false positive contained, you can easily move it back to your home directory. You may also delete this file(s). *Note that there is no recycle bin - once deleted, they are gone forever.*    
 * Scan a file or directory by right-clicking on it within the file manager (e.g., Nautilus).  This functionality requires an extra package (clamtk-gnome).
-* You can STOP the scan by clicking the Cancel button. Note that due to the speed of the scanning, it may not stop immediately; it will continue scanning and displaying files it has already "read" until the stop catches up.
-* View previous scans by selecting "History".
-* The Update Assistant is necessary because some systems are set up to do automatic updates, while others must manually update them.
-* If you require specific proxy settings, select "Network".
-* As of version 5.xx, you can use the "Analysis" button to see if a particular file is considered malicious by other antivirus products. This uses results from Virustotal. If you desire, you can submit a file for further review. Please do *not* submit personal files.
-* The "Whitelist" option provides the ability to skip specific directories during scan time. For example, you may wish to skip directories containing music or videos.
+* You can STOP the scan by clicking the Cancel button. Note that due to the speed of the scanning, it may not stop immediately; it will continue scanning and displaying files it has already "read" until the stop catches up.  
+* View previous scans by selecting "History".  
+* The Update Assistant is necessary because some systems are set up to do automatic updates, while others must manually update them.  
+* If you require specific proxy settings, select "Network".  
+* As of version 5.xx, you can use the "Analysis" button to see if a particular file is considered malicious by other antivirus products. This uses results from Virustotal. If you desire, you can submit a file for further review. Please do *not* submit personal files.  
+* The "Whitelist" option provides the ability to skip specific directories during scan time. For example, you may wish to skip directories containing music or videos.  
 
 ### Commandline
 
@@ -166,17 +181,17 @@ or
 clamtk directory_to_be_scanned  
 ```
   
-However, the main reason for the commandline option (though basic) is to allow for right-click scanning within your file manager (e.g., Nautilus or Dolphin).  If you want more extensive commandline options, it is recommended that you use the clamscan binary itself. (Type `man clamscan` at the commandline.) Or, if you know of something useful, let me know and I can add it as an option.
+However, the main reason for the commandline option (though basic) is to allow for right-click scanning within your file manager (e.g., Files, Caja, or Dolphin).  If you require more extensive commandline options, it is recommended that you use the clamscan executable itself. (Type `man clamscan` at the commandline.)  
 
 ### Afterwards
 
-You can view and delete scan logs by selecting the "History" option.
+You can view and delete scan logs by selecting the "History" option.  
 
-You also have a few options with the files displayed. Click on the file scanned to select it, then right-click: you should have four options there.
+You also have a few options with the files displayed. Click on the file scanned to select it, then right-click: you should have four options there.  
 
-* Quarantine this file: This drops the selected file into a "quarantined" folder with the executable bit removed. The quarantine folder is held in the user's ClamTk folder (`~/.clamtk/viruses`).
-* Delete this file: Be careful: There's no recycle bin!
-* Cancel: Cancels this menu.
+* Quarantine this file: This drops the selected file into a "quarantined" folder with the executable bit removed. The quarantine folder is held in the user's ClamTk folder (`~/.clamtk/viruses`).  
+* Delete this file: Be careful: There's no recycle bin!  
+* Cancel: Cancels this menu.  
 
 ### Quarantine/Maintenance
 
@@ -192,10 +207,13 @@ Here are the specific pages:
   
 For Gnome (Files file manager):  
 https://gitlab.com/dave_m/clamtk-gnome  
+
 For KDE (Dolphin file manager):  
 https://gitlab.com/dave_m/clamtk-kde  
+
 For XFCE (Thunar file manager):  
 https://gitlab.com/dave_m/thunar-sendto-clamtk  
+
 For MATE (Nemo file manager):  
 https://gitlab.com/dave_m/nemo-sendto-clamtk  
   
@@ -215,7 +233,7 @@ https://gitlab.com/dave_m/nemo-sendto-cl
 
 * Are you using the source and you see something like this: Can't locate Foo/Bar.pm in @INC... (etc, etc).
 
-  This means you are missing some of the dependencies. Try to find the dependency through your distribution's repositories, or simply go to http://search.cpan.org. Always try your distribution's repo first. It's more than likely your distribution already packages these for easy installation. Depending on your distro, you will likely use "yum" or "apt" or some "Update Manager" and the like.
+  This means you are missing some of the dependencies. Try to find the dependency through your distribution's repositories, or simply go to [CPAN](https://metacpan.org/). Always try your distribution's repository first. It is more than likely your distribution already packages these for easy installation. Depending on your distro, you will likely use `yum`, `dnf`, `apt` or some "Update Manager" and the like.
 
 * I can't right click on files/directories to scan anymore!
 
@@ -223,14 +241,14 @@ https://gitlab.com/dave_m/nemo-sendto-cl
 
 ### Limitations/Bugs
 
-Probably a lot. Let me know, please. Ranting on some bulletin board somewhere on one of dozens of Linux sites will not improve things. See the section below for contact info.
+Probably a lot. Let me know, please. Ranting on some bulletin board somewhere on one of dozens of Linux sites will not fix bugs or improve the program. See the section below for contact info.
 
 
 ## Contributing
 
 ### Locale/Internationalization
 
-Version 2.20 is the first ClamTk version to offer this. Have time on your hands and want to contribute? See the Launchpad page at https://launchpad.net/clamtk
+ClamTk has supported multiple languages for many years now. Have time on your hands and want to contribute? See the [Launchpad page](https://launchpad.net/clamtk).
 
 Note that some builds do not account for other than English languages because they have not yet updated their build/spec files. A polite email to the respective maintainer may fix this.
 
@@ -239,7 +257,7 @@ Note that some builds do not account for
 
 As of version 3.10, ClamTk will not scan standard mail directories, such as .evolution, .mozilla or .thunderbird. This is due to parsing problems. If a smart way of doing that comes up, it will be added.
 
-Also, please note that version numbers mean absolutely nothing. There is no rhyme or reason to odd or even numbers (i.e., an odd number does not mean "unstable"). A new version means it goes up 1 (or, rather, .01). Version 6.xx, still in development, will likely use the Gtk3 libraries.
+Also, please note that version numbers mean absolutely nothing. There is no rhyme or reason to odd or even numbers (i.e., an odd number does not mean "unstable"). A new version means it goes up 1 (or, rather, .01).  
 
 ### GUI
 
@@ -247,7 +265,7 @@ ClamTk started out using the Tk librarie
 
 The plan for the 5.xx series was to use Gtk3. Unfortunately, Debian and Ubuntu did not have a recent version of libgtk3-perl, and CentOS did not have perl-Gtk3. So, at the last second, the 5.00 version was rewritten to use Gtk2. Again.
 
-Version 6.xx has been written to use Gtk3, as Gtk2 is mostly deprecated. There's no new design this time, as this was an effort to ensure the Gtk3 version could be included in upcoming releases (such as with Debian). It is planned to put the 6.xx series in its own git repository, so that the older 5.xx series will still be there for distros that do not have Gtk3.
+Version 6.xx has been written to use Gtk3, as Gtk2 is deprecated. There's no new design this time, as this was an effort to ensure the Gtk3 version could be included in upcoming distribution releases (such as with Debian). The 6.xx series is in its own git repository (usually clamtk-gtk3), so that the older 5.xx series will still be there for distros that do not have Gtk3.
 
 Version 7.xx will likely have a new design, and may be written in a different language as well.
 
@@ -256,13 +274,13 @@ And there's also a Gtk4 in the works...
 
 ## Thank you
 
-Many people have contributed their time, energy, opinions, recommendations, and expertise to this software. I cannot thank them enough. Their names are listed in the [credits.md file](credits.md)
+Many people have contributed their time, energy, opinions, recommendations, and expertise to this software. I cannot thank them enough. Their names are listed in the credits file.
 
 Also a big thank you to:
 * Everyone who has contributed in one way or another to ClamTk - including language files, bug notifications, and feature requests
 * Dag, without whom rpms would likely not exist
 * All the gtk2-perl and gtk3-perl folks for their time and effort
-* Perlmonks.org for helping me learn the wonderful Perl language - and continuing to do so on a daily basis!
+* [Perlmonks](https://perlmonks.org), for helping me learn the wonderful Perl language - and continuing to do so on a daily basis!
 
 
 ## Contact
@@ -274,9 +292,5 @@ https://launchpad.net/clamtk
   
 While we recommend opening an official bug on the appropriate page, we'll also accept emails:  
 
-* Dave M, dave.nerd AT gmail (0x6ADA59DE)  
-* Tord D, tord.dellsen AT gmail  
-
-    <!-->
-~ You can also [chat with us on gitter](https://gitter.im/clamtk/Lobby)
--->
+* Dave M, dave.nerd at gmail (0x6ADA59DE)  
+* Tord D, tord.dellsen at gmail  
\ No newline at end of file
diff -pruN 6.02-1/thunar-sendto-clamtk/CHANGES 6.03-1/thunar-sendto-clamtk/CHANGES
--- 6.02-1/thunar-sendto-clamtk/CHANGES	1970-01-01 00:00:00.000000000 +0000
+++ 6.03-1/thunar-sendto-clamtk/CHANGES	2017-09-30 04:48:30.000000000 +0000
@@ -0,0 +1,33 @@
+CHANGES for thunar-sendto-clamtk:
+
+0.06 - 29 Sep 2017
+------------------
+    * Updated strings: Romanian (ro), English (en_AU),
+        Italian (it), Korean (ko_KR), Afrikaans (af), English (en_AU),
+        Esperanto (eo), Basque (eu), Punjabi (pa)
+    * Updated documentation and links
+    * Change compression gz -> xz
+
+0.05 - 15 Mar 2014
+------------------
+    * Updated strings: Dutch (nl), Czech (cs), Punjabi (pa),
+    Serbian Latin (sr@latin), Marathi (mr), Brazilian
+    Portuguese (pt_BR), Portuguese (pt), French (fr),
+    probably others
+
+0.04 - 6 Nov 2013
+------------------
+    * Updated all files.
+
+0.03 - 20 Apr 2012
+------------------
+    * Updated language fields.
+    * Updated LICENSE file.
+
+0.02 - 12 Aug 2011
+------------------
+    * Lots of updates: languages and fields.
+
+0.01 - 3 July 2010
+------------------
+    * Initial release.
diff -pruN 6.02-1/thunar-sendto-clamtk/DISCLAIMER 6.03-1/thunar-sendto-clamtk/DISCLAIMER
--- 6.02-1/thunar-sendto-clamtk/DISCLAIMER	1970-01-01 00:00:00.000000000 +0000
+++ 6.03-1/thunar-sendto-clamtk/DISCLAIMER	2010-06-26 16:38:53.000000000 +0000
@@ -0,0 +1,14 @@
+This software (thunar-sendto-clamtk) is provided 'as is' without
+warranty of any kind, either expressed or implied, including, but
+not limited to, the implied warranties of fitness for a purpose,
+or the warranty of non-infringement.
+
+Without limiting the foregoing, there is no warranty that:
+
+   1. the software will meet your requirements
+   2. the software will be uninterrupted, timely, secure or error-free
+   3. the results that may be obtained from the use of the software will
+      be effective, accurate or reliable
+   4. the quality of the software will meet your expectations
+
+Having said that, I do my best to make it as good as I can. Really.
diff -pruN 6.02-1/thunar-sendto-clamtk/LICENSE 6.03-1/thunar-sendto-clamtk/LICENSE
--- 6.02-1/thunar-sendto-clamtk/LICENSE	1970-01-01 00:00:00.000000000 +0000
+++ 6.03-1/thunar-sendto-clamtk/LICENSE	2017-09-30 04:09:49.000000000 +0000
@@ -0,0 +1,19 @@
+COPYRIGHT AND LICENCE
+
+thunar-sendto-clamtk, copyright (C) 2010-2017 Dave M 
+
+https://github.com/dave-theunsub/thunar-sendto-clamtk
+https://gitlab.com/dave_m/thunar-sendto-clamtk
+https://bitbucket.org/davem_/thunar-sendto-clamtk/
+http://thunar.xfce.org
+http://standards.freedesktop.org/desktop-entry-spec/latest/
+<dave.nerd AT gmail.com>
+
+All rights reserved.  This program is free software; you can
+redistribute it and/or modify it under the terms of either:
+
+a) the GNU General Public License as published by the Free
+Software Foundation;
+either version 1, or (at your option) any later version, or
+
+b) the "Artistic License". 
diff -pruN 6.02-1/thunar-sendto-clamtk/README 6.03-1/thunar-sendto-clamtk/README
--- 6.02-1/thunar-sendto-clamtk/README	1970-01-01 00:00:00.000000000 +0000
+++ 6.03-1/thunar-sendto-clamtk/README	2017-09-30 04:11:52.000000000 +0000
@@ -0,0 +1,40 @@
+README
+------
+(Last updated 29 Sept 2017)
+
+thunar-sendto-clamtk is a simple plugin to allow a right-click,
+context menu scan of files or folders in Thunar, XFCE's file manager.
+
+All this plugin does is copy a desktop file to Thunar's send-to
+directory.  If this seems redundant, that's because it is:
+this plugin depends on clamtk, which already has this directory
+file. So, it stands to reason we should be able to just find that
+file and copy it, rather than having our own copy.
+
+thunar-sendto-clamtk is available for Fedora, CentOS, and Debian/
+Ubuntu - or probably any system that can run XFCE.  It is also
+now available via Fedora's official repositories.
+
+DEPENDENCIES
+------------
+
+clamtk >= 5.00
+Thunar
+
+LINKS
+-----
+https://dave-theunsub.github.io/clamtk/
+https://github.com/dave-theunsub/thunar-sendto-clamtk
+https://gitlab.com/dave_m/thunar-sendto-clamtk
+https://bitbucket.org/davem_/thunar-sendto-clamtk/
+http://thunar.xfce.org
+http://standards.freedesktop.org/desktop-entry-spec/latest/
+
+Screenshot:
+https://i.imgur.com/2l1Ct1h.png
+
+CONTACT
+-------
+
+Dave M, dave.nerd @ gmail .com
+0x6ADA59DE
Binary files 6.02-1/thunar-sendto-clamtk/thunar-sendto-clamtk.1.gz and 6.03-1/thunar-sendto-clamtk/thunar-sendto-clamtk.1.gz differ
diff -pruN 6.02-1/thunar-sendto-clamtk/thunar-sendto-clamtk.desktop 6.03-1/thunar-sendto-clamtk/thunar-sendto-clamtk.desktop
--- 6.02-1/thunar-sendto-clamtk/thunar-sendto-clamtk.desktop	1970-01-01 00:00:00.000000000 +0000
+++ 6.03-1/thunar-sendto-clamtk/thunar-sendto-clamtk.desktop	2017-09-30 04:35:23.000000000 +0000
@@ -0,0 +1,114 @@
+# thunar-sendto-clamtk 0.06
+[Desktop Entry]
+Name=ClamTk
+GenericName=Virus Scanner
+GenericName[af]=Virus Skandeerder
+GenericName[ar]=ماسح الفيروسات
+GenericName[ast]=Antivirus
+GenericName[az]=Virus axtarışı
+GenericName[bg]=Скенер за вируси
+GenericName[bs]=Virus Skener
+GenericName[ca]=Comprovador de virus
+GenericName[cs]=Antivirový program
+GenericName[da]=Virusscanneren
+GenericName[de]=Virensuche
+GenericName[el]=Ανιχνευτής ιών
+GenericName[en_AU]=Virus Scanner
+GenericName[en_CA]=Virus Scanner
+GenericName[en_GB]=Virus Scanner
+GenericName[eo]=Viruskontrolilo
+GenericName[es]=Analizador de Virus
+GenericName[eu]=Birus eskanerra
+GenericName[fi]=Virustorjuntasovellus
+GenericName[fo]=Virus skannari
+GenericName[fr]=Module de recherche et analyse de virus
+GenericName[gl]=Analizador de virus
+GenericName[he]=סורק וירוסים
+GenericName[hr]=Skener virusa
+GenericName[hu]=Víruskereső
+GenericName[id]=Pemindai Virus
+GenericName[it]=Analizzatore virus
+GenericName[ja]=ウイルススキャナ
+GenericName[ko]=바이러스 검사기
+GenericName[lt]=Virusų suradimo programa
+GenericName[mr]=धमक्या साठी स्कॅन
+GenericName[ms]=Pengimbas Virus
+GenericName[nb]=Virusskanner
+GenericName[nl]=Virusscanner
+GenericName[nl_BE]=Virusscanner
+GenericName[nn]=Virusskannar
+GenericName[pa]=ਵਿਸ਼ਾਣੂ ਖੋਜੀ"
+GenericName[pl]=Skaner wirusów
+GenericName[pt]=Verificador de vírus
+GenericName[pt_BR]=Antivírus Escaner
+GenericName[ro]=Scaner pentru viruși
+GenericName[ru]=Проверка на вирусы
+GenericName[sk]=Antivírus
+GenericName[sl]=Virusni pregledovalec
+GenericName[sr@latin]=Virus Skener
+GenericName[sv]=Virusskanner
+GenericName[te]=వైరస్ స్కానర్
+GenericName[th]=โปรแกรมตรวจจับไวรัส
+GenericName[tr]=Virüs Tarayıcı
+GenericName[ug]=ۋﻯﺭۇﺱ ﺕەﻚﺷۈﺭگۈچ
+GenericName[uk]=Антивірусний сканер
+GenericName[uz]=Вирусларни текшириш
+GenericName[zh_CN]=病毒扫描工具
+GenericName[zh_TW]=病毒掃描程式
+Comment=Scan for threats...
+Comment[af]=Skandeer vir virusse...
+Comment[ar]=إمسح للكشف عن الفيروسات
+Comment[ast]=Buscar amenaces...
+Comment[az]=Təhlükə mövcudluğuna yoxla...
+Comment[bg]=Проверка за наличие на заплахи ...
+Comment[bs]=Pretraga za virusima...
+Comment[cs]=Skenování hrozeb...
+Comment[da]=Skan for virus...
+Comment[de]=Auf Bedrohungen untersuchen…
+Comment[el]=Έλεγχος για ιούς...
+Comment[en]=Scan for threats...
+Comment[en_AU]=Scan for threats...
+Comment[en_CA]=Scan for threats...
+Comment[en_GB]=Scan for threats...
+Comment[es]=Analizar en busca de amenazas…
+Comment[eu]=Eskaneatu birusen bila...
+Comment[fi]=Tarkista uhkien varalta...
+Comment[fo]=Skanna eftir virus...
+Comment[fr]=Rechercher des menaces...
+Comment[gl]=Buscar ameazas...
+Comment[he]=סריקה לאיתור איומים…
+Comment[hr]=Pretraživanje virusa...
+Comment[hu]=Vírusok keresése...
+Comment[id]=Pindai untuk ancaman...
+Comment[it]=Analizza per la ricerca di minacce...
+Comment[ja]=ウィルスをスキャンします...
+Comment[ko]=위험 요소를 검사합니다...
+Comment[ms]=Imbas jika ada ancaman...
+Comment[nl]=Scannen op virussen…
+Comment[nb]=Skann etter virus...
+Comment[nn]=Skann...
+Comment[pa]=ਧਮਕਿਯਾੰ ਲਈ ਖੋਜ ਕਰੋ
+Comment[pl]=Przeskanuj pliki w poszukiwaniu wirusów...
+Comment[pt]=A analizar ameaças...
+Comment[pt_BR]=Verificar se há vírus...
+Comment[ro]=Scanare pentru amenințări...
+Comment[ru]=Проверка на наличие угроз...
+Comment[sk]=Skenovanie hrozieb...
+Comment[sl]=Preglej za virusi...
+Comment[sr@latin]=Skeniranje pretnji...
+Comment[sv]=Skanna efter virus...
+Comment[te]=వైరస్సుల కోసం సంశోధిస్తున్నది...
+Comment[tr]=Virüs taraması yap...
+Comment[ug]=ۋىرۇس تەكشۈر…
+Comment[uk]=Шукати загрози…
+Comment[uz]=Хавф учун текшириш...
+Comment[zh_CN]=扫描威胁...
+Comment[zh_TW]=掃描威脅...
+TryExec=clamtk
+Exec=clamtk %F
+Icon=clamtk
+Type=Application
+Terminal=false
+StartupNotify=true
+Keywords=antivirus;virus;malware;scan;scanner;
+OnlyShowIn=XFCE;
diff -pruN 6.02-1/thunar-sendto-clamtk-0-06/CHANGES 6.03-1/thunar-sendto-clamtk-0-06/CHANGES
--- 6.02-1/thunar-sendto-clamtk-0-06/CHANGES	2017-09-30 04:48:30.000000000 +0000
+++ 6.03-1/thunar-sendto-clamtk-0-06/CHANGES	1970-01-01 00:00:00.000000000 +0000
@@ -1,33 +0,0 @@
-CHANGES for thunar-sendto-clamtk:
-
-0.06 - 29 Sep 2017
-------------------
-    * Updated strings: Romanian (ro), English (en_AU),
-        Italian (it), Korean (ko_KR), Afrikaans (af), English (en_AU),
-        Esperanto (eo), Basque (eu), Punjabi (pa)
-    * Updated documentation and links
-    * Change compression gz -> xz
-
-0.05 - 15 Mar 2014
-------------------
-    * Updated strings: Dutch (nl), Czech (cs), Punjabi (pa),
-    Serbian Latin (sr@latin), Marathi (mr), Brazilian
-    Portuguese (pt_BR), Portuguese (pt), French (fr),
-    probably others
-
-0.04 - 6 Nov 2013
-------------------
-    * Updated all files.
-
-0.03 - 20 Apr 2012
-------------------
-    * Updated language fields.
-    * Updated LICENSE file.
-
-0.02 - 12 Aug 2011
-------------------
-    * Lots of updates: languages and fields.
-
-0.01 - 3 July 2010
-------------------
-    * Initial release.
diff -pruN 6.02-1/thunar-sendto-clamtk-0-06/DISCLAIMER 6.03-1/thunar-sendto-clamtk-0-06/DISCLAIMER
--- 6.02-1/thunar-sendto-clamtk-0-06/DISCLAIMER	2010-06-26 16:38:53.000000000 +0000
+++ 6.03-1/thunar-sendto-clamtk-0-06/DISCLAIMER	1970-01-01 00:00:00.000000000 +0000
@@ -1,14 +0,0 @@
-This software (thunar-sendto-clamtk) is provided 'as is' without
-warranty of any kind, either expressed or implied, including, but
-not limited to, the implied warranties of fitness for a purpose,
-or the warranty of non-infringement.
-
-Without limiting the foregoing, there is no warranty that:
-
-   1. the software will meet your requirements
-   2. the software will be uninterrupted, timely, secure or error-free
-   3. the results that may be obtained from the use of the software will
-      be effective, accurate or reliable
-   4. the quality of the software will meet your expectations
-
-Having said that, I do my best to make it as good as I can. Really.
diff -pruN 6.02-1/thunar-sendto-clamtk-0-06/LICENSE 6.03-1/thunar-sendto-clamtk-0-06/LICENSE
--- 6.02-1/thunar-sendto-clamtk-0-06/LICENSE	2017-09-30 04:09:49.000000000 +0000
+++ 6.03-1/thunar-sendto-clamtk-0-06/LICENSE	1970-01-01 00:00:00.000000000 +0000
@@ -1,19 +0,0 @@
-COPYRIGHT AND LICENCE
-
-thunar-sendto-clamtk, copyright (C) 2010-2017 Dave M 
-
-https://github.com/dave-theunsub/thunar-sendto-clamtk
-https://gitlab.com/dave_m/thunar-sendto-clamtk
-https://bitbucket.org/davem_/thunar-sendto-clamtk/
-http://thunar.xfce.org
-http://standards.freedesktop.org/desktop-entry-spec/latest/
-<dave.nerd AT gmail.com>
-
-All rights reserved.  This program is free software; you can
-redistribute it and/or modify it under the terms of either:
-
-a) the GNU General Public License as published by the Free
-Software Foundation;
-either version 1, or (at your option) any later version, or
-
-b) the "Artistic License". 
diff -pruN 6.02-1/thunar-sendto-clamtk-0-06/README 6.03-1/thunar-sendto-clamtk-0-06/README
--- 6.02-1/thunar-sendto-clamtk-0-06/README	2017-09-30 04:11:52.000000000 +0000
+++ 6.03-1/thunar-sendto-clamtk-0-06/README	1970-01-01 00:00:00.000000000 +0000
@@ -1,40 +0,0 @@
-README
-------
-(Last updated 29 Sept 2017)
-
-thunar-sendto-clamtk is a simple plugin to allow a right-click,
-context menu scan of files or folders in Thunar, XFCE's file manager.
-
-All this plugin does is copy a desktop file to Thunar's send-to
-directory.  If this seems redundant, that's because it is:
-this plugin depends on clamtk, which already has this directory
-file. So, it stands to reason we should be able to just find that
-file and copy it, rather than having our own copy.
-
-thunar-sendto-clamtk is available for Fedora, CentOS, and Debian/
-Ubuntu - or probably any system that can run XFCE.  It is also
-now available via Fedora's official repositories.
-
-DEPENDENCIES
-------------
-
-clamtk >= 5.00
-Thunar
-
-LINKS
------
-https://dave-theunsub.github.io/clamtk/
-https://github.com/dave-theunsub/thunar-sendto-clamtk
-https://gitlab.com/dave_m/thunar-sendto-clamtk
-https://bitbucket.org/davem_/thunar-sendto-clamtk/
-http://thunar.xfce.org
-http://standards.freedesktop.org/desktop-entry-spec/latest/
-
-Screenshot:
-https://i.imgur.com/2l1Ct1h.png
-
-CONTACT
--------
-
-Dave M, dave.nerd @ gmail .com
-0x6ADA59DE
Binary files 6.02-1/thunar-sendto-clamtk-0-06/thunar-sendto-clamtk.1.gz and 6.03-1/thunar-sendto-clamtk-0-06/thunar-sendto-clamtk.1.gz differ
diff -pruN 6.02-1/thunar-sendto-clamtk-0-06/thunar-sendto-clamtk.desktop 6.03-1/thunar-sendto-clamtk-0-06/thunar-sendto-clamtk.desktop
--- 6.02-1/thunar-sendto-clamtk-0-06/thunar-sendto-clamtk.desktop	2017-09-30 04:35:23.000000000 +0000
+++ 6.03-1/thunar-sendto-clamtk-0-06/thunar-sendto-clamtk.desktop	1970-01-01 00:00:00.000000000 +0000
@@ -1,114 +0,0 @@
-# thunar-sendto-clamtk 0.06
-[Desktop Entry]
-Name=ClamTk
-GenericName=Virus Scanner
-GenericName[af]=Virus Skandeerder
-GenericName[ar]=ماسح الفيروسات
-GenericName[ast]=Antivirus
-GenericName[az]=Virus axtarışı
-GenericName[bg]=Скенер за вируси
-GenericName[bs]=Virus Skener
-GenericName[ca]=Comprovador de virus
-GenericName[cs]=Antivirový program
-GenericName[da]=Virusscanneren
-GenericName[de]=Virensuche
-GenericName[el]=Ανιχνευτής ιών
-GenericName[en_AU]=Virus Scanner
-GenericName[en_CA]=Virus Scanner
-GenericName[en_GB]=Virus Scanner
-GenericName[eo]=Viruskontrolilo
-GenericName[es]=Analizador de Virus
-GenericName[eu]=Birus eskanerra
-GenericName[fi]=Virustorjuntasovellus
-GenericName[fo]=Virus skannari
-GenericName[fr]=Module de recherche et analyse de virus
-GenericName[gl]=Analizador de virus
-GenericName[he]=סורק וירוסים
-GenericName[hr]=Skener virusa
-GenericName[hu]=Víruskereső
-GenericName[id]=Pemindai Virus
-GenericName[it]=Analizzatore virus
-GenericName[ja]=ウイルススキャナ
-GenericName[ko]=바이러스 검사기
-GenericName[lt]=Virusų suradimo programa
-GenericName[mr]=धमक्या साठी स्कॅन
-GenericName[ms]=Pengimbas Virus
-GenericName[nb]=Virusskanner
-GenericName[nl]=Virusscanner
-GenericName[nl_BE]=Virusscanner
-GenericName[nn]=Virusskannar
-GenericName[pa]=ਵਿਸ਼ਾਣੂ ਖੋਜੀ"
-GenericName[pl]=Skaner wirusów
-GenericName[pt]=Verificador de vírus
-GenericName[pt_BR]=Antivírus Escaner
-GenericName[ro]=Scaner pentru viruși
-GenericName[ru]=Проверка на вирусы
-GenericName[sk]=Antivírus
-GenericName[sl]=Virusni pregledovalec
-GenericName[sr@latin]=Virus Skener
-GenericName[sv]=Virusskanner
-GenericName[te]=వైరస్ స్కానర్
-GenericName[th]=โปรแกรมตรวจจับไวรัส
-GenericName[tr]=Virüs Tarayıcı
-GenericName[ug]=ۋﻯﺭۇﺱ ﺕەﻚﺷۈﺭگۈچ
-GenericName[uk]=Антивірусний сканер
-GenericName[uz]=Вирусларни текшириш
-GenericName[zh_CN]=病毒扫描工具
-GenericName[zh_TW]=病毒掃描程式
-Comment=Scan for threats...
-Comment[af]=Skandeer vir virusse...
-Comment[ar]=إمسح للكشف عن الفيروسات
-Comment[ast]=Buscar amenaces...
-Comment[az]=Təhlükə mövcudluğuna yoxla...
-Comment[bg]=Проверка за наличие на заплахи ...
-Comment[bs]=Pretraga za virusima...
-Comment[cs]=Skenování hrozeb...
-Comment[da]=Skan for virus...
-Comment[de]=Auf Bedrohungen untersuchen…
-Comment[el]=Έλεγχος για ιούς...
-Comment[en]=Scan for threats...
-Comment[en_AU]=Scan for threats...
-Comment[en_CA]=Scan for threats...
-Comment[en_GB]=Scan for threats...
-Comment[es]=Analizar en busca de amenazas…
-Comment[eu]=Eskaneatu birusen bila...
-Comment[fi]=Tarkista uhkien varalta...
-Comment[fo]=Skanna eftir virus...
-Comment[fr]=Rechercher des menaces...
-Comment[gl]=Buscar ameazas...
-Comment[he]=סריקה לאיתור איומים…
-Comment[hr]=Pretraživanje virusa...
-Comment[hu]=Vírusok keresése...
-Comment[id]=Pindai untuk ancaman...
-Comment[it]=Analizza per la ricerca di minacce...
-Comment[ja]=ウィルスをスキャンします...
-Comment[ko]=위험 요소를 검사합니다...
-Comment[ms]=Imbas jika ada ancaman...
-Comment[nl]=Scannen op virussen…
-Comment[nb]=Skann etter virus...
-Comment[nn]=Skann...
-Comment[pa]=ਧਮਕਿਯਾੰ ਲਈ ਖੋਜ ਕਰੋ
-Comment[pl]=Przeskanuj pliki w poszukiwaniu wirusów...
-Comment[pt]=A analizar ameaças...
-Comment[pt_BR]=Verificar se há vírus...
-Comment[ro]=Scanare pentru amenințări...
-Comment[ru]=Проверка на наличие угроз...
-Comment[sk]=Skenovanie hrozieb...
-Comment[sl]=Preglej za virusi...
-Comment[sr@latin]=Skeniranje pretnji...
-Comment[sv]=Skanna efter virus...
-Comment[te]=వైరస్సుల కోసం సంశోధిస్తున్నది...
-Comment[tr]=Virüs taraması yap...
-Comment[ug]=ۋىرۇس تەكشۈر…
-Comment[uk]=Шукати загрози…
-Comment[uz]=Хавф учун текшириш...
-Comment[zh_CN]=扫描威胁...
-Comment[zh_TW]=掃描威脅...
-TryExec=clamtk
-Exec=clamtk %F
-Icon=clamtk
-Type=Application
-Terminal=false
-StartupNotify=true
-Keywords=antivirus;virus;malware;scan;scanner;
-OnlyShowIn=XFCE;
